searchData={"items":[{"type":"module","title":"Beaver","doc":"This module contains top level functions and macros for Beaver DSL for MLIR.\n\nHere are some of the examples of most common forms of Beaver DSL:\n- single result\n```\nres = TOSA.add(a, b) >>> res_t\n```\n- multiple results\n```\n[res1, res2] = TOSA.add(a, b) >>> [res_t, res_t]\n[res1, res2] = TOSA.add(a, b) >>> res_t_list\nres_list = TOSA.add(a, b) >>> res_t_list\n```\n- infer results\n```\nTOSA.add(a, b) >>> :infer\n```\n- with op\n```\n{op, res} = TOSA.add(a, b) >>> {:op, res_t}\n```\n- with no result\n```\nTOSA.add(a, b) >>> []\n```","ref":"Beaver.html"},{"type":"function","title":"Beaver.>>>/2","doc":"","ref":"Beaver.html#%3E%3E%3E/2"},{"type":"macro","title":"Beaver.block/1","doc":"","ref":"Beaver.html#block/1"},{"type":"macro","title":"Beaver.block/2","doc":"","ref":"Beaver.html#block/2"},{"type":"macro","title":"Beaver.mlir/1","doc":"This is a macro where Beaver's MLIR DSL expressions get transformed to MLIR API calls.\nThis transformation will works on any expression of this form, so it is also possible to call any other function/macro rather than an Op creation function. There is one operator `>>>` for typing the result of the SSA or an argument of a block. It kind of works like the `::` in specs and types of Elixir.","ref":"Beaver.html#mlir/1"},{"type":"macro","title":"How it works under the hood - Beaver.mlir/1","doc":"```\nmlir do\n  [res0, res1] = TestDialect.some_op(operand0, operand1, attr0: ~a{11 : i32}) >>> ~t{f32}\nend\n# will be transform to:\n[res0, res1] =\n  %DSL.SSA{}\n  |> DSL.SSA.arguments([operand0, operand1, attr0: ~a{11 : i32}, attr1: ~a{11 : i32}])\n  |> DSL.SSA.results([~t{f32}])\n  |> TestDialect.some_op()\n```\nThe SSA form will return:\n- For op with multiple result: the results of this op in a list.\n- For op with one single result: the result\n- For op with no result: the op itself (for instance, module, func, and terminators)\n\nIf there is no returns, add a `[]` to make the transformation effective:\n```\nTestDialect.some_op(operand0) >>> []\n```\nTo defer the creation of a terminator in case its successor block has not been created. You can pass an atom of the name in the block's call form.\n```\nCF.cond_br(cond0, :bb1, {:bb2, [v0]})  >>> []\n```\nTo create region, call the op with a do block. The block macro works like the function definition in Elixir, and in the do block of `block` macro you can reference an argument by name. One caveat is that if it is a Op with region, it requires all arguments to be passed in one list to make it to call the macro version of the Op creation function.\n```\nTestDialect.op_with_region [operand0, attr0: ~a{1}i32] do\n  region do\n    block(arg >>> ~t{f32}) do\n      TestDialect.some_op(arg) >>> ~t{f32}\n    end\n  end\nend >>> ~t{f32}\n```","ref":"Beaver.html#mlir/1-how-it-works-under-the-hood"},{"type":"macro","title":"Beaver.mlir/2","doc":"","ref":"Beaver.html#mlir/2"},{"type":"macro","title":"Beaver.region/1","doc":"","ref":"Beaver.html#region/1"},{"type":"module","title":"Beaver.Env","doc":"This module defines macros to getting MLIR context, region, block within the do block of mlir/1. It works like __MODULE__/0, __CALLER__/0 of Elixir special forms.","ref":"Beaver.Env.html"},{"type":"macro","title":"Beaver.Env.block/0","doc":"Return block in the DSL environment","ref":"Beaver.Env.html#block/0"},{"type":"macro","title":"Beaver.Env.block/1","doc":"Return block with a given name in the DSL environment","ref":"Beaver.Env.html#block/1"},{"type":"macro","title":"Beaver.Env.context/0","doc":"Return context in the DSL environment","ref":"Beaver.Env.html#context/0"},{"type":"macro","title":"Beaver.Env.region/0","doc":"Return region in the DSL environment","ref":"Beaver.Env.html#region/0"},{"type":"behaviour","title":"Beaver.Exterior","doc":"Behavior to build and register a dialect not included in LLVM mono repo. It is called \"Exterior\" not \"Extension\" or \"External\" to avoid confusing it with various LLVM/MLIR concepts of extensions.","ref":"Beaver.Exterior.html"},{"type":"function","title":"Beaver.Exterior.register_all/1","doc":"","ref":"Beaver.Exterior.html#register_all/1"},{"type":"callback","title":"Beaver.Exterior.register_dialect/1","doc":"Register a register to a MLIR context","ref":"Beaver.Exterior.html#c:register_dialect/1"},{"type":"module","title":"Beaver.Exterior.Elixir","doc":"","ref":"Beaver.Exterior.Elixir.html"},{"type":"function","title":"Beaver.Exterior.Elixir.register_dialect/1","doc":"","ref":"Beaver.Exterior.Elixir.html#register_dialect/1"},{"type":"module","title":"Beaver.Pattern","doc":"Beaver pattern DSL for MLIR, a PDL frontend in Elixir.","ref":"Beaver.Pattern.html"},{"type":"macro","title":"Beaver.Pattern.attribute/1","doc":"","ref":"Beaver.Pattern.html#attribute/1"},{"type":"function","title":"Beaver.Pattern.create_operation/5","doc":"The difference between a pdl.operation creation in a match body and a rewrite body:\n- in a match body, `pdl.attribute`/`pdl.operand`/`pdl.result` will be generated for unbound variables\n- in a rewrite body, all variables are considered bound before creation pdl ops","ref":"Beaver.Pattern.html#create_operation/5"},{"type":"macro","title":"Beaver.Pattern.defpat/2","doc":"","ref":"Beaver.Pattern.html#defpat/2"},{"type":"function","title":"Beaver.Pattern.eval_rewrite/1","doc":"Evaluate SSA as ops in a rewrite block. Note that function is only public so that it could be used in a AST.","ref":"Beaver.Pattern.html#eval_rewrite/1"},{"type":"macro","title":"Beaver.Pattern.replace/2","doc":"","ref":"Beaver.Pattern.html#replace/2"},{"type":"macro","title":"Beaver.Pattern.rewrite/2","doc":"","ref":"Beaver.Pattern.html#rewrite/2"},{"type":"macro","title":"Beaver.Pattern.type/0","doc":"","ref":"Beaver.Pattern.html#type/0"},{"type":"macro","title":"Beaver.Pattern.type/1","doc":"","ref":"Beaver.Pattern.html#type/1"},{"type":"macro","title":"Beaver.Pattern.value/0","doc":"","ref":"Beaver.Pattern.html#value/0"},{"type":"module","title":"Beaver.SSA","doc":"Storing MLIR IR structure with a Elixir struct. Macros like `Beaver.mlir/1` will generate SSA structs defined by this module.","ref":"Beaver.SSA.html"},{"type":"function","title":"Beaver.SSA.eval/1","doc":"","ref":"Beaver.SSA.html#eval/1"},{"type":"function","title":"Beaver.SSA.postwalk/2","doc":"","ref":"Beaver.SSA.html#postwalk/2"},{"type":"function","title":"Beaver.SSA.prewalk/2","doc":"","ref":"Beaver.SSA.html#prewalk/2"},{"type":"function","title":"Beaver.SSA.put_arguments/2","doc":"","ref":"Beaver.SSA.html#put_arguments/2"},{"type":"function","title":"Beaver.SSA.put_block/2","doc":"","ref":"Beaver.SSA.html#put_block/2"},{"type":"function","title":"Beaver.SSA.put_ctx/2","doc":"","ref":"Beaver.SSA.html#put_ctx/2"},{"type":"function","title":"Beaver.SSA.put_filler/2","doc":"","ref":"Beaver.SSA.html#put_filler/2"},{"type":"function","title":"Beaver.SSA.put_location/2","doc":"","ref":"Beaver.SSA.html#put_location/2"},{"type":"function","title":"Beaver.SSA.put_results/2","doc":"","ref":"Beaver.SSA.html#put_results/2"},{"type":"type","title":"Beaver.SSA.t/0","doc":"","ref":"Beaver.SSA.html#t:t/0"},{"type":"behaviour","title":"Beaver.Slang","doc":"Defining a MLIR dialect with macros in Elixir. Internally expressions are compiled to [IRDL](https://mlir.llvm.org/docs/Dialects/IRDL/)","ref":"Beaver.Slang.html"},{"type":"callback","title":"Beaver.Slang.__slang_dialect__/1","doc":"","ref":"Beaver.Slang.html#c:__slang_dialect__/1"},{"type":"macro","title":"Beaver.Slang.__using__/1","doc":"This macro is invoked when the module is used. It sets up the module by registering attributes and importing macros from `Beaver.Slang`.","ref":"Beaver.Slang.html#__using__/1"},{"type":"macro","title":"Beaver.Slang.any/0","doc":"This macro generates the AST for the `irdl.any` op.","ref":"Beaver.Slang.html#any/0"},{"type":"macro","title":"Beaver.Slang.any_of/1","doc":"This macro generates the AST for the any_of attribute in the dialect.","ref":"Beaver.Slang.html#any_of/1"},{"type":"macro","title":"Beaver.Slang.defalias/2","doc":"This macro defines an alias for a lengthy type. It generates the AST for the alias function.","ref":"Beaver.Slang.html#defalias/2"},{"type":"macro","title":"Beaver.Slang.defattr/1","doc":"This macro defines a attribute in the dialect.","ref":"Beaver.Slang.html#defattr/1"},{"type":"macro","title":"Beaver.Slang.defop/2","doc":"This macro defines an operation in the dialect. It generates the AST for the creator function for the operation.","ref":"Beaver.Slang.html#defop/2"},{"type":"macro","title":"Beaver.Slang.deftype/1","doc":"This macro defines a type in the dialect.","ref":"Beaver.Slang.html#deftype/1"},{"type":"macro","title":"Beaver.Slang.is/1","doc":"This macro generates the AST for `irdl.is` op, usually used to create a constraint on type","ref":"Beaver.Slang.html#is/1"},{"type":"function","title":"Beaver.Slang.load/2","doc":"This function loads the MLIR dialect into the MLIR context. It invokes the internal function of the provided module to create the dialect's IRDL module and performs additional MLIR transformations and verification.","ref":"Beaver.Slang.html#load/2"},{"type":"module","title":"Beaver.Walker","doc":"Walker to traverse MLIR structures including operands, results, successors, attributes, regions.\nIt implements the `Enumerable` protocol and the `Access` behavior.","ref":"Beaver.Walker.html"},{"type":"function","title":"Beaver.Walker.arguments/1","doc":"Returns an enumerable of the arguments of an `Block.t()`","ref":"Beaver.Walker.html#arguments/1"},{"type":"function","title":"Beaver.Walker.attributes/1","doc":"Returns an enumerable of the attributes of an `operation()`.","ref":"Beaver.Walker.html#attributes/1"},{"type":"function","title":"Beaver.Walker.blocks/1","doc":"Returns an enumerable of the blocks of an `Region.t()`","ref":"Beaver.Walker.html#blocks/1"},{"type":"function","title":"Beaver.Walker.operands/1","doc":"Returns an enumerable of the operands of an `operation()`.","ref":"Beaver.Walker.html#operands/1"},{"type":"function","title":"Beaver.Walker.operations/1","doc":"Returns an enumerable of the operations of an `Block.t()`","ref":"Beaver.Walker.html#operations/1"},{"type":"function","title":"Beaver.Walker.postwalk/2","doc":"Performs a depth-first, post-order traversal of a MLIR structure.","ref":"Beaver.Walker.html#postwalk/2"},{"type":"function","title":"Beaver.Walker.postwalk/3","doc":"Performs a depth-first, post-order traversal of a MLIR structure using an accumulator.","ref":"Beaver.Walker.html#postwalk/3"},{"type":"function","title":"Beaver.Walker.prewalk/2","doc":"Performs a depth-first, pre-order traversal of a MLIR structure.","ref":"Beaver.Walker.html#prewalk/2"},{"type":"function","title":"Beaver.Walker.prewalk/3","doc":"Performs a depth-first, pre-order traversal of a MLIR structure using an accumulator.","ref":"Beaver.Walker.html#prewalk/3"},{"type":"function","title":"Beaver.Walker.regions/1","doc":"Returns an enumerable of the regions of an `operation()`.","ref":"Beaver.Walker.html#regions/1"},{"type":"function","title":"Beaver.Walker.replace/3","doc":"Replace a operation with a value","ref":"Beaver.Walker.html#replace/3"},{"type":"function","title":"Beaver.Walker.results/1","doc":"Returns an enumerable of the results of an `operation()`.","ref":"Beaver.Walker.html#results/1"},{"type":"function","title":"Beaver.Walker.successors/1","doc":"Returns an enumerable of the successor blocks of an `operation()`.","ref":"Beaver.Walker.html#successors/1"},{"type":"function","title":"Beaver.Walker.traverse/4","doc":"Traverse and transform a container in MLIR, it could be a operation, region, block.\nYou might expect this function works like `Macro.traverse/4`.","ref":"Beaver.Walker.html#traverse/4"},{"type":"function","title":"More on manipulating the IR - Beaver.Walker.traverse/4","doc":"During the traversal, there are generally two choices to manipulate the IR:\n- Use a pattern defined by macro `Beaver.Pattern.defpat/2` to have the PDL interpreter transform the IR for you.\nYou can use both if it is proper to do so.\n- Use `Beaver.Walker.replace/2` to replace the operation and return a walker as placeholder if is replaced by value.\nIt could be mind-boggling to think the IR is mutable but not an issue if your approach is very functional. Inappropriate mutation might cause crash or bugs if somewhere else is keeping a reference of the replace op.","ref":"Beaver.Walker.html#traverse/4-more-on-manipulating-the-ir"},{"type":"function","title":"Some tips - Beaver.Walker.traverse/4","doc":"- If your matching is very complicated, using `with/1` in Elixir should cover it.\n- Use `defpat` if you want MLIR's greedy pattern application based on benefits instead of implementing something alike yourself.\n- You can run traversals in a MLIR pass by calling them in `run/1` so that it joins the general MLIR pass manager's orchestration and will be run in parallel when possible.","ref":"Beaver.Walker.html#traverse/4-some-tips"},{"type":"function","title":"Beaver.Walker.uses/1","doc":"Returns an enumerable of the uses of an `Value.t()`","ref":"Beaver.Walker.html#uses/1"},{"type":"type","title":"Beaver.Walker.container/0","doc":"","ref":"Beaver.Walker.html#t:container/0"},{"type":"type","title":"Beaver.Walker.element/0","doc":"","ref":"Beaver.Walker.html#t:element/0"},{"type":"type","title":"Beaver.Walker.element_module/0","doc":"","ref":"Beaver.Walker.html#t:element_module/0"},{"type":"type","title":"Beaver.Walker.mlir/0","doc":"","ref":"Beaver.Walker.html#t:mlir/0"},{"type":"type","title":"Beaver.Walker.operation/0","doc":"","ref":"Beaver.Walker.html#t:operation/0"},{"type":"type","title":"Beaver.Walker.t/0","doc":"","ref":"Beaver.Walker.html#t:t/0"},{"type":"module","title":"Beaver.Walker.OpReplacement","doc":"A placeholder when an operation is replaced by value.","ref":"Beaver.Walker.OpReplacement.html"},{"type":"type","title":"Beaver.Walker.OpReplacement.t/0","doc":"","ref":"Beaver.Walker.OpReplacement.html#t:t/0"},{"type":"module","title":"Beaver.ENIF","doc":"This module provides functions to work with Erlang's [erl_nif](https://www.erlang.org/doc/man/erl_nif.html) APIs in MLIR.","ref":"Beaver.ENIF.html"},{"type":"module","title":"Main usages - Beaver.ENIF","doc":"- call `declare_external_functions/2` to insert external function declarations into a `Beaver.MLIR.Block`\n- call `register_symbols/1` to register symbols of ENIF functions in a `Beaver.MLIR.ExecutionEngine`","ref":"Beaver.ENIF.html#module-main-usages"},{"type":"function","title":"Beaver.ENIF.alloc/1","doc":"function call to [enif_alloc](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_alloc)","ref":"Beaver.ENIF.html#alloc/1"},{"type":"function","title":"Beaver.ENIF.alloc_binary/1","doc":"function call to [enif_alloc_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_alloc_binary)","ref":"Beaver.ENIF.html#alloc_binary/1"},{"type":"function","title":"Beaver.ENIF.alloc_env/1","doc":"function call to [enif_alloc_env](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_alloc_env)","ref":"Beaver.ENIF.html#alloc_env/1"},{"type":"function","title":"Beaver.ENIF.alloc_resource/1","doc":"function call to [enif_alloc_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_alloc_resource)","ref":"Beaver.ENIF.html#alloc_resource/1"},{"type":"function","title":"Beaver.ENIF.binary_to_term/1","doc":"function call to [enif_binary_to_term](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_binary_to_term)","ref":"Beaver.ENIF.html#binary_to_term/1"},{"type":"function","title":"Beaver.ENIF.clear_env/1","doc":"function call to [enif_clear_env](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_clear_env)","ref":"Beaver.ENIF.html#clear_env/1"},{"type":"function","title":"Beaver.ENIF.compare/1","doc":"function call to [enif_compare](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_compare)","ref":"Beaver.ENIF.html#compare/1"},{"type":"function","title":"Beaver.ENIF.compare_monitors/1","doc":"function call to [enif_compare_monitors](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_compare_monitors)","ref":"Beaver.ENIF.html#compare_monitors/1"},{"type":"function","title":"Beaver.ENIF.compare_pids/1","doc":"function call to [enif_compare_pids](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_compare_pids)","ref":"Beaver.ENIF.html#compare_pids/1"},{"type":"function","title":"Beaver.ENIF.cond_broadcast/1","doc":"function call to [enif_cond_broadcast](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_broadcast)","ref":"Beaver.ENIF.html#cond_broadcast/1"},{"type":"function","title":"Beaver.ENIF.cond_create/1","doc":"function call to [enif_cond_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_create)","ref":"Beaver.ENIF.html#cond_create/1"},{"type":"function","title":"Beaver.ENIF.cond_destroy/1","doc":"function call to [enif_cond_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_destroy)","ref":"Beaver.ENIF.html#cond_destroy/1"},{"type":"function","title":"Beaver.ENIF.cond_name/1","doc":"function call to [enif_cond_name](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_name)","ref":"Beaver.ENIF.html#cond_name/1"},{"type":"function","title":"Beaver.ENIF.cond_signal/1","doc":"function call to [enif_cond_signal](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_signal)","ref":"Beaver.ENIF.html#cond_signal/1"},{"type":"function","title":"Beaver.ENIF.cond_wait/1","doc":"function call to [enif_cond_wait](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_wait)","ref":"Beaver.ENIF.html#cond_wait/1"},{"type":"function","title":"Beaver.ENIF.consume_timeslice/1","doc":"function call to [enif_consume_timeslice](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_consume_timeslice)","ref":"Beaver.ENIF.html#consume_timeslice/1"},{"type":"function","title":"Beaver.ENIF.convert_time_unit/1","doc":"function call to [enif_convert_time_unit](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_convert_time_unit)","ref":"Beaver.ENIF.html#convert_time_unit/1"},{"type":"function","title":"Beaver.ENIF.cpu_time/1","doc":"function call to [enif_cpu_time](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cpu_time)","ref":"Beaver.ENIF.html#cpu_time/1"},{"type":"function","title":"Beaver.ENIF.declare_external_functions/2","doc":"Insert external functions of ENIF into given MLIR block","ref":"Beaver.ENIF.html#declare_external_functions/2"},{"type":"function","title":"Beaver.ENIF.demonitor_process/1","doc":"function call to [enif_demonitor_process](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_demonitor_process)","ref":"Beaver.ENIF.html#demonitor_process/1"},{"type":"function","title":"Beaver.ENIF.dynamic_resource_call/1","doc":"function call to [enif_dynamic_resource_call](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_dynamic_resource_call)","ref":"Beaver.ENIF.html#dynamic_resource_call/1"},{"type":"function","title":"Beaver.ENIF.equal_tids/1","doc":"function call to [enif_equal_tids](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_equal_tids)","ref":"Beaver.ENIF.html#equal_tids/1"},{"type":"function","title":"Beaver.ENIF.fprintf/1","doc":"function call to [enif_fprintf](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_fprintf)","ref":"Beaver.ENIF.html#fprintf/1"},{"type":"function","title":"Beaver.ENIF.free/1","doc":"function call to [enif_free](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_free)","ref":"Beaver.ENIF.html#free/1"},{"type":"function","title":"Beaver.ENIF.free_env/1","doc":"function call to [enif_free_env](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_free_env)","ref":"Beaver.ENIF.html#free_env/1"},{"type":"function","title":"Beaver.ENIF.free_iovec/1","doc":"function call to [enif_free_iovec](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_free_iovec)","ref":"Beaver.ENIF.html#free_iovec/1"},{"type":"function","title":"Beaver.ENIF.functions/0","doc":"","ref":"Beaver.ENIF.html#functions/0"},{"type":"function","title":"Beaver.ENIF.get_atom/1","doc":"function call to [enif_get_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_atom)","ref":"Beaver.ENIF.html#get_atom/1"},{"type":"function","title":"Beaver.ENIF.get_atom_length/1","doc":"function call to [enif_get_atom_length](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_atom_length)","ref":"Beaver.ENIF.html#get_atom_length/1"},{"type":"function","title":"Beaver.ENIF.get_double/1","doc":"function call to [enif_get_double](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_double)","ref":"Beaver.ENIF.html#get_double/1"},{"type":"function","title":"Beaver.ENIF.get_int64/1","doc":"function call to [enif_get_int64](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_int64)","ref":"Beaver.ENIF.html#get_int64/1"},{"type":"function","title":"Beaver.ENIF.get_int/1","doc":"function call to [enif_get_int](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_int)","ref":"Beaver.ENIF.html#get_int/1"},{"type":"function","title":"Beaver.ENIF.get_list_cell/1","doc":"function call to [enif_get_list_cell](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_list_cell)","ref":"Beaver.ENIF.html#get_list_cell/1"},{"type":"function","title":"Beaver.ENIF.get_list_length/1","doc":"function call to [enif_get_list_length](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_list_length)","ref":"Beaver.ENIF.html#get_list_length/1"},{"type":"function","title":"Beaver.ENIF.get_local_pid/1","doc":"function call to [enif_get_local_pid](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_local_pid)","ref":"Beaver.ENIF.html#get_local_pid/1"},{"type":"function","title":"Beaver.ENIF.get_local_port/1","doc":"function call to [enif_get_local_port](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_local_port)","ref":"Beaver.ENIF.html#get_local_port/1"},{"type":"function","title":"Beaver.ENIF.get_long/1","doc":"function call to [enif_get_long](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_long)","ref":"Beaver.ENIF.html#get_long/1"},{"type":"function","title":"Beaver.ENIF.get_map_size/1","doc":"function call to [enif_get_map_size](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_map_size)","ref":"Beaver.ENIF.html#get_map_size/1"},{"type":"function","title":"Beaver.ENIF.get_map_value/1","doc":"function call to [enif_get_map_value](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_map_value)","ref":"Beaver.ENIF.html#get_map_value/1"},{"type":"function","title":"Beaver.ENIF.get_resource/1","doc":"function call to [enif_get_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_resource)","ref":"Beaver.ENIF.html#get_resource/1"},{"type":"function","title":"Beaver.ENIF.get_string/1","doc":"function call to [enif_get_string](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_string)","ref":"Beaver.ENIF.html#get_string/1"},{"type":"function","title":"Beaver.ENIF.get_string_length/1","doc":"function call to [enif_get_string_length](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_string_length)","ref":"Beaver.ENIF.html#get_string_length/1"},{"type":"function","title":"Beaver.ENIF.get_tuple/1","doc":"function call to [enif_get_tuple](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_tuple)","ref":"Beaver.ENIF.html#get_tuple/1"},{"type":"function","title":"Beaver.ENIF.get_uint64/1","doc":"function call to [enif_get_uint64](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_uint64)","ref":"Beaver.ENIF.html#get_uint64/1"},{"type":"function","title":"Beaver.ENIF.get_uint/1","doc":"function call to [enif_get_uint](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_uint)","ref":"Beaver.ENIF.html#get_uint/1"},{"type":"function","title":"Beaver.ENIF.get_ulong/1","doc":"function call to [enif_get_ulong](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_ulong)","ref":"Beaver.ENIF.html#get_ulong/1"},{"type":"function","title":"Beaver.ENIF.getenv/1","doc":"function call to [enif_getenv](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_getenv)","ref":"Beaver.ENIF.html#getenv/1"},{"type":"function","title":"Beaver.ENIF.has_pending_exception/1","doc":"function call to [enif_has_pending_exception](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_has_pending_exception)","ref":"Beaver.ENIF.html#has_pending_exception/1"},{"type":"function","title":"Beaver.ENIF.hash/1","doc":"function call to [enif_hash](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_hash)","ref":"Beaver.ENIF.html#hash/1"},{"type":"function","title":"Beaver.ENIF.init_resource_type/1","doc":"function call to [enif_init_resource_type](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_init_resource_type)","ref":"Beaver.ENIF.html#init_resource_type/1"},{"type":"function","title":"Beaver.ENIF.inspect_binary/1","doc":"function call to [enif_inspect_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_inspect_binary)","ref":"Beaver.ENIF.html#inspect_binary/1"},{"type":"function","title":"Beaver.ENIF.inspect_iolist_as_binary/1","doc":"function call to [enif_inspect_iolist_as_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_inspect_iolist_as_binary)","ref":"Beaver.ENIF.html#inspect_iolist_as_binary/1"},{"type":"function","title":"Beaver.ENIF.inspect_iovec/1","doc":"function call to [enif_inspect_iovec](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_inspect_iovec)","ref":"Beaver.ENIF.html#inspect_iovec/1"},{"type":"function","title":"Beaver.ENIF.invoke/4","doc":"","ref":"Beaver.ENIF.html#invoke/4"},{"type":"function","title":"Beaver.ENIF.ioq_create/1","doc":"function call to [enif_ioq_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_create)","ref":"Beaver.ENIF.html#ioq_create/1"},{"type":"function","title":"Beaver.ENIF.ioq_deq/1","doc":"function call to [enif_ioq_deq](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_deq)","ref":"Beaver.ENIF.html#ioq_deq/1"},{"type":"function","title":"Beaver.ENIF.ioq_destroy/1","doc":"function call to [enif_ioq_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_destroy)","ref":"Beaver.ENIF.html#ioq_destroy/1"},{"type":"function","title":"Beaver.ENIF.ioq_enq_binary/1","doc":"function call to [enif_ioq_enq_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_enq_binary)","ref":"Beaver.ENIF.html#ioq_enq_binary/1"},{"type":"function","title":"Beaver.ENIF.ioq_enqv/1","doc":"function call to [enif_ioq_enqv](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_enqv)","ref":"Beaver.ENIF.html#ioq_enqv/1"},{"type":"function","title":"Beaver.ENIF.ioq_peek/1","doc":"function call to [enif_ioq_peek](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_peek)","ref":"Beaver.ENIF.html#ioq_peek/1"},{"type":"function","title":"Beaver.ENIF.ioq_peek_head/1","doc":"function call to [enif_ioq_peek_head](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_peek_head)","ref":"Beaver.ENIF.html#ioq_peek_head/1"},{"type":"function","title":"Beaver.ENIF.ioq_size/1","doc":"function call to [enif_ioq_size](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_size)","ref":"Beaver.ENIF.html#ioq_size/1"},{"type":"function","title":"Beaver.ENIF.is_atom/1","doc":"function call to [enif_is_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_atom)","ref":"Beaver.ENIF.html#is_atom/1"},{"type":"function","title":"Beaver.ENIF.is_binary/1","doc":"function call to [enif_is_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_binary)","ref":"Beaver.ENIF.html#is_binary/1"},{"type":"function","title":"Beaver.ENIF.is_current_process_alive/1","doc":"function call to [enif_is_current_process_alive](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_current_process_alive)","ref":"Beaver.ENIF.html#is_current_process_alive/1"},{"type":"function","title":"Beaver.ENIF.is_empty_list/1","doc":"function call to [enif_is_empty_list](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_empty_list)","ref":"Beaver.ENIF.html#is_empty_list/1"},{"type":"function","title":"Beaver.ENIF.is_exception/1","doc":"function call to [enif_is_exception](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_exception)","ref":"Beaver.ENIF.html#is_exception/1"},{"type":"function","title":"Beaver.ENIF.is_fun/1","doc":"function call to [enif_is_fun](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_fun)","ref":"Beaver.ENIF.html#is_fun/1"},{"type":"function","title":"Beaver.ENIF.is_identical/1","doc":"function call to [enif_is_identical](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_identical)","ref":"Beaver.ENIF.html#is_identical/1"},{"type":"function","title":"Beaver.ENIF.is_list/1","doc":"function call to [enif_is_list](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_list)","ref":"Beaver.ENIF.html#is_list/1"},{"type":"function","title":"Beaver.ENIF.is_map/1","doc":"function call to [enif_is_map](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_map)","ref":"Beaver.ENIF.html#is_map/1"},{"type":"function","title":"Beaver.ENIF.is_number/1","doc":"function call to [enif_is_number](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_number)","ref":"Beaver.ENIF.html#is_number/1"},{"type":"function","title":"Beaver.ENIF.is_pid/1","doc":"function call to [enif_is_pid](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_pid)","ref":"Beaver.ENIF.html#is_pid/1"},{"type":"function","title":"Beaver.ENIF.is_pid_undefined/1","doc":"function call to [enif_is_pid_undefined](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_pid_undefined)","ref":"Beaver.ENIF.html#is_pid_undefined/1"},{"type":"function","title":"Beaver.ENIF.is_port/1","doc":"function call to [enif_is_port](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_port)","ref":"Beaver.ENIF.html#is_port/1"},{"type":"function","title":"Beaver.ENIF.is_port_alive/1","doc":"function call to [enif_is_port_alive](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_port_alive)","ref":"Beaver.ENIF.html#is_port_alive/1"},{"type":"function","title":"Beaver.ENIF.is_process_alive/1","doc":"function call to [enif_is_process_alive](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_process_alive)","ref":"Beaver.ENIF.html#is_process_alive/1"},{"type":"function","title":"Beaver.ENIF.is_ref/1","doc":"function call to [enif_is_ref](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_ref)","ref":"Beaver.ENIF.html#is_ref/1"},{"type":"function","title":"Beaver.ENIF.is_tuple/1","doc":"function call to [enif_is_tuple](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_tuple)","ref":"Beaver.ENIF.html#is_tuple/1"},{"type":"function","title":"Beaver.ENIF.keep_resource/1","doc":"function call to [enif_keep_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_keep_resource)","ref":"Beaver.ENIF.html#keep_resource/1"},{"type":"function","title":"Beaver.ENIF.make_atom/1","doc":"function call to [enif_make_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_atom)","ref":"Beaver.ENIF.html#make_atom/1"},{"type":"function","title":"Beaver.ENIF.make_atom_len/1","doc":"function call to [enif_make_atom_len](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_atom_len)","ref":"Beaver.ENIF.html#make_atom_len/1"},{"type":"function","title":"Beaver.ENIF.make_badarg/1","doc":"function call to [enif_make_badarg](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_badarg)","ref":"Beaver.ENIF.html#make_badarg/1"},{"type":"function","title":"Beaver.ENIF.make_binary/1","doc":"function call to [enif_make_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_binary)","ref":"Beaver.ENIF.html#make_binary/1"},{"type":"function","title":"Beaver.ENIF.make_copy/1","doc":"function call to [enif_make_copy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_copy)","ref":"Beaver.ENIF.html#make_copy/1"},{"type":"function","title":"Beaver.ENIF.make_double/1","doc":"function call to [enif_make_double](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_double)","ref":"Beaver.ENIF.html#make_double/1"},{"type":"function","title":"Beaver.ENIF.make_existing_atom/1","doc":"function call to [enif_make_existing_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_existing_atom)","ref":"Beaver.ENIF.html#make_existing_atom/1"},{"type":"function","title":"Beaver.ENIF.make_existing_atom_len/1","doc":"function call to [enif_make_existing_atom_len](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_existing_atom_len)","ref":"Beaver.ENIF.html#make_existing_atom_len/1"},{"type":"function","title":"Beaver.ENIF.make_int64/1","doc":"function call to [enif_make_int64](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_int64)","ref":"Beaver.ENIF.html#make_int64/1"},{"type":"function","title":"Beaver.ENIF.make_int/1","doc":"function call to [enif_make_int](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_int)","ref":"Beaver.ENIF.html#make_int/1"},{"type":"function","title":"Beaver.ENIF.make_list1/1","doc":"function call to [enif_make_list1](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list1)","ref":"Beaver.ENIF.html#make_list1/1"},{"type":"function","title":"Beaver.ENIF.make_list2/1","doc":"function call to [enif_make_list2](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list2)","ref":"Beaver.ENIF.html#make_list2/1"},{"type":"function","title":"Beaver.ENIF.make_list3/1","doc":"function call to [enif_make_list3](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list3)","ref":"Beaver.ENIF.html#make_list3/1"},{"type":"function","title":"Beaver.ENIF.make_list4/1","doc":"function call to [enif_make_list4](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list4)","ref":"Beaver.ENIF.html#make_list4/1"},{"type":"function","title":"Beaver.ENIF.make_list5/1","doc":"function call to [enif_make_list5](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list5)","ref":"Beaver.ENIF.html#make_list5/1"},{"type":"function","title":"Beaver.ENIF.make_list6/1","doc":"function call to [enif_make_list6](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list6)","ref":"Beaver.ENIF.html#make_list6/1"},{"type":"function","title":"Beaver.ENIF.make_list7/1","doc":"function call to [enif_make_list7](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list7)","ref":"Beaver.ENIF.html#make_list7/1"},{"type":"function","title":"Beaver.ENIF.make_list8/1","doc":"function call to [enif_make_list8](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list8)","ref":"Beaver.ENIF.html#make_list8/1"},{"type":"function","title":"Beaver.ENIF.make_list9/1","doc":"function call to [enif_make_list9](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list9)","ref":"Beaver.ENIF.html#make_list9/1"},{"type":"function","title":"Beaver.ENIF.make_list/1","doc":"function call to [enif_make_list](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list)","ref":"Beaver.ENIF.html#make_list/1"},{"type":"function","title":"Beaver.ENIF.make_list_cell/1","doc":"function call to [enif_make_list_cell](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list_cell)","ref":"Beaver.ENIF.html#make_list_cell/1"},{"type":"function","title":"Beaver.ENIF.make_list_from_array/1","doc":"function call to [enif_make_list_from_array](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list_from_array)","ref":"Beaver.ENIF.html#make_list_from_array/1"},{"type":"function","title":"Beaver.ENIF.make_long/1","doc":"function call to [enif_make_long](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_long)","ref":"Beaver.ENIF.html#make_long/1"},{"type":"function","title":"Beaver.ENIF.make_map_from_arrays/1","doc":"function call to [enif_make_map_from_arrays](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_map_from_arrays)","ref":"Beaver.ENIF.html#make_map_from_arrays/1"},{"type":"function","title":"Beaver.ENIF.make_map_put/1","doc":"function call to [enif_make_map_put](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_map_put)","ref":"Beaver.ENIF.html#make_map_put/1"},{"type":"function","title":"Beaver.ENIF.make_map_remove/1","doc":"function call to [enif_make_map_remove](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_map_remove)","ref":"Beaver.ENIF.html#make_map_remove/1"},{"type":"function","title":"Beaver.ENIF.make_map_update/1","doc":"function call to [enif_make_map_update](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_map_update)","ref":"Beaver.ENIF.html#make_map_update/1"},{"type":"function","title":"Beaver.ENIF.make_monitor_term/1","doc":"function call to [enif_make_monitor_term](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_monitor_term)","ref":"Beaver.ENIF.html#make_monitor_term/1"},{"type":"function","title":"Beaver.ENIF.make_new_atom/1","doc":"function call to [enif_make_new_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_new_atom)","ref":"Beaver.ENIF.html#make_new_atom/1"},{"type":"function","title":"Beaver.ENIF.make_new_atom_len/1","doc":"function call to [enif_make_new_atom_len](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_new_atom_len)","ref":"Beaver.ENIF.html#make_new_atom_len/1"},{"type":"function","title":"Beaver.ENIF.make_new_binary/1","doc":"function call to [enif_make_new_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_new_binary)","ref":"Beaver.ENIF.html#make_new_binary/1"},{"type":"function","title":"Beaver.ENIF.make_new_map/1","doc":"function call to [enif_make_new_map](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_new_map)","ref":"Beaver.ENIF.html#make_new_map/1"},{"type":"function","title":"Beaver.ENIF.make_ref/1","doc":"function call to [enif_make_ref](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_ref)","ref":"Beaver.ENIF.html#make_ref/1"},{"type":"function","title":"Beaver.ENIF.make_resource/1","doc":"function call to [enif_make_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_resource)","ref":"Beaver.ENIF.html#make_resource/1"},{"type":"function","title":"Beaver.ENIF.make_resource_binary/1","doc":"function call to [enif_make_resource_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_resource_binary)","ref":"Beaver.ENIF.html#make_resource_binary/1"},{"type":"function","title":"Beaver.ENIF.make_reverse_list/1","doc":"function call to [enif_make_reverse_list](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_reverse_list)","ref":"Beaver.ENIF.html#make_reverse_list/1"},{"type":"function","title":"Beaver.ENIF.make_string/1","doc":"function call to [enif_make_string](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_string)","ref":"Beaver.ENIF.html#make_string/1"},{"type":"function","title":"Beaver.ENIF.make_string_len/1","doc":"function call to [enif_make_string_len](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_string_len)","ref":"Beaver.ENIF.html#make_string_len/1"},{"type":"function","title":"Beaver.ENIF.make_sub_binary/1","doc":"function call to [enif_make_sub_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_sub_binary)","ref":"Beaver.ENIF.html#make_sub_binary/1"},{"type":"function","title":"Beaver.ENIF.make_tuple1/1","doc":"function call to [enif_make_tuple1](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple1)","ref":"Beaver.ENIF.html#make_tuple1/1"},{"type":"function","title":"Beaver.ENIF.make_tuple2/1","doc":"function call to [enif_make_tuple2](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple2)","ref":"Beaver.ENIF.html#make_tuple2/1"},{"type":"function","title":"Beaver.ENIF.make_tuple3/1","doc":"function call to [enif_make_tuple3](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple3)","ref":"Beaver.ENIF.html#make_tuple3/1"},{"type":"function","title":"Beaver.ENIF.make_tuple4/1","doc":"function call to [enif_make_tuple4](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple4)","ref":"Beaver.ENIF.html#make_tuple4/1"},{"type":"function","title":"Beaver.ENIF.make_tuple5/1","doc":"function call to [enif_make_tuple5](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple5)","ref":"Beaver.ENIF.html#make_tuple5/1"},{"type":"function","title":"Beaver.ENIF.make_tuple6/1","doc":"function call to [enif_make_tuple6](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple6)","ref":"Beaver.ENIF.html#make_tuple6/1"},{"type":"function","title":"Beaver.ENIF.make_tuple7/1","doc":"function call to [enif_make_tuple7](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple7)","ref":"Beaver.ENIF.html#make_tuple7/1"},{"type":"function","title":"Beaver.ENIF.make_tuple8/1","doc":"function call to [enif_make_tuple8](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple8)","ref":"Beaver.ENIF.html#make_tuple8/1"},{"type":"function","title":"Beaver.ENIF.make_tuple9/1","doc":"function call to [enif_make_tuple9](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple9)","ref":"Beaver.ENIF.html#make_tuple9/1"},{"type":"function","title":"Beaver.ENIF.make_tuple/1","doc":"function call to [enif_make_tuple](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple)","ref":"Beaver.ENIF.html#make_tuple/1"},{"type":"function","title":"Beaver.ENIF.make_tuple_from_array/1","doc":"function call to [enif_make_tuple_from_array](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple_from_array)","ref":"Beaver.ENIF.html#make_tuple_from_array/1"},{"type":"function","title":"Beaver.ENIF.make_uint64/1","doc":"function call to [enif_make_uint64](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_uint64)","ref":"Beaver.ENIF.html#make_uint64/1"},{"type":"function","title":"Beaver.ENIF.make_uint/1","doc":"function call to [enif_make_uint](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_uint)","ref":"Beaver.ENIF.html#make_uint/1"},{"type":"function","title":"Beaver.ENIF.make_ulong/1","doc":"function call to [enif_make_ulong](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_ulong)","ref":"Beaver.ENIF.html#make_ulong/1"},{"type":"function","title":"Beaver.ENIF.make_unique_integer/1","doc":"function call to [enif_make_unique_integer](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_unique_integer)","ref":"Beaver.ENIF.html#make_unique_integer/1"},{"type":"function","title":"Beaver.ENIF.map_iterator_create/1","doc":"function call to [enif_map_iterator_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_create)","ref":"Beaver.ENIF.html#map_iterator_create/1"},{"type":"function","title":"Beaver.ENIF.map_iterator_destroy/1","doc":"function call to [enif_map_iterator_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_destroy)","ref":"Beaver.ENIF.html#map_iterator_destroy/1"},{"type":"function","title":"Beaver.ENIF.map_iterator_get_pair/1","doc":"function call to [enif_map_iterator_get_pair](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_get_pair)","ref":"Beaver.ENIF.html#map_iterator_get_pair/1"},{"type":"function","title":"Beaver.ENIF.map_iterator_is_head/1","doc":"function call to [enif_map_iterator_is_head](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_is_head)","ref":"Beaver.ENIF.html#map_iterator_is_head/1"},{"type":"function","title":"Beaver.ENIF.map_iterator_is_tail/1","doc":"function call to [enif_map_iterator_is_tail](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_is_tail)","ref":"Beaver.ENIF.html#map_iterator_is_tail/1"},{"type":"function","title":"Beaver.ENIF.map_iterator_next/1","doc":"function call to [enif_map_iterator_next](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_next)","ref":"Beaver.ENIF.html#map_iterator_next/1"},{"type":"function","title":"Beaver.ENIF.map_iterator_prev/1","doc":"function call to [enif_map_iterator_prev](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_prev)","ref":"Beaver.ENIF.html#map_iterator_prev/1"},{"type":"function","title":"Beaver.ENIF.monitor_process/1","doc":"function call to [enif_monitor_process](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_monitor_process)","ref":"Beaver.ENIF.html#monitor_process/1"},{"type":"function","title":"Beaver.ENIF.monotonic_time/1","doc":"function call to [enif_monotonic_time](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_monotonic_time)","ref":"Beaver.ENIF.html#monotonic_time/1"},{"type":"function","title":"Beaver.ENIF.mutex_create/1","doc":"function call to [enif_mutex_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_create)","ref":"Beaver.ENIF.html#mutex_create/1"},{"type":"function","title":"Beaver.ENIF.mutex_destroy/1","doc":"function call to [enif_mutex_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_destroy)","ref":"Beaver.ENIF.html#mutex_destroy/1"},{"type":"function","title":"Beaver.ENIF.mutex_lock/1","doc":"function call to [enif_mutex_lock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_lock)","ref":"Beaver.ENIF.html#mutex_lock/1"},{"type":"function","title":"Beaver.ENIF.mutex_name/1","doc":"function call to [enif_mutex_name](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_name)","ref":"Beaver.ENIF.html#mutex_name/1"},{"type":"function","title":"Beaver.ENIF.mutex_trylock/1","doc":"function call to [enif_mutex_trylock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_trylock)","ref":"Beaver.ENIF.html#mutex_trylock/1"},{"type":"function","title":"Beaver.ENIF.mutex_unlock/1","doc":"function call to [enif_mutex_unlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_unlock)","ref":"Beaver.ENIF.html#mutex_unlock/1"},{"type":"function","title":"Beaver.ENIF.now_time/1","doc":"function call to [enif_now_time](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_now_time)","ref":"Beaver.ENIF.html#now_time/1"},{"type":"function","title":"Beaver.ENIF.open_resource_type/1","doc":"function call to [enif_open_resource_type](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_open_resource_type)","ref":"Beaver.ENIF.html#open_resource_type/1"},{"type":"function","title":"Beaver.ENIF.open_resource_type_x/1","doc":"function call to [enif_open_resource_type_x](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_open_resource_type_x)","ref":"Beaver.ENIF.html#open_resource_type_x/1"},{"type":"function","title":"Beaver.ENIF.port_command/1","doc":"function call to [enif_port_command](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_port_command)","ref":"Beaver.ENIF.html#port_command/1"},{"type":"function","title":"Beaver.ENIF.print_close/1","doc":"function call to print_close","ref":"Beaver.ENIF.html#print_close/1"},{"type":"function","title":"Beaver.ENIF.print_comma/1","doc":"function call to print_comma","ref":"Beaver.ENIF.html#print_comma/1"},{"type":"function","title":"Beaver.ENIF.print_f32/1","doc":"function call to print_f32","ref":"Beaver.ENIF.html#print_f32/1"},{"type":"function","title":"Beaver.ENIF.print_f64/1","doc":"function call to print_f64","ref":"Beaver.ENIF.html#print_f64/1"},{"type":"function","title":"Beaver.ENIF.print_i32/1","doc":"function call to print_i32","ref":"Beaver.ENIF.html#print_i32/1"},{"type":"function","title":"Beaver.ENIF.print_i64/1","doc":"function call to print_i64","ref":"Beaver.ENIF.html#print_i64/1"},{"type":"function","title":"Beaver.ENIF.print_newline/1","doc":"function call to print_newline","ref":"Beaver.ENIF.html#print_newline/1"},{"type":"function","title":"Beaver.ENIF.print_open/1","doc":"function call to print_open","ref":"Beaver.ENIF.html#print_open/1"},{"type":"function","title":"Beaver.ENIF.print_u32/1","doc":"function call to print_u32","ref":"Beaver.ENIF.html#print_u32/1"},{"type":"function","title":"Beaver.ENIF.print_u64/1","doc":"function call to print_u64","ref":"Beaver.ENIF.html#print_u64/1"},{"type":"function","title":"Beaver.ENIF.priv_data/1","doc":"function call to [enif_priv_data](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_priv_data)","ref":"Beaver.ENIF.html#priv_data/1"},{"type":"function","title":"Beaver.ENIF.ptr_to_memref/1","doc":"Convert a pointer to a memref\n\n`ptr_to_memref(ptr(), size()) :: memref<?xi8>`","ref":"Beaver.ENIF.html#ptr_to_memref/1"},{"type":"function","title":"Beaver.ENIF.raise_exception/1","doc":"function call to [enif_raise_exception](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_raise_exception)","ref":"Beaver.ENIF.html#raise_exception/1"},{"type":"function","title":"Beaver.ENIF.realloc/1","doc":"function call to [enif_realloc](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_realloc)","ref":"Beaver.ENIF.html#realloc/1"},{"type":"function","title":"Beaver.ENIF.realloc_binary/1","doc":"function call to [enif_realloc_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_realloc_binary)","ref":"Beaver.ENIF.html#realloc_binary/1"},{"type":"function","title":"Beaver.ENIF.register_symbols/1","doc":"","ref":"Beaver.ENIF.html#register_symbols/1"},{"type":"function","title":"Beaver.ENIF.release_binary/1","doc":"function call to [enif_release_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_release_binary)","ref":"Beaver.ENIF.html#release_binary/1"},{"type":"function","title":"Beaver.ENIF.release_resource/1","doc":"function call to [enif_release_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_release_resource)","ref":"Beaver.ENIF.html#release_resource/1"},{"type":"function","title":"Beaver.ENIF.rwlock_create/1","doc":"function call to [enif_rwlock_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_create)","ref":"Beaver.ENIF.html#rwlock_create/1"},{"type":"function","title":"Beaver.ENIF.rwlock_destroy/1","doc":"function call to [enif_rwlock_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_destroy)","ref":"Beaver.ENIF.html#rwlock_destroy/1"},{"type":"function","title":"Beaver.ENIF.rwlock_name/1","doc":"function call to [enif_rwlock_name](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_name)","ref":"Beaver.ENIF.html#rwlock_name/1"},{"type":"function","title":"Beaver.ENIF.rwlock_rlock/1","doc":"function call to [enif_rwlock_rlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_rlock)","ref":"Beaver.ENIF.html#rwlock_rlock/1"},{"type":"function","title":"Beaver.ENIF.rwlock_runlock/1","doc":"function call to [enif_rwlock_runlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_runlock)","ref":"Beaver.ENIF.html#rwlock_runlock/1"},{"type":"function","title":"Beaver.ENIF.rwlock_rwlock/1","doc":"function call to [enif_rwlock_rwlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_rwlock)","ref":"Beaver.ENIF.html#rwlock_rwlock/1"},{"type":"function","title":"Beaver.ENIF.rwlock_rwunlock/1","doc":"function call to [enif_rwlock_rwunlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_rwunlock)","ref":"Beaver.ENIF.html#rwlock_rwunlock/1"},{"type":"function","title":"Beaver.ENIF.rwlock_tryrlock/1","doc":"function call to [enif_rwlock_tryrlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_tryrlock)","ref":"Beaver.ENIF.html#rwlock_tryrlock/1"},{"type":"function","title":"Beaver.ENIF.rwlock_tryrwlock/1","doc":"function call to [enif_rwlock_tryrwlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_tryrwlock)","ref":"Beaver.ENIF.html#rwlock_tryrwlock/1"},{"type":"function","title":"Beaver.ENIF.schedule_nif/1","doc":"function call to [enif_schedule_nif](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_schedule_nif)","ref":"Beaver.ENIF.html#schedule_nif/1"},{"type":"function","title":"Beaver.ENIF.select/1","doc":"function call to [enif_select](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_select)","ref":"Beaver.ENIF.html#select/1"},{"type":"function","title":"Beaver.ENIF.self/1","doc":"function call to [enif_self](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_self)","ref":"Beaver.ENIF.html#self/1"},{"type":"function","title":"Beaver.ENIF.send/1","doc":"function call to [enif_send](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_send)","ref":"Beaver.ENIF.html#send/1"},{"type":"function","title":"Beaver.ENIF.set_option/1","doc":"function call to [enif_set_option](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_set_option)","ref":"Beaver.ENIF.html#set_option/1"},{"type":"function","title":"Beaver.ENIF.set_pid_undefined/1","doc":"function call to [enif_set_pid_undefined](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_set_pid_undefined)","ref":"Beaver.ENIF.html#set_pid_undefined/1"},{"type":"function","title":"Beaver.ENIF.signature/2","doc":"Query the signature of an ENIF function.","ref":"Beaver.ENIF.html#signature/2"},{"type":"function","title":"Beaver.ENIF.signatures/1","doc":"Retrieve the signatures of all available ENIF functions.","ref":"Beaver.ENIF.html#signatures/1"},{"type":"function","title":"Beaver.ENIF.sizeof_resource/1","doc":"function call to [enif_sizeof_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_sizeof_resource)","ref":"Beaver.ENIF.html#sizeof_resource/1"},{"type":"function","title":"Beaver.ENIF.snprintf/1","doc":"function call to [enif_snprintf](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_snprintf)","ref":"Beaver.ENIF.html#snprintf/1"},{"type":"function","title":"Beaver.ENIF.system_info/1","doc":"function call to [enif_system_info](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_system_info)","ref":"Beaver.ENIF.html#system_info/1"},{"type":"function","title":"Beaver.ENIF.term_to_binary/1","doc":"function call to [enif_term_to_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_term_to_binary)","ref":"Beaver.ENIF.html#term_to_binary/1"},{"type":"function","title":"Beaver.ENIF.term_type/1","doc":"function call to [enif_term_type](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_term_type)","ref":"Beaver.ENIF.html#term_type/1"},{"type":"function","title":"Beaver.ENIF.thread_create/1","doc":"function call to [enif_thread_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_create)","ref":"Beaver.ENIF.html#thread_create/1"},{"type":"function","title":"Beaver.ENIF.thread_exit/1","doc":"function call to [enif_thread_exit](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_exit)","ref":"Beaver.ENIF.html#thread_exit/1"},{"type":"function","title":"Beaver.ENIF.thread_join/1","doc":"function call to [enif_thread_join](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_join)","ref":"Beaver.ENIF.html#thread_join/1"},{"type":"function","title":"Beaver.ENIF.thread_name/1","doc":"function call to [enif_thread_name](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_name)","ref":"Beaver.ENIF.html#thread_name/1"},{"type":"function","title":"Beaver.ENIF.thread_opts_create/1","doc":"function call to [enif_thread_opts_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_opts_create)","ref":"Beaver.ENIF.html#thread_opts_create/1"},{"type":"function","title":"Beaver.ENIF.thread_opts_destroy/1","doc":"function call to [enif_thread_opts_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_opts_destroy)","ref":"Beaver.ENIF.html#thread_opts_destroy/1"},{"type":"function","title":"Beaver.ENIF.thread_self/1","doc":"function call to [enif_thread_self](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_self)","ref":"Beaver.ENIF.html#thread_self/1"},{"type":"function","title":"Beaver.ENIF.thread_type/1","doc":"function call to [enif_thread_type](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_type)","ref":"Beaver.ENIF.html#thread_type/1"},{"type":"function","title":"Beaver.ENIF.time_offset/1","doc":"function call to [enif_time_offset](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_time_offset)","ref":"Beaver.ENIF.html#time_offset/1"},{"type":"function","title":"Beaver.ENIF.tsd_get/1","doc":"function call to [enif_tsd_get](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_tsd_get)","ref":"Beaver.ENIF.html#tsd_get/1"},{"type":"function","title":"Beaver.ENIF.tsd_key_create/1","doc":"function call to [enif_tsd_key_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_tsd_key_create)","ref":"Beaver.ENIF.html#tsd_key_create/1"},{"type":"function","title":"Beaver.ENIF.tsd_key_destroy/1","doc":"function call to [enif_tsd_key_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_tsd_key_destroy)","ref":"Beaver.ENIF.html#tsd_key_destroy/1"},{"type":"function","title":"Beaver.ENIF.tsd_set/1","doc":"function call to [enif_tsd_set](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_tsd_set)","ref":"Beaver.ENIF.html#tsd_set/1"},{"type":"function","title":"Beaver.ENIF.vfprintf/1","doc":"function call to [enif_vfprintf](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_vfprintf)","ref":"Beaver.ENIF.html#vfprintf/1"},{"type":"function","title":"Beaver.ENIF.vsnprintf/1","doc":"function call to [enif_vsnprintf](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_vsnprintf)","ref":"Beaver.ENIF.html#vsnprintf/1"},{"type":"function","title":"Beaver.ENIF.whereis_pid/1","doc":"function call to [enif_whereis_pid](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_whereis_pid)","ref":"Beaver.ENIF.html#whereis_pid/1"},{"type":"function","title":"Beaver.ENIF.whereis_port/1","doc":"function call to [enif_whereis_port](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_whereis_port)","ref":"Beaver.ENIF.html#whereis_port/1"},{"type":"module","title":"Beaver.ENIF.Type","doc":"Query the MLIR type of an Erlang term or environment.","ref":"Beaver.ENIF.Type.html"},{"type":"function","title":"Beaver.ENIF.Type.binary/1","doc":"","ref":"Beaver.ENIF.Type.html#binary/1"},{"type":"function","title":"Beaver.ENIF.Type.env/1","doc":"","ref":"Beaver.ENIF.Type.html#env/1"},{"type":"function","title":"Beaver.ENIF.Type.term/1","doc":"","ref":"Beaver.ENIF.Type.html#term/1"},{"type":"type","title":"Beaver.ENIF.Type.signature/0","doc":"A tuple representing the signature of an enif function.\nEach tuple contains:\n- The name of the function, which is an atom.\n- A list of argument MLIR types.\n- A list of return MLIR types.","ref":"Beaver.ENIF.Type.html#t:signature/0"},{"type":"behaviour","title":"Beaver.MLIR.Dialect","doc":"This module defines macro to generate code for an MLIR dialect.\nYou might override `eval_ssa/1` function to introduce your custom op generation","ref":"Beaver.MLIR.Dialect.html"},{"type":"macro","title":"Beaver.MLIR.Dialect.define_modules/1","doc":"","ref":"Beaver.MLIR.Dialect.html#define_modules/1"},{"type":"callback","title":"Beaver.MLIR.Dialect.eval_ssa/1","doc":"","ref":"Beaver.MLIR.Dialect.html#c:eval_ssa/1"},{"type":"function","title":"Beaver.MLIR.Dialect.make/1","doc":"","ref":"Beaver.MLIR.Dialect.html#make/1"},{"type":"type","title":"Beaver.MLIR.Dialect.t/0","doc":"","ref":"Beaver.MLIR.Dialect.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Dialect.Arith","doc":"This module defines functions for Ops in Arith dialect.","ref":"Beaver.MLIR.Dialect.Arith.html"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.addf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#addf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.addi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#addi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.addui_extended/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#addui_extended/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.andi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#andi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.bitcast/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#bitcast/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.ceildivsi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#ceildivsi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.ceildivui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#ceildivui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.cmp_f_predicate/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#cmp_f_predicate/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.cmp_i_predicate/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#cmp_i_predicate/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.cmpf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#cmpf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.cmpi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#cmpi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.constant/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#constant/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.divf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#divf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.divsi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#divsi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.divui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#divui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.extf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#extf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.extsi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#extsi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.extui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#extui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.floordivsi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#floordivsi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.fptosi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#fptosi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.fptoui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#fptoui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.index_cast/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#index_cast/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.index_castui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#index_castui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.maximumf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#maximumf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.maxnumf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#maxnumf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.maxsi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#maxsi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.maxui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#maxui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.minimumf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#minimumf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.minnumf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#minnumf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.minsi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#minsi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.minui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#minui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.mulf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#mulf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.muli/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#muli/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.mulsi_extended/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#mulsi_extended/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.mului_extended/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#mului_extended/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.negf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#negf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.ori/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#ori/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.remf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#remf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.remsi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#remsi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.remui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#remui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.select/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#select/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.shli/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#shli/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.shrsi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#shrsi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.shrui/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#shrui/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.sitofp/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#sitofp/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.subf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#subf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.subi/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#subi/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.truncf/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#truncf/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.trunci/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#trunci/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.uitofp/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#uitofp/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Arith.xori/1","doc":"","ref":"Beaver.MLIR.Dialect.Arith.html#xori/1"},{"type":"module","title":"Beaver.MLIR.Dialect.Builtin","doc":"This module defines functions for Ops in Builtin dialect.","ref":"Beaver.MLIR.Dialect.Builtin.html"},{"type":"macro","title":"Beaver.MLIR.Dialect.Builtin.module/2","doc":"Macro to create a module and insert ops into its body. Beaver.region/1 shouldn't be called because module's one-block region will be created.","ref":"Beaver.MLIR.Dialect.Builtin.html#module/2"},{"type":"function","title":"Beaver.MLIR.Dialect.Builtin.unrealized_conversion_cast/1","doc":"","ref":"Beaver.MLIR.Dialect.Builtin.html#unrealized_conversion_cast/1"},{"type":"module","title":"Beaver.MLIR.Dialect.CF","doc":"This module defines functions for Ops in CF dialect.","ref":"Beaver.MLIR.Dialect.CF.html"},{"type":"function","title":"Beaver.MLIR.Dialect.CF.assert/1","doc":"","ref":"Beaver.MLIR.Dialect.CF.html#assert/1"},{"type":"function","title":"Beaver.MLIR.Dialect.CF.br/1","doc":"","ref":"Beaver.MLIR.Dialect.CF.html#br/1"},{"type":"function","title":"Beaver.MLIR.Dialect.CF.cond_br/1","doc":"Create cf.cond_br op. Passing atom will lead to defer the creation of this terminator.","ref":"Beaver.MLIR.Dialect.CF.html#cond_br/1"},{"type":"function","title":"Beaver.MLIR.Dialect.CF.switch/1","doc":"","ref":"Beaver.MLIR.Dialect.CF.html#switch/1"},{"type":"module","title":"Beaver.MLIR.Dialect.Elixir","doc":"","ref":"Beaver.MLIR.Dialect.Elixir.html"},{"type":"function","title":"Beaver.MLIR.Dialect.Elixir.add/1","doc":"","ref":"Beaver.MLIR.Dialect.Elixir.html#add/1"},{"type":"module","title":"Beaver.MLIR.Dialect.Func","doc":"This module defines functions for Ops in Func dialect.","ref":"Beaver.MLIR.Dialect.Func.html"},{"type":"function","title":"Beaver.MLIR.Dialect.Func.call/1","doc":"","ref":"Beaver.MLIR.Dialect.Func.html#call/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Func.call_indirect/1","doc":"","ref":"Beaver.MLIR.Dialect.Func.html#call_indirect/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Func.constant/1","doc":"","ref":"Beaver.MLIR.Dialect.Func.html#constant/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Func.func/1","doc":"","ref":"Beaver.MLIR.Dialect.Func.html#func/1"},{"type":"macro","title":"Beaver.MLIR.Dialect.Func.func/2","doc":"","ref":"Beaver.MLIR.Dialect.Func.html#func/2"},{"type":"function","title":"Beaver.MLIR.Dialect.Func.is_external/1","doc":"","ref":"Beaver.MLIR.Dialect.Func.html#is_external/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Func.return/1","doc":"","ref":"Beaver.MLIR.Dialect.Func.html#return/1"},{"type":"module","title":"Beaver.MLIR.Dialect.MemRef","doc":"This module defines functions for Ops in MemRef dialect.","ref":"Beaver.MLIR.Dialect.MemRef.html"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.alloc/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#alloc/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.alloca/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#alloca/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.alloca_scope/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#alloca_scope/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.alloca_scope_return/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#alloca_scope_return/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.assume_alignment/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#assume_alignment/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.atomic_rmw/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#atomic_rmw/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.atomic_yield/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#atomic_yield/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.cast/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#cast/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.collapse_shape/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#collapse_shape/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.copy/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#copy/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.dealloc/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#dealloc/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.dim/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#dim/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.dma_start/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#dma_start/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.dma_wait/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#dma_wait/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.expand_shape/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#expand_shape/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.extract_aligned_pointer_as_index/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#extract_aligned_pointer_as_index/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.extract_strided_metadata/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#extract_strided_metadata/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.generic_atomic_rmw/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#generic_atomic_rmw/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.get_global/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#get_global/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.global/1","doc":"Create a global.","ref":"Beaver.MLIR.Dialect.MemRef.html#global/1"},{"type":"function","title":"Special arguments - Beaver.MLIR.Dialect.MemRef.global/1","doc":"- `global(binary(), {[:i | :f], [8 | 16 | 32 | 64 | 128]})`: To to serialize a binary to MLIR. By default, it will be a `memref<[byte size]*i8>`.","ref":"Beaver.MLIR.Dialect.MemRef.html#global/1-special-arguments"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.load/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#load/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.memory_space_cast/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#memory_space_cast/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.prefetch/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#prefetch/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.rank/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#rank/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.realloc/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#realloc/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.reinterpret_cast/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#reinterpret_cast/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.reshape/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#reshape/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.store/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#store/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.subview/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#subview/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.transpose/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#transpose/1"},{"type":"function","title":"Beaver.MLIR.Dialect.MemRef.view/1","doc":"","ref":"Beaver.MLIR.Dialect.MemRef.html#view/1"},{"type":"module","title":"Beaver.MLIR.Dialect.Registry","doc":"This module defines functions to query MLIR dialect registry.","ref":"Beaver.MLIR.Dialect.Registry.html"},{"type":"function","title":"Beaver.MLIR.Dialect.Registry.dialects/1","doc":"Get dialects registered","ref":"Beaver.MLIR.Dialect.Registry.html#dialects/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Registry.normalize_dialect_name/1","doc":"","ref":"Beaver.MLIR.Dialect.Registry.html#normalize_dialect_name/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Registry.normalize_op_name/1","doc":"","ref":"Beaver.MLIR.Dialect.Registry.html#normalize_op_name/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Registry.ops/2","doc":"","ref":"Beaver.MLIR.Dialect.Registry.html#ops/2"},{"type":"module","title":"Beaver.MLIR.Dialect.Tensor","doc":"This module defines functions for Ops in Tensor dialect.","ref":"Beaver.MLIR.Dialect.Tensor.html"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.bitcast/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#bitcast/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.cast/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#cast/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.collapse_shape/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#collapse_shape/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.concat/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#concat/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.dim/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#dim/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.empty/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#empty/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.expand_shape/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#expand_shape/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.extract/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#extract/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.extract_slice/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#extract_slice/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.from_elements/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#from_elements/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.gather/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#gather/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.generate/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#generate/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.insert/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#insert/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.insert_slice/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#insert_slice/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.pack/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#pack/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.pad/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#pad/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.parallel_insert_slice/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#parallel_insert_slice/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.rank/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#rank/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.reassociation/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#reassociation/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.reassociation_for_reshape/2","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#reassociation_for_reshape/2"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.reshape/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#reshape/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.scatter/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#scatter/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.splat/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#splat/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.unpack/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#unpack/1"},{"type":"function","title":"Beaver.MLIR.Dialect.Tensor.yield/1","doc":"","ref":"Beaver.MLIR.Dialect.Tensor.html#yield/1"},{"type":"module","title":"Beaver.MLIR.DialectHandle","doc":"","ref":"Beaver.MLIR.DialectHandle.html"},{"type":"function","title":"Beaver.MLIR.DialectHandle.make/1","doc":"","ref":"Beaver.MLIR.DialectHandle.html#make/1"},{"type":"type","title":"Beaver.MLIR.DialectHandle.t/0","doc":"","ref":"Beaver.MLIR.DialectHandle.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.DialectRegistry","doc":"","ref":"Beaver.MLIR.DialectRegistry.html"},{"type":"function","title":"Beaver.MLIR.DialectRegistry.make/1","doc":"","ref":"Beaver.MLIR.DialectRegistry.html#make/1"},{"type":"type","title":"Beaver.MLIR.DialectRegistry.t/0","doc":"","ref":"Beaver.MLIR.DialectRegistry.html#t:t/0"},{"type":"module","title":"Beaver.MLIR","doc":"This module provides functions to dump MLIR elements or print them to Elixir string.","ref":"Beaver.MLIR.html"},{"type":"function","title":"Beaver.MLIR.dump/2","doc":"","ref":"Beaver.MLIR.html#dump/2"},{"type":"function","title":"Beaver.MLIR.dump!/2","doc":"","ref":"Beaver.MLIR.html#dump!/2"},{"type":"function","title":"Beaver.MLIR.equal?/2","doc":"","ref":"Beaver.MLIR.html#equal?/2"},{"type":"function","title":"Beaver.MLIR.is_null/1","doc":"","ref":"Beaver.MLIR.html#is_null/1"},{"type":"function","title":"Beaver.MLIR.to_string/2","doc":"Print MLIR element as Elixir binary string. When printing an operation, it is recommended to use `generic: false` or `generic: true` to explicitly specify the format if your usage requires consistent output. If not specified, the default behavior is subject to change according to the MLIR version.","ref":"Beaver.MLIR.html#to_string/2"},{"type":"type","title":"Beaver.MLIR.dump_opts/0","doc":"","ref":"Beaver.MLIR.html#t:dump_opts/0"},{"type":"type","title":"Beaver.MLIR.nullable/0","doc":"","ref":"Beaver.MLIR.html#t:nullable/0"},{"type":"type","title":"Beaver.MLIR.printable/0","doc":"","ref":"Beaver.MLIR.html#t:printable/0"},{"type":"module","title":"Beaver.MLIR.AffineExpr","doc":"","ref":"Beaver.MLIR.AffineExpr.html"},{"type":"function","title":"Beaver.MLIR.AffineExpr.make/1","doc":"","ref":"Beaver.MLIR.AffineExpr.html#make/1"},{"type":"type","title":"Beaver.MLIR.AffineExpr.t/0","doc":"","ref":"Beaver.MLIR.AffineExpr.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.AffineMap","doc":"This module defines functions working with MLIR AffineMap.","ref":"Beaver.MLIR.AffineMap.html"},{"type":"function","title":"Beaver.MLIR.AffineMap.create/4","doc":"","ref":"Beaver.MLIR.AffineMap.html#create/4"},{"type":"function","title":"Beaver.MLIR.AffineMap.dim/2","doc":"","ref":"Beaver.MLIR.AffineMap.html#dim/2"},{"type":"function","title":"Beaver.MLIR.AffineMap.make/1","doc":"","ref":"Beaver.MLIR.AffineMap.html#make/1"},{"type":"function","title":"Beaver.MLIR.AffineMap.symbol/2","doc":"","ref":"Beaver.MLIR.AffineMap.html#symbol/2"},{"type":"type","title":"Beaver.MLIR.AffineMap.t/0","doc":"","ref":"Beaver.MLIR.AffineMap.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.AsmState","doc":"","ref":"Beaver.MLIR.AsmState.html"},{"type":"function","title":"Beaver.MLIR.AsmState.make/1","doc":"","ref":"Beaver.MLIR.AsmState.html#make/1"},{"type":"type","title":"Beaver.MLIR.AsmState.t/0","doc":"","ref":"Beaver.MLIR.AsmState.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Attribute","doc":"This module defines functions parsing and creating attributes in MLIR.","ref":"Beaver.MLIR.Attribute.html"},{"type":"function","title":"Beaver.MLIR.Attribute.affine_map/1","doc":"","ref":"Beaver.MLIR.Attribute.html#affine_map/1"},{"type":"function","title":"Beaver.MLIR.Attribute.array/2","doc":"","ref":"Beaver.MLIR.Attribute.html#array/2"},{"type":"function","title":"Beaver.MLIR.Attribute.bool/2","doc":"","ref":"Beaver.MLIR.Attribute.html#bool/2"},{"type":"function","title":"Beaver.MLIR.Attribute.dense_array/3","doc":"","ref":"Beaver.MLIR.Attribute.html#dense_array/3"},{"type":"function","title":"Beaver.MLIR.Attribute.dense_elements/3","doc":"","ref":"Beaver.MLIR.Attribute.html#dense_elements/3"},{"type":"function","title":"Beaver.MLIR.Attribute.equal?/2","doc":"","ref":"Beaver.MLIR.Attribute.html#equal?/2"},{"type":"function","title":"Beaver.MLIR.Attribute.flat_symbol_ref/2","doc":"","ref":"Beaver.MLIR.Attribute.html#flat_symbol_ref/2"},{"type":"function","title":"Beaver.MLIR.Attribute.float/3","doc":"","ref":"Beaver.MLIR.Attribute.html#float/3"},{"type":"function","title":"Beaver.MLIR.Attribute.get/2","doc":"","ref":"Beaver.MLIR.Attribute.html#get/2"},{"type":"function","title":"Beaver.MLIR.Attribute.index/2","doc":"","ref":"Beaver.MLIR.Attribute.html#index/2"},{"type":"function","title":"Beaver.MLIR.Attribute.integer/2","doc":"","ref":"Beaver.MLIR.Attribute.html#integer/2"},{"type":"function","title":"Beaver.MLIR.Attribute.is_null/1","doc":"","ref":"Beaver.MLIR.Attribute.html#is_null/1"},{"type":"function","title":"Beaver.MLIR.Attribute.make/1","doc":"","ref":"Beaver.MLIR.Attribute.html#make/1"},{"type":"function","title":"Beaver.MLIR.Attribute.null/0","doc":"","ref":"Beaver.MLIR.Attribute.html#null/0"},{"type":"function","title":"Beaver.MLIR.Attribute.string/2","doc":"","ref":"Beaver.MLIR.Attribute.html#string/2"},{"type":"function","title":"Beaver.MLIR.Attribute.symbol_ref/3","doc":"","ref":"Beaver.MLIR.Attribute.html#symbol_ref/3"},{"type":"function","title":"Beaver.MLIR.Attribute.type/1","doc":"","ref":"Beaver.MLIR.Attribute.html#type/1"},{"type":"function","title":"Beaver.MLIR.Attribute.unit/1","doc":"","ref":"Beaver.MLIR.Attribute.html#unit/1"},{"type":"function","title":"Beaver.MLIR.Attribute.unwrap/1","doc":"","ref":"Beaver.MLIR.Attribute.html#unwrap/1"},{"type":"function","title":"Beaver.MLIR.Attribute.unwrap_string/1","doc":"","ref":"Beaver.MLIR.Attribute.html#unwrap_string/1"},{"type":"function","title":"Beaver.MLIR.Attribute.unwrap_type/1","doc":"","ref":"Beaver.MLIR.Attribute.html#unwrap_type/1"},{"type":"type","title":"Beaver.MLIR.Attribute.t/0","doc":"","ref":"Beaver.MLIR.Attribute.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Block","doc":"This module defines functions working with MLIR Block.","ref":"Beaver.MLIR.Block.html"},{"type":"function","title":"Beaver.MLIR.Block.add_args!/3","doc":"add arguments to a block","ref":"Beaver.MLIR.Block.html#add_args!/3"},{"type":"function","title":"Beaver.MLIR.Block.create/1","doc":"","ref":"Beaver.MLIR.Block.html#create/1"},{"type":"function","title":"Beaver.MLIR.Block.create/2","doc":"","ref":"Beaver.MLIR.Block.html#create/2"},{"type":"function","title":"Beaver.MLIR.Block.get_arg!/2","doc":"","ref":"Beaver.MLIR.Block.html#get_arg!/2"},{"type":"function","title":"Beaver.MLIR.Block.make/1","doc":"","ref":"Beaver.MLIR.Block.html#make/1"},{"type":"type","title":"Beaver.MLIR.Block.arg/0","doc":"","ref":"Beaver.MLIR.Block.html#t:arg/0"},{"type":"type","title":"Beaver.MLIR.Block.arg_type/0","doc":"","ref":"Beaver.MLIR.Block.html#t:arg_type/0"},{"type":"type","title":"Beaver.MLIR.Block.t/0","doc":"","ref":"Beaver.MLIR.Block.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.BytecodeWriterConfig","doc":"","ref":"Beaver.MLIR.BytecodeWriterConfig.html"},{"type":"function","title":"Beaver.MLIR.BytecodeWriterConfig.make/1","doc":"","ref":"Beaver.MLIR.BytecodeWriterConfig.html#make/1"},{"type":"type","title":"Beaver.MLIR.BytecodeWriterConfig.t/0","doc":"","ref":"Beaver.MLIR.BytecodeWriterConfig.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.CAPI","doc":"This module ships MLIR's C API. These NIFs are generated from headers in LLVM repo and this repo's headers providing supplemental functions.","ref":"Beaver.MLIR.CAPI.html"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_context_attach_diagnostic_handler/2","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_context_attach_diagnostic_handler/2"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_create_mlir_pass/5","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_create_mlir_pass/5"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_deallocate_opaque_ptr/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_deallocate_opaque_ptr/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_enif_functions/0","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_enif_functions/0"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_enif_signatures/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_enif_signatures/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_get_diagnostic_string_callback/0","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_get_diagnostic_string_callback/0"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_get_null_ptr/0","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_get_null_ptr/0"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_get_string_ref/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_get_string_ref/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_jit_invoke_with_terms/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_jit_invoke_with_terms/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_jit_invoke_with_terms_cpu_bound/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_jit_invoke_with_terms_cpu_bound/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_jit_invoke_with_terms_io_bound/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_jit_invoke_with_terms_io_bound/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_jit_register_enif/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_jit_register_enif/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_mlir_type_of_enif_obj/2","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_mlir_type_of_enif_obj/2"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_pass_token_signal/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_pass_token_signal/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_read_opaque_ptr/2","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_read_opaque_ptr/2"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_registered_dialects/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_registered_dialects/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_registered_ops/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_registered_ops/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_string_ref_to_binary/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_string_ref_to_binary/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_affine_map/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_affine_map/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_attribute/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_attribute/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_location/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_location/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_operation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_operation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_operation_bytecode/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_operation_bytecode/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_operation_generic/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_operation_generic/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_operation_specialized/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_operation_specialized/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_pm/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_pm/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_type/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_type/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_value/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_value/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverContextEnterMultiThreadedExecution/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverContextEnterMultiThreadedExecution/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverContextExitMultiThreadedExecution/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverContextExitMultiThreadedExecution/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverContextGetDialects/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverContextGetDialects/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverContextGetOps/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverContextGetOps/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverGetReassociationIndicesForReshape/2","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverGetReassociationIndicesForReshape/2"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIRDLGetDefinedAttr/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIRDLGetDefinedAttr/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIRDLGetDefinedType/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIRDLGetDefinedType/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullAttribute/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullAttribute/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullBlock/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullBlock/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullDialect/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullDialect/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullDialectRegistry/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullDialectRegistry/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullExecutionEngine/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullExecutionEngine/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullLocation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullLocation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullModule/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullModule/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullOperation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullOperation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullRegion/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullRegion/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullSymbolTable/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullSymbolTable/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsNullValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsNullValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverIsOpNameTerminator/2","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverIsOpNameTerminator/2"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverLocationPrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverLocationPrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverLogicalResultFailure/0","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverLogicalResultFailure/0"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverLogicalResultIsFailure/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverLogicalResultIsFailure/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverLogicalResultIsSuccess/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverLogicalResultIsSuccess/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverLogicalResultSuccess/0","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverLogicalResultSuccess/0"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverModuleApplyPatternsAndFoldGreedily/2","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverModuleApplyPatternsAndFoldGreedily/2"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverNamedAttributeGetAttribute/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverNamedAttributeGetAttribute/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverNamedAttributeGetName/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverNamedAttributeGetName/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationDumpGeneric/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationDumpGeneric/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationGetAttribute/2","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationGetAttribute/2"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationGetName/2","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationGetName/2"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationPrintGenericOpForm/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationPrintGenericOpForm/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationPrintSpecializedFrom/3","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationPrintSpecializedFrom/3"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationStateGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationStateGetLocation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetLocation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationStateGetName/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetName/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationStateGetNumAttributes/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetNumAttributes/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationStateGetNumOperands/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetNumOperands/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationStateGetNumRegions/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetNumRegions/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverOperationStateGetNumResults/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetNumResults/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverPassCreate/13","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverPassCreate/13"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverPassGetArgument/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverPassGetArgument/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverPassGetDescription/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverPassGetDescription/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverPassGetName/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverPassGetName/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverPassManagerEnableTiming/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverPassManagerEnableTiming/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverPassManagerGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverPassManagerGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverStringRefGetData/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverStringRefGetData/1"},{"type":"function","title":"Beaver.MLIR.CAPI.beaverStringRefGetLength/1","doc":"","ref":"Beaver.MLIR.CAPI.html#beaverStringRefGetLength/1"},{"type":"function","title":"Beaver.MLIR.CAPI.load_nif/0","doc":"","ref":"Beaver.MLIR.CAPI.html#load_nif/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineAddExprGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineAddExprGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineBinaryOpExprGetLHS/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineBinaryOpExprGetLHS/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineBinaryOpExprGetRHS/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineBinaryOpExprGetRHS/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineCeilDivExprGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineCeilDivExprGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineConstantExprGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineConstantExprGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineConstantExprGetValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineConstantExprGetValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineDimExprGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineDimExprGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineDimExprGetPosition/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineDimExprGetPosition/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprCompose/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprCompose/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprDump/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprDump/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprGetLargestKnownDivisor/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprGetLargestKnownDivisor/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAAdd/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAAdd/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsABinary/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsABinary/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsACeilDiv/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsACeilDiv/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAConstant/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAConstant/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsADim/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsADim/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAFloorDiv/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAFloorDiv/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAMod/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAMod/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAMul/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAMul/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsASymbol/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsASymbol/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsFunctionOfDim/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsFunctionOfDim/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsMultipleOf/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsMultipleOf/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsPureAffine/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsPureAffine/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprIsSymbolicOrConstant/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsSymbolicOrConstant/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineExprPrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprPrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineFloorDivExprGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineFloorDivExprGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapAttrGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapAttrGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapAttrGetValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapAttrGetValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapCompressUnusedSymbols/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapCompressUnusedSymbols/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapConstantGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapConstantGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapDump/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapDump/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapEmptyGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapEmptyGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetMajorSubMap/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetMajorSubMap/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetMinorSubMap/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetMinorSubMap/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetNumDims/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetNumDims/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetNumInputs/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetNumInputs/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetNumResults/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetNumResults/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetNumSymbols/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetNumSymbols/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetResult/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetResult/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetSingleConstantResult/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetSingleConstantResult/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapGetSubMap/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetSubMap/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapIsEmpty/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsEmpty/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapIsIdentity/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsIdentity/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapIsMinorIdentity/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsMinorIdentity/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapIsPermutation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsPermutation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapIsProjectedPermutation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsProjectedPermutation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapIsSingleConstant/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsSingleConstant/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapMinorIdentityGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapMinorIdentityGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapMultiDimIdentityGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapMultiDimIdentityGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapPermutationGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapPermutationGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapPrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapPrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapReplace/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapReplace/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMapZeroResultGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapZeroResultGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineModExprGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineModExprGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineMulExprGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineMulExprGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineSymbolExprGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineSymbolExprGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAffineSymbolExprGetPosition/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAffineSymbolExprGetPosition/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAnyQuantizedTypeGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAnyQuantizedTypeGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirApplyPatternsAndFoldGreedily/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirApplyPatternsAndFoldGreedily/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirArrayAttrGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirArrayAttrGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirArrayAttrGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirArrayAttrGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirArrayAttrGetNumElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirArrayAttrGetNumElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirArrayAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirArrayAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAsmStateCreateForOperation/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAsmStateCreateForOperation/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAsmStateCreateForValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAsmStateCreateForValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAsmStateDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAsmStateDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeDump/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeDump/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeGetDialect/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetDialect/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeGetNull/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetNull/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeGetType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeGetTypeID/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetTypeID/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAAffineMap/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAAffineMap/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAArray/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAArray/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsABool/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsABool/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseBoolArray/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseBoolArray/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseF32Array/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseF32Array/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseF64Array/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseF64Array/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseFPElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseFPElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseI8Array/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseI8Array/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseI16Array/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseI16Array/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseI32Array/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseI32Array/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseI64Array/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseI64Array/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseIntElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseIntElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseResourceElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseResourceElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsADictionary/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADictionary/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAFlatSymbolRef/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAFlatSymbolRef/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAFloat/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAFloat/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAGPUObjectAttr/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAGPUObjectAttr/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAInteger/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAInteger/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAIntegerSet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAIntegerSet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsALocation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsALocation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAOpaque/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAOpaque/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsASparseElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsASparseElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsASparseTensorEncodingAttr/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsASparseTensorEncodingAttr/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAStridedLayout/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAStridedLayout/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAString/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAString/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsASymbolRef/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsASymbolRef/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeIsAUnit/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAUnit/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributeParseGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributeParseGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirAttributePrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirAttributePrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBF16TypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBF16TypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBFloat16TypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBFloat16TypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockAddArgument/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockAddArgument/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockAppendOwnedOperation/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockAppendOwnedOperation/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockArgumentGetArgNumber/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockArgumentGetArgNumber/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockArgumentGetOwner/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockArgumentGetOwner/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockArgumentSetType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockArgumentSetType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockCreate/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockCreate/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockDetach/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockDetach/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockEraseArgument/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockEraseArgument/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockGetArgument/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetArgument/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockGetFirstOperation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetFirstOperation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockGetNextInRegion/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetNextInRegion/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockGetNumArguments/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetNumArguments/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockGetParentOperation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetParentOperation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockGetParentRegion/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetParentRegion/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockGetTerminator/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetTerminator/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockInsertArgument/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockInsertArgument/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockInsertOwnedOperation/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockInsertOwnedOperation/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockInsertOwnedOperationAfter/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockInsertOwnedOperationAfter/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockInsertOwnedOperationBefore/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockInsertOwnedOperationBefore/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBlockPrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBlockPrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBoolAttrGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBoolAttrGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBoolAttrGetValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBoolAttrGetValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBytecodeWriterConfigCreate/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBytecodeWriterConfigCreate/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBytecodeWriterConfigDesiredEmitVersion/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBytecodeWriterConfigDesiredEmitVersion/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirBytecodeWriterConfigDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirBytecodeWriterConfigDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCalibratedQuantizedTypeGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCalibratedQuantizedTypeGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCalibratedQuantizedTypeGetMax/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCalibratedQuantizedTypeGetMax/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCalibratedQuantizedTypeGetMin/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCalibratedQuantizedTypeGetMin/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirComplexTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirComplexTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirComplexTypeGetElementType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirComplexTypeGetElementType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirComplexTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirComplexTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextAppendDialectRegistry/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextAppendDialectRegistry/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextAttachDiagnosticHandler/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextAttachDiagnosticHandler/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextCreate/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextCreate/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextCreateWithRegistry/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextCreateWithRegistry/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextCreateWithThreading/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextCreateWithThreading/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextDetachDiagnosticHandler/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextDetachDiagnosticHandler/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextEnableMultithreading/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextEnableMultithreading/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextGetAllowUnregisteredDialects/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextGetAllowUnregisteredDialects/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextGetNumLoadedDialects/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextGetNumLoadedDialects/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextGetNumRegisteredDialects/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextGetNumRegisteredDialects/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextGetOrLoadDialect/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextGetOrLoadDialect/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextIsRegisteredOperation/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextIsRegisteredOperation/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextLoadAllAvailableDialects/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextLoadAllAvailableDialects/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextSetAllowUnregisteredDialects/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextSetAllowUnregisteredDialects/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirContextSetThreadPool/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirContextSetThreadPool/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncFuncToAsyncRuntime/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncFuncToAsyncRuntime/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncParallelFor/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncParallelFor/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncRuntimePolicyBasedRefCounting/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncRuntimePolicyBasedRefCounting/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncRuntimeRefCounting/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncRuntimeRefCounting/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncRuntimeRefCountingOpt/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncRuntimeRefCountingOpt/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncToAsyncRuntime/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncToAsyncRuntime/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionArithToAMDGPUConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionArithToAMDGPUConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionArithToArmSMEConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionArithToArmSMEConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionArithToLLVMConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionArithToLLVMConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertAffineForToGPU/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertAffineForToGPU/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertAffineToStandard/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertAffineToStandard/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertAMDGPUToROCDL/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertAMDGPUToROCDL/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArithToEmitC/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArithToEmitC/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArithToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArithToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArmNeon2dToIntr/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArmNeon2dToIntr/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArmSMEToLLVM/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArmSMEToLLVM/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArmSMEToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArmSMEToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertAsyncToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertAsyncToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertBufferizationToMemRef/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertBufferizationToMemRef/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertComplexToLibm/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertComplexToLibm/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertComplexToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertComplexToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertComplexToSPIRVPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertComplexToSPIRVPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertComplexToStandard/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertComplexToStandard/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertControlFlowToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertControlFlowToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertControlFlowToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertControlFlowToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertFuncToEmitC/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertFuncToEmitC/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertFuncToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertFuncToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertFuncToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertFuncToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGPUToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGPUToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGpuLaunchFuncToVulkanLaunchFunc/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGpuLaunchFuncToVulkanLaunchFunc/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGpuOpsToLLVMSPVOps/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGpuOpsToLLVMSPVOps/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGpuOpsToNVVMOps/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGpuOpsToNVVMOps/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGpuOpsToROCDLOps/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGpuOpsToROCDLOps/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertIndexToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertIndexToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertIndexToSPIRVPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertIndexToSPIRVPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertLinalgToStandard/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertLinalgToStandard/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToFuncs/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToFuncs/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToLibm/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToLibm/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToROCDL/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToROCDL/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMemRefToEmitC/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMemRefToEmitC/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMemRefToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMemRefToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertNVGPUToNVVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertNVGPUToNVVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertNVVMToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertNVVMToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertOpenACCToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertOpenACCToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertOpenMPToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertOpenMPToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertParallelLoopToGpu/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertParallelLoopToGpu/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertPDLToPDLInterp/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertPDLToPDLInterp/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertSCFToOpenMPPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertSCFToOpenMPPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertShapeConstraints/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertShapeConstraints/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertShapeToStandard/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertShapeToStandard/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertSPIRVToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertSPIRVToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertTensorToLinalg/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertTensorToLinalg/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertTensorToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertTensorToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertToSPIRVPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertToSPIRVPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToArmSME/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToArmSME/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToGPU/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToGPU/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVulkanLaunchFuncToVulkanCallsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVulkanLaunchFuncToVulkanCallsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionFinalizeMemRefToLLVMConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionFinalizeMemRefToLLVMConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionGpuToLLVMConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionGpuToLLVMConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionLiftControlFlowToSCFPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionLiftControlFlowToSCFPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionLowerHostCodeToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionLowerHostCodeToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionMapMemRefStorageClass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionMapMemRefStorageClass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionReconcileUnrealizedCasts/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionReconcileUnrealizedCasts/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionSCFToControlFlow/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionSCFToControlFlow/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionSCFToEmitC/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionSCFToEmitC/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionSCFToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionSCFToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionSetLLVMModuleDataLayoutPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionSetLLVMModuleDataLayoutPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToArith/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToArith/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToLinalg/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToLinalg/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToLinalgNamed/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToLinalgNamed/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToMLProgram/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToMLProgram/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToTensor/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToTensor/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionUBToLLVMConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionUBToLLVMConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateConversionUBToSPIRVConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionUBToSPIRVConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateExternalPass/9","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateExternalPass/9"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuAsyncRegionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuAsyncRegionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuDecomposeMemrefsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuDecomposeMemrefsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuEliminateBarriers/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuEliminateBarriers/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuKernelOutlining/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuKernelOutlining/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuLaunchSinkIndexComputations/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuLaunchSinkIndexComputations/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuMapParallelLoopsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuMapParallelLoopsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuModuleToBinaryPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuModuleToBinaryPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuNVVMAttachTarget/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuNVVMAttachTarget/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuROCDLAttachTarget/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuROCDLAttachTarget/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuSPIRVAttachTarget/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuSPIRVAttachTarget/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgConvertElementwiseToLinalgPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgConvertElementwiseToLinalgPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgConvertLinalgToAffineLoopsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgConvertLinalgToAffineLoopsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgConvertLinalgToLoopsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgConvertLinalgToLoopsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgConvertLinalgToParallelLoopsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgConvertLinalgToParallelLoopsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgBlockPackMatmul/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgBlockPackMatmul/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgDetensorizePass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgDetensorizePass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgElementwiseOpFusionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgElementwiseOpFusionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgFoldUnitExtentDimsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgFoldUnitExtentDimsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgGeneralizeNamedOpsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgGeneralizeNamedOpsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgInlineScalarOperandsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgInlineScalarOperandsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgNamedOpConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgNamedOpConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgSpecializeGenericOpsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgSpecializeGenericOpsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorLowerForeachToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorLowerForeachToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorLowerSparseIterationToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorLowerSparseIterationToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorLowerSparseOpsToForeach/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorLowerSparseOpsToForeach/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorPreSparsificationRewrite/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorPreSparsificationRewrite/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseAssembler/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseAssembler/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseBufferRewrite/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseBufferRewrite/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseGPUCodegen/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseGPUCodegen/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseReinterpretMap/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseReinterpretMap/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseSpaceCollapse/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseSpaceCollapse/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseTensorCodegen/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseTensorCodegen/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseTensorConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseTensorConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseVectorization/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseVectorization/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparsificationAndBufferization/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparsificationAndBufferization/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparsificationPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparsificationPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorStageSparseOperations/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorStageSparseOperations/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorStorageSpecifierToLLVM/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorStorageSpecifierToLLVM/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsCanonicalizer/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsCanonicalizer/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsCompositeFixedPointPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsCompositeFixedPointPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsControlFlowSink/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsControlFlowSink/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsCSE/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsCSE/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsGenerateRuntimeVerification/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsGenerateRuntimeVerification/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsInliner/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsInliner/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsLocationSnapshot/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsLocationSnapshot/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsLoopInvariantCodeMotion/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsLoopInvariantCodeMotion/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsLoopInvariantSubsetHoisting/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsLoopInvariantSubsetHoisting/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsMem2Reg/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsMem2Reg/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsPrintIRPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsPrintIRPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsPrintOpStats/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsPrintOpStats/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsRemoveDeadValues/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsRemoveDeadValues/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsSCCP/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsSCCP/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsSROA/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsSROA/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsStripDebugInfo/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsStripDebugInfo/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsSymbolDCE/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsSymbolDCE/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsSymbolPrivatize/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsSymbolPrivatize/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsTopologicalSort/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsTopologicalSort/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirCreateTransformsViewOpGraph/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsViewOpGraph/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseArrayAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseArrayAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseArrayGetNumElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseArrayGetNumElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseBoolArrayGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseBoolArrayGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseBoolArrayGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseBoolArrayGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseBoolResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseBoolResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseDoubleResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseDoubleResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrBFloat16Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrBFloat16Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrBoolGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrBoolGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrBoolSplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrBoolSplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrDoubleGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrDoubleGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrDoubleSplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrDoubleSplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrFloat16Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrFloat16Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrFloatGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrFloatGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrFloatSplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrFloatSplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetBoolSplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetBoolSplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetBoolValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetBoolValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetDoubleSplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetDoubleSplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetDoubleValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetDoubleValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetFloatSplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetFloatSplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetFloatValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetFloatValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt8SplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt8SplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt8Value/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt8Value/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt16Value/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt16Value/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt32SplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt32SplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt32Value/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt32Value/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt64SplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt64SplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt64Value/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt64Value/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetRawData/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetRawData/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetSplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetSplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetStringSplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetStringSplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetStringValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetStringValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt8SplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt8SplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt8Value/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt8Value/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt16Value/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt16Value/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt32SplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt32SplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt32Value/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt32Value/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt64SplatValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt64SplatValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt64Value/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt64Value/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt8Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt8Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt8SplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt8SplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt16Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt16Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt32Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt32Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt32SplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt32SplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt64Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt64Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt64SplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt64SplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrIsSplat/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrIsSplat/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrRawBufferGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrRawBufferGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrReshapeGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrReshapeGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrSplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrSplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrStringGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrStringGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt8Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt8Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt8SplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt8SplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt16Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt16Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt32Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt32Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt32SplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt32SplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt64Get/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt64Get/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt64SplatGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt64SplatGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseF32ArrayGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseF32ArrayGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseF32ArrayGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseF32ArrayGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseF64ArrayGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseF64ArrayGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseF64ArrayGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseF64ArrayGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseFloatResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseFloatResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseI8ArrayGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseI8ArrayGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseI8ArrayGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseI8ArrayGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseI16ArrayGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseI16ArrayGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseI16ArrayGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseI16ArrayGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseI32ArrayGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseI32ArrayGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseI32ArrayGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseI32ArrayGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseI64ArrayGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseI64ArrayGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseI64ArrayGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseI64ArrayGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseInt8ResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseInt8ResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseInt16ResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseInt16ResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseInt32ResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseInt32ResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseInt64ResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseInt64ResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseIntOrFPElementsAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseIntOrFPElementsAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseUInt8ResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseUInt8ResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseUInt16ResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseUInt16ResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseUInt32ResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseUInt32ResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDenseUInt64ResourceElementsAttrGetValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDenseUInt64ResourceElementsAttrGetValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDiagnosticGetLocation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticGetLocation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDiagnosticGetNote/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticGetNote/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDiagnosticGetNumNotes/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticGetNumNotes/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDiagnosticGetSeverity/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticGetSeverity/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDiagnosticPrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticPrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectGetNamespace/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectGetNamespace/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectHandleGetNamespace/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectHandleGetNamespace/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectHandleInsertDialect/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectHandleInsertDialect/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectHandleLoadDialect/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectHandleLoadDialect/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectHandleRegisterDialect/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectHandleRegisterDialect/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectRegistryCreate/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectRegistryCreate/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDialectRegistryDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDialectRegistryDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGetElement/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGetElement/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGetElementByName/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGetElementByName/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGetNumElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGetNumElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirDisctinctAttrCreate/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirDisctinctAttrCreate/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirElementsAttrGetNumElements/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirElementsAttrGetNumElements/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirElementsAttrGetValue/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirElementsAttrGetValue/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirElementsAttrIsValidIndex/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirElementsAttrIsValidIndex/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirEmitError/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirEmitError/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirEnableGlobalDebug/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirEnableGlobalDebug/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineCreate/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineCreate/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineDumpToObjectFile/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineDumpToObjectFile/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineInvokePacked/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineInvokePacked/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineInvokePacked_dirty_cpu/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineInvokePacked_dirty_cpu/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineInvokePacked_dirty_io/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineInvokePacked_dirty_io/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineLookup/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineLookup/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineLookupPacked/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineLookupPacked/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExecutionEngineRegisterSymbol/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineRegisterSymbol/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirExternalPassSignalFailure/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirExternalPassSignalFailure/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirF16TypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirF16TypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirF32TypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirF32TypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirF64TypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirF64TypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFlatSymbolRefAttrGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFlatSymbolRefAttrGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFlatSymbolRefAttrGetValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFlatSymbolRefAttrGetValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E3M4TypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E3M4TypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E3M4TypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E3M4TypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3B11FNUZTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3B11FNUZTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3B11FNUZTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3B11FNUZTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3FNTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3FNTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3FNTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3FNTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3FNUZTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3FNUZTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3FNUZTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3FNUZTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3TypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3TypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3TypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3TypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E5M2FNUZTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E5M2FNUZTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E5M2FNUZTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E5M2FNUZTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E5M2TypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E5M2TypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat8E5M2TypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E5M2TypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat16TypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat16TypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat32TypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat32TypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloat64TypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloat64TypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloatAttrDoubleGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrDoubleGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloatAttrDoubleGetChecked/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrDoubleGetChecked/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloatAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloatAttrGetValueDouble/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrGetValueDouble/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloatTF32TypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloatTF32TypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFloatTypeGetWidth/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFloatTypeGetWidth/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFreezeRewritePattern/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFreezeRewritePattern/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFrozenRewritePatternSetDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFrozenRewritePatternSetDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFuncSetArgAttr/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFuncSetArgAttr/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetInput/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetInput/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetNumInputs/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetNumInputs/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetNumResults/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetNumResults/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetResult/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetResult/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__async__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__async__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__cf__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__cf__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__elixir__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__elixir__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__func__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__func__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__gpu__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__gpu__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__irdl__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__irdl__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__linalg__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__linalg__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__llvm__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__llvm__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__pdl__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__pdl__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__quant__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__quant__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__scf__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__scf__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__shape__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__shape__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__sparse_tensor__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__sparse_tensor__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__tensor__/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__tensor__/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUAsyncTokenTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUAsyncTokenTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetFormat/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetFormat/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetKernels/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetKernels/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetObject/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetObject/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetProperties/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetProperties/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetTarget/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetTarget/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetWithKernels/6","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetWithKernels/6"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrHasKernels/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrHasKernels/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrHasProperties/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrHasProperties/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIdentifierEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIdentifierGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIdentifierGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIdentifierStr/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierStr/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIndexTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIndexTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIndexTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIndexTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirInferShapedTypeOpInterfaceInferReturnTypes/11","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirInferShapedTypeOpInterfaceInferReturnTypes/11"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirInferShapedTypeOpInterfaceTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirInferShapedTypeOpInterfaceTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirInferTypeOpInterfaceInferReturnTypes/11","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirInferTypeOpInterfaceInferReturnTypes/11"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirInferTypeOpInterfaceTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirInferTypeOpInterfaceTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGetValueInt/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGetValueInt/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGetValueSInt/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGetValueSInt/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGetValueUInt/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGetValueUInt/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetDump/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetDump/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetEmptyGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetEmptyGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGet/6","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGet/6"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetConstraint/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetConstraint/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumConstraints/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumConstraints/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumDims/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumDims/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumEqualities/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumEqualities/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumInequalities/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumInequalities/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumInputs/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumInputs/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumSymbols/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumSymbols/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetIsCanonicalEmpty/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetIsCanonicalEmpty/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetIsConstraintEq/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetIsConstraintEq/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetPrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetPrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerSetReplaceGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetReplaceGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerTypeGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerTypeGetWidth/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeGetWidth/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerTypeIsSigned/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeIsSigned/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerTypeIsSignless/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeIsSignless/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerTypeIsUnsigned/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeIsUnsigned/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerTypeSignedGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeSignedGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIntegerTypeUnsignedGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeUnsignedGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIRRewriterCreate/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIRRewriterCreate/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIRRewriterCreateFromOp/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIRRewriterCreateFromOp/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIRRewriterDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIRRewriterDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIsCurrentDebugType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIsCurrentDebugType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirIsGlobalDebugEnabled/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirIsGlobalDebugEnabled/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLinalgFillBuiltinNamedOpRegion/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLinalgFillBuiltinNamedOpRegion/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMArrayTypeGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMArrayTypeGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMCConvAttrGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMCConvAttrGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMComdatAttrGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMComdatAttrGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIBasicTypeAttrGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIBasicTypeAttrGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDICompileUnitAttrGet/8","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDICompileUnitAttrGet/8"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDICompositeTypeAttrGet/18","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDICompositeTypeAttrGet/18"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDICompositeTypeAttrGetRecSelf/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDICompositeTypeAttrGetRecSelf/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIDerivedTypeAttrGet/9","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIDerivedTypeAttrGet/9"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIDerivedTypeAttrGetBaseType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIDerivedTypeAttrGetBaseType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIExpressionAttrGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIExpressionAttrGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIExpressionElemAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIExpressionElemAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIFileAttrGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIFileAttrGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIFlagsAttrGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIFlagsAttrGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIImportedEntityAttrGet/9","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIImportedEntityAttrGet/9"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDILexicalBlockAttrGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDILexicalBlockAttrGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDILexicalBlockFileAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDILexicalBlockFileAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDILocalVariableAttrGet/9","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDILocalVariableAttrGet/9"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIModuleAttrGet/9","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIModuleAttrGet/9"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIModuleAttrGetScope/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIModuleAttrGetScope/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDINullTypeAttrGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDINullTypeAttrGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDIStringTypeAttrGet/9","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIStringTypeAttrGet/9"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGet/15","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGet/15"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetCompileUnit/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetCompileUnit/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetFile/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetFile/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetLine/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetLine/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetRecSelf/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetRecSelf/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetScope/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetScope/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetScopeLine/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetScopeLine/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMDISubroutineTypeAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubroutineTypeAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMFunctionTypeGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMFunctionTypeGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMLinkageAttrGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMLinkageAttrGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMPointerTypeGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMPointerTypeGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMPointerTypeGetAddressSpace/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMPointerTypeGetAddressSpace/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeGetElementType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeGetElementType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeGetIdentifier/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeGetIdentifier/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeGetNumElementTypes/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeGetNumElementTypes/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIdentifiedGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIdentifiedGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIdentifiedNewGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIdentifiedNewGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIsLiteral/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIsLiteral/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIsOpaque/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIsOpaque/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIsPacked/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIsPacked/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeLiteralGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeLiteralGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeLiteralGetChecked/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeLiteralGetChecked/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeOpaqueGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeOpaqueGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeSetBody/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeSetBody/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLLVMVoidTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLLVMVoidTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLlvmThreadPoolCreate/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLlvmThreadPoolCreate/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLlvmThreadPoolDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLlvmThreadPoolDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLoadIRDLDialects/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLoadIRDLDialects/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationCallSiteGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationCallSiteGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationFileLineColGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationFileLineColGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationFromAttribute/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationFromAttribute/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationFusedGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationFusedGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationGetAttribute/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationGetAttribute/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationNameGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationNameGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationPrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationPrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirLocationUnknownGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirLocationUnknownGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeContiguousGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeContiguousGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeContiguousGetChecked/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeContiguousGetChecked/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetAffineMap/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetAffineMap/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetChecked/6","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetChecked/6"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetLayout/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetLayout/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetMemorySpace/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetMemorySpace/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetStridesAndOffset/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetStridesAndOffset/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirModuleCreateEmpty/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirModuleCreateEmpty/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirModuleCreateParse/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirModuleCreateParse/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirModuleDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirModuleDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirModuleFromOperation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirModuleFromOperation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirModuleGetBody/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirModuleGetBody/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirModuleGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirModuleGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirModuleGetOperation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirModuleGetOperation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirNamedAttributeGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirNamedAttributeGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirNoneTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirNoneTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirNoneTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirNoneTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpaqueAttrGet/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueAttrGet/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpaqueAttrGetData/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueAttrGetData/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpaqueAttrGetDialectNamespace/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueAttrGetDialectNamespace/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpaqueAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpaqueTypeGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueTypeGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpaqueTypeGetData/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueTypeGetData/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpaqueTypeGetDialectNamespace/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueTypeGetDialectNamespace/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpaqueTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationClone/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationClone/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationCreate/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationCreate/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationCreateParse/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationCreateParse/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationDump/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationDump/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetAttribute/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetAttribute/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetAttributeByName/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetAttributeByName/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetBlock/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetBlock/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetDiscardableAttribute/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetDiscardableAttribute/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetDiscardableAttributeByName/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetDiscardableAttributeByName/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetFirstRegion/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetFirstRegion/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetInherentAttributeByName/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetInherentAttributeByName/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetLocation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetLocation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetName/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetName/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetNextInBlock/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNextInBlock/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetNumAttributes/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumAttributes/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetNumDiscardableAttributes/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumDiscardableAttributes/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetNumOperands/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumOperands/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetNumRegions/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumRegions/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetNumResults/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumResults/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetNumSuccessors/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumSuccessors/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetOperand/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetOperand/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetParentOperation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetParentOperation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetRegion/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetRegion/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetResult/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetResult/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetSuccessor/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetSuccessor/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationGetTypeID/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetTypeID/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationHasInherentAttributeByName/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationHasInherentAttributeByName/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationImplementsInterface/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationImplementsInterface/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationImplementsInterfaceStatic/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationImplementsInterfaceStatic/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationMoveAfter/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationMoveAfter/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationMoveBefore/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationMoveBefore/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationPrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationPrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationPrintWithFlags/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationPrintWithFlags/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationPrintWithState/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationPrintWithState/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationRemoveAttributeByName/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationRemoveAttributeByName/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationRemoveDiscardableAttributeByName/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationRemoveDiscardableAttributeByName/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationRemoveFromParent/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationRemoveFromParent/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationSetAttributeByName/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetAttributeByName/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationSetDiscardableAttributeByName/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetDiscardableAttributeByName/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationSetInherentAttributeByName/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetInherentAttributeByName/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationSetOperand/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetOperand/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationSetOperands/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetOperands/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationSetSuccessor/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetSuccessor/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationStateAddAttributes/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddAttributes/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationStateAddOperands/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddOperands/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationStateAddOwnedRegions/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddOwnedRegions/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationStateAddResults/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddResults/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationStateAddSuccessors/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddSuccessors/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationStateEnableResultTypeInference/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateEnableResultTypeInference/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationStateGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationVerify/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationVerify/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationWalk/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationWalk/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationWriteBytecode/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationWriteBytecode/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOperationWriteBytecodeWithConfig/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOperationWriteBytecodeWithConfig/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpOperandGetNextUse/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandGetNextUse/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpOperandGetOperandNumber/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandGetOperandNumber/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpOperandGetOwner/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandGetOwner/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpOperandGetValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandGetValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpOperandIsNull/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandIsNull/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPassManagerAddOwnedPass/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPassManagerAddOwnedPass/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPassManagerAddPipeline/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPassManagerAddPipeline/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPassManagerGetNestedUnder/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPassManagerGetNestedUnder/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsAssumeVerified/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsAssumeVerified/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsCreate/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsCreate/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsElideLargeElementsAttrs/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsElideLargeElementsAttrs/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsElideLargeResourceString/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsElideLargeResourceString/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsEnableDebugInfo/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsEnableDebugInfo/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsPrintGenericOpForm/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsPrintGenericOpForm/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsSkipRegions/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsSkipRegions/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsUseLocalScope/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsUseLocalScope/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpResultGetOwner/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpResultGetOwner/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirOpResultGetResultNumber/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirOpResultGetResultNumber/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirParsePassPipeline/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirParsePassPipeline/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerAddOwnedPass/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerAddOwnedPass/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerCreate/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerCreate/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerCreateOnOperation/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerCreateOnOperation/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerEnableIRPrinting/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerEnableIRPrinting/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerEnableVerifier/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerEnableVerifier/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerGetAsOpPassManager/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerGetAsOpPassManager/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerGetNestedUnder/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerGetNestedUnder/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPassManagerRunOnOp/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerRunOnOp/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPDLAttributeTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPDLAttributeTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPDLOperationTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPDLOperationTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPDLPatternModuleDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPDLPatternModuleDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPDLPatternModuleFromModule/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPDLPatternModuleFromModule/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPDLRangeTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPDLRangeTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPDLRangeTypeGetElementType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPDLRangeTypeGetElementType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPDLTypeTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPDLTypeTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPDLValueTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPDLValueTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirPrintPassPipeline/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirPrintPassPipeline/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastExpressedToStorageType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastExpressedToStorageType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastFromExpressedType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastFromExpressedType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastFromStorageType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastFromStorageType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastToExpressedType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastToExpressedType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastToStorageType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastToStorageType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetDefaultMaximumForInteger/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetDefaultMaximumForInteger/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetDefaultMinimumForInteger/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetDefaultMinimumForInteger/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetExpressedType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetExpressedType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetFlags/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetFlags/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetQuantizedElementType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetQuantizedElementType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetSignedFlag/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetSignedFlag/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetStorageType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetStorageType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetStorageTypeIntegralWidth/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetStorageTypeIntegralWidth/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetStorageTypeMax/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetStorageTypeMax/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetStorageTypeMin/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetStorageTypeMin/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeIsCompatibleExpressedType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeIsCompatibleExpressedType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeIsSigned/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeIsSigned/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGetChecked/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGetChecked/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGetEncoding/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGetEncoding/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionAppendOwnedBlock/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionAppendOwnedBlock/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionCreate/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionCreate/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionGetFirstBlock/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionGetFirstBlock/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionGetNextInOperation/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionGetNextInOperation/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionInsertOwnedBlock/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionInsertOwnedBlock/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionInsertOwnedBlockAfter/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionInsertOwnedBlockAfter/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionInsertOwnedBlockBefore/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionInsertOwnedBlockBefore/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegionTakeBody/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegionTakeBody/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAllDialects/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAllDialects/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAllLLVMTranslations/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAllLLVMTranslations/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAllPasses/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAllPasses/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncFuncToAsyncRuntime/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncFuncToAsyncRuntime/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncParallelFor/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncParallelFor/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncRuntimePolicyBasedRefCounting/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncRuntimePolicyBasedRefCounting/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncRuntimeRefCounting/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncRuntimeRefCounting/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncRuntimeRefCountingOpt/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncRuntimeRefCountingOpt/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncToAsyncRuntime/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncToAsyncRuntime/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncPasses/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncPasses/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionArithToAMDGPUConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionArithToAMDGPUConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionArithToArmSMEConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionArithToArmSMEConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionArithToLLVMConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionArithToLLVMConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertAffineForToGPU/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertAffineForToGPU/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertAffineToStandard/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertAffineToStandard/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertAMDGPUToROCDL/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertAMDGPUToROCDL/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArithToEmitC/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArithToEmitC/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArithToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArithToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArmNeon2dToIntr/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArmNeon2dToIntr/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArmSMEToLLVM/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArmSMEToLLVM/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArmSMEToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArmSMEToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertAsyncToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertAsyncToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertBufferizationToMemRef/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertBufferizationToMemRef/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertComplexToLibm/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertComplexToLibm/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertComplexToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertComplexToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertComplexToSPIRVPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertComplexToSPIRVPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertComplexToStandard/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertComplexToStandard/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertControlFlowToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertControlFlowToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertControlFlowToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertControlFlowToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertFuncToEmitC/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertFuncToEmitC/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertFuncToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertFuncToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertFuncToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertFuncToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGPUToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGPUToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGpuLaunchFuncToVulkanLaunchFunc/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGpuLaunchFuncToVulkanLaunchFunc/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGpuOpsToLLVMSPVOps/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGpuOpsToLLVMSPVOps/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGpuOpsToNVVMOps/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGpuOpsToNVVMOps/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGpuOpsToROCDLOps/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGpuOpsToROCDLOps/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertIndexToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertIndexToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertIndexToSPIRVPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertIndexToSPIRVPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertLinalgToStandard/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertLinalgToStandard/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToFuncs/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToFuncs/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToLibm/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToLibm/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToROCDL/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToROCDL/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMemRefToEmitC/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMemRefToEmitC/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMemRefToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMemRefToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertNVGPUToNVVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertNVGPUToNVVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertNVVMToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertNVVMToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertOpenACCToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertOpenACCToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertOpenMPToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertOpenMPToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertParallelLoopToGpu/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertParallelLoopToGpu/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertPDLToPDLInterp/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertPDLToPDLInterp/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertSCFToOpenMPPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertSCFToOpenMPPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertShapeConstraints/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertShapeConstraints/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertShapeToStandard/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertShapeToStandard/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertSPIRVToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertSPIRVToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertTensorToLinalg/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertTensorToLinalg/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertTensorToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertTensorToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertToSPIRVPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertToSPIRVPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToArmSME/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToArmSME/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToGPU/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToGPU/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVulkanLaunchFuncToVulkanCallsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVulkanLaunchFuncToVulkanCallsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionFinalizeMemRefToLLVMConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionFinalizeMemRefToLLVMConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionGpuToLLVMConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionGpuToLLVMConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionLiftControlFlowToSCFPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionLiftControlFlowToSCFPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionLowerHostCodeToLLVMPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionLowerHostCodeToLLVMPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionMapMemRefStorageClass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionMapMemRefStorageClass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionPasses/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionPasses/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionReconcileUnrealizedCasts/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionReconcileUnrealizedCasts/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionSCFToControlFlow/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionSCFToControlFlow/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionSCFToEmitC/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionSCFToEmitC/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionSCFToSPIRV/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionSCFToSPIRV/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionSetLLVMModuleDataLayoutPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionSetLLVMModuleDataLayoutPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToArith/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToArith/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToLinalg/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToLinalg/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToLinalgNamed/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToLinalgNamed/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToMLProgram/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToMLProgram/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToTensor/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToTensor/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionUBToLLVMConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionUBToLLVMConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterConversionUBToSPIRVConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionUBToSPIRVConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuAsyncRegionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuAsyncRegionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuDecomposeMemrefsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuDecomposeMemrefsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuEliminateBarriers/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuEliminateBarriers/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuKernelOutlining/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuKernelOutlining/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuLaunchSinkIndexComputations/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuLaunchSinkIndexComputations/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuMapParallelLoopsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuMapParallelLoopsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuModuleToBinaryPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuModuleToBinaryPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuNVVMAttachTarget/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuNVVMAttachTarget/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuROCDLAttachTarget/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuROCDLAttachTarget/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuSPIRVAttachTarget/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuSPIRVAttachTarget/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterGPUPasses/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUPasses/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgConvertElementwiseToLinalgPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgConvertElementwiseToLinalgPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgConvertLinalgToAffineLoopsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgConvertLinalgToAffineLoopsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgConvertLinalgToLoopsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgConvertLinalgToLoopsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgConvertLinalgToParallelLoopsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgConvertLinalgToParallelLoopsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgBlockPackMatmul/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgBlockPackMatmul/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgDetensorizePass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgDetensorizePass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgElementwiseOpFusionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgElementwiseOpFusionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgFoldUnitExtentDimsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgFoldUnitExtentDimsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgGeneralizeNamedOpsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgGeneralizeNamedOpsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgInlineScalarOperandsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgInlineScalarOperandsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgNamedOpConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgNamedOpConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgSpecializeGenericOpsPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgSpecializeGenericOpsPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgPasses/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgPasses/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorLowerForeachToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorLowerForeachToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorLowerSparseIterationToSCF/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorLowerSparseIterationToSCF/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorLowerSparseOpsToForeach/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorLowerSparseOpsToForeach/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorPasses/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorPasses/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorPreSparsificationRewrite/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorPreSparsificationRewrite/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseAssembler/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseAssembler/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseBufferRewrite/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseBufferRewrite/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseGPUCodegen/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseGPUCodegen/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseReinterpretMap/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseReinterpretMap/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseSpaceCollapse/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseSpaceCollapse/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseTensorCodegen/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseTensorCodegen/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseTensorConversionPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseTensorConversionPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseVectorization/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseVectorization/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparsificationAndBufferization/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparsificationAndBufferization/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparsificationPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparsificationPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorStageSparseOperations/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorStageSparseOperations/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorStorageSpecifierToLLVM/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorStorageSpecifierToLLVM/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsCanonicalizer/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsCanonicalizer/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsCompositeFixedPointPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsCompositeFixedPointPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsControlFlowSink/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsControlFlowSink/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsCSE/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsCSE/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsGenerateRuntimeVerification/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsGenerateRuntimeVerification/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsInliner/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsInliner/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsLocationSnapshot/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsLocationSnapshot/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsLoopInvariantCodeMotion/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsLoopInvariantCodeMotion/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsLoopInvariantSubsetHoisting/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsLoopInvariantSubsetHoisting/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsMem2Reg/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsMem2Reg/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsPasses/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsPasses/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsPrintIRPass/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsPrintIRPass/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsPrintOpStats/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsPrintOpStats/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsRemoveDeadValues/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsRemoveDeadValues/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsSCCP/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsSCCP/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsSROA/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsSROA/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsStripDebugInfo/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsStripDebugInfo/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsSymbolDCE/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsSymbolDCE/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsSymbolPrivatize/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsSymbolPrivatize/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsTopologicalSort/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsTopologicalSort/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsViewOpGraph/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsViewOpGraph/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewritePatternSetFromPDLPatternModule/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewritePatternSetFromPDLPatternModule/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseCancelOpModification/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseCancelOpModification/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseClearInsertionPoint/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseClearInsertionPoint/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseClone/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseClone/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseCloneRegionBefore/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseCloneRegionBefore/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseCloneWithoutRegions/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseCloneWithoutRegions/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseCreateBlockBefore/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseCreateBlockBefore/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseEraseBlock/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseEraseBlock/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseEraseOp/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseEraseOp/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseFinalizeOpModification/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseFinalizeOpModification/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseGetBlock/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseGetBlock/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseGetInsertionBlock/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseGetInsertionBlock/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseInlineBlockBefore/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseInlineBlockBefore/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseInlineRegionBefore/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseInlineRegionBefore/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseInsert/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseInsert/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseMergeBlocks/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseMergeBlocks/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseMoveBlockBefore/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseMoveBlockBefore/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseMoveOpAfter/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseMoveOpAfter/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseMoveOpBefore/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseMoveOpBefore/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllOpUsesWithOperation/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllOpUsesWithOperation/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllOpUsesWithValueRange/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllOpUsesWithValueRange/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllUsesExcept/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllUsesExcept/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllUsesWith/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllUsesWith/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllValueRangeUsesWith/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllValueRangeUsesWith/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceOpUsesWithinBlock/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceOpUsesWithinBlock/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceOpWithOperation/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceOpWithOperation/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceOpWithValues/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceOpWithValues/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointAfter/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointAfter/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointAfterValue/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointAfterValue/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointBefore/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointBefore/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointToEnd/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointToEnd/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointToStart/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointToStart/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirRewriterBaseStartOpModification/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseStartOpModification/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSetGlobalDebugType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSetGlobalDebugType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSetGlobalDebugTypes/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSetGlobalDebugTypes/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetDimSize/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetDimSize/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetDynamicSize/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetDynamicSize/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetDynamicStrideOrOffset/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetDynamicStrideOrOffset/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetElementType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetElementType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetRank/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetRank/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeHasRank/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeHasRank/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeHasStaticShape/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeHasStaticShape/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeIsDynamicDim/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeIsDynamicDim/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeIsDynamicSize/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeIsDynamicSize/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirShapedTypeIsDynamicStrideOrOffset/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeIsDynamicStrideOrOffset/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseElementsAttrGetIndices/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseElementsAttrGetIndices/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseElementsAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseElementsAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseElementsAttrGetValues/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseElementsAttrGetValues/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseElementsAttribute/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseElementsAttribute/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrBuildLvlType/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrBuildLvlType/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGet/9","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGet/9"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetCrdWidth/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetCrdWidth/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetDimToLvl/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetDimToLvl/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetExplicitVal/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetExplicitVal/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetImplicitVal/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetImplicitVal/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetLvlFmt/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetLvlFmt/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetLvlToDim/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetLvlToDim/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetLvlType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetLvlType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetPosWidth/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetPosWidth/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetStructuredM/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetStructuredM/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetStructuredN/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetStructuredN/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingGetLvlRank/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingGetLvlRank/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGetNumStrides/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGetNumStrides/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGetOffset/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGetOffset/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGetStride/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGetStride/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStringAttrGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStringAttrGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStringAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStringAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStringAttrGetValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStringAttrGetValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStringAttrTypedGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStringAttrTypedGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStringRefCreateFromCString/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStringRefCreateFromCString/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirStringRefEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirStringRefEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetLeafReference/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetLeafReference/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetNestedReference/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetNestedReference/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetNumNestedReferences/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetNumNestedReferences/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetRootReference/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetRootReference/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableCreate/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableCreate/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableErase/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableErase/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableGetSymbolAttributeName/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableGetSymbolAttributeName/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableGetVisibilityAttributeName/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableGetVisibilityAttributeName/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableInsert/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableInsert/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableLookup/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableLookup/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableReplaceAllSymbolUses/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableReplaceAllSymbolUses/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirSymbolTableWalkSymbolTables/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableWalkSymbolTables/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTF32TypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTF32TypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTupleTypeGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTupleTypeGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTupleTypeGetNumTypes/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTupleTypeGetNumTypes/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTupleTypeGetType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTupleTypeGetType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTupleTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTupleTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeAttrGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeAttrGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeAttrGetValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeAttrGetValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeDump/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeDump/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeGetContext/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeGetContext/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeGetDialect/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeGetDialect/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeGetTypeID/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeGetTypeID/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIDAllocatorAllocateTypeID/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDAllocatorAllocateTypeID/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIDAllocatorCreate/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDAllocatorCreate/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIDAllocatorDestroy/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDAllocatorDestroy/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIDCreate/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDCreate/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIDEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIDHashValue/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDHashValue/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAAnyQuantizedType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAAnyQuantizedType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsABF16/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsABF16/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsACalibratedQuantizedType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsACalibratedQuantizedType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAComplex/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAComplex/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAF16/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAF16/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAF32/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAF32/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAF64/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAF64/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E3M4/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E3M4/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E4M3/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E4M3/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E4M3B11FNUZ/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E4M3B11FNUZ/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E4M3FN/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E4M3FN/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E4M3FNUZ/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E4M3FNUZ/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E5M2/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E5M2/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E5M2FNUZ/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E5M2FNUZ/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAFunction/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFunction/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAGPUAsyncTokenType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAGPUAsyncTokenType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAIndex/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAIndex/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAInteger/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAInteger/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsALLVMPointerType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsALLVMPointerType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsALLVMStructType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsALLVMStructType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAMemRef/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAMemRef/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsANone/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsANone/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAOpaque/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAOpaque/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLAttributeType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLAttributeType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLOperationType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLOperationType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLRangeType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLRangeType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLTypeType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLTypeType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLValueType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLValueType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAQuantizedType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAQuantizedType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsARankedTensor/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsARankedTensor/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAShaped/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAShaped/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsATensor/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATensor/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsATF32/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATF32/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsATuple/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATuple/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAUniformQuantizedPerAxisType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAUniformQuantizedPerAxisType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAUniformQuantizedType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAUniformQuantizedType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAUnrankedMemRef/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAUnrankedMemRef/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAUnrankedTensor/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAUnrankedTensor/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeIsAVector/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAVector/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypeParseGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypeParseGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirTypePrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirTypePrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGet/9","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGet/9"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGetNumDims/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGetNumDims/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGetQuantizedDimension/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGetQuantizedDimension/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGetScale/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGetScale/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGetZeroPoint/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGetZeroPoint/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeIsFixedPoint/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeIsFixedPoint/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedTypeGet/7","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedTypeGet/7"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedTypeGetScale/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedTypeGetScale/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedTypeGetZeroPoint/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedTypeGetZeroPoint/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedTypeIsFixedPoint/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedTypeIsFixedPoint/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnitAttrGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnitAttrGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnitAttrGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnitAttrGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseBoolResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseBoolResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseDoubleResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseDoubleResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseFloatResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseFloatResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseInt8ResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseInt8ResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseInt16ResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseInt16ResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseInt32ResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseInt32ResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseInt64ResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseInt64ResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseResourceElementsAttrGet/8","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseResourceElementsAttrGet/8"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseUInt8ResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseUInt8ResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseUInt16ResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseUInt16ResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseUInt32ResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseUInt32ResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseUInt64ResourceElementsAttrGet/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseUInt64ResourceElementsAttrGet/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnrankedMemRefTypeGet/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemRefTypeGet/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnrankedMemRefTypeGetChecked/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemRefTypeGetChecked/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnrankedMemRefTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemRefTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnrankedMemrefGetMemorySpace/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemrefGetMemorySpace/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnrankedTensorTypeGet/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedTensorTypeGet/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnrankedTensorTypeGetChecked/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedTensorTypeGetChecked/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirUnrankedTensorTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedTensorTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValueDump/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValueDump/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValueEqual/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValueEqual/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValueGetFirstUse/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValueGetFirstUse/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValueGetType/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValueGetType/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValueIsABlockArgument/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValueIsABlockArgument/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValueIsAOpResult/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValueIsAOpResult/1"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValuePrint/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValuePrint/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValuePrintAsOperand/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValuePrintAsOperand/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValueReplaceAllUsesOfWith/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValueReplaceAllUsesOfWith/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirValueSetType/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirValueSetType/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirVectorTypeGet/3","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGet/3"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetChecked/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetChecked/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetScalable/4","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetScalable/4"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetScalableChecked/5","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetScalableChecked/5"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetTypeID/0","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetTypeID/0"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirVectorTypeIsDimScalable/2","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeIsDimScalable/2"},{"type":"function","title":"Beaver.MLIR.CAPI.mlirVectorTypeIsScalable/1","doc":"","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeIsScalable/1"},{"type":"module","title":"Beaver.MLIR.Context","doc":"This module defines functions creating or destroying MLIR context.","ref":"Beaver.MLIR.Context.html"},{"type":"function","title":"Beaver.MLIR.Context.create/1","doc":"Create a MLIR context. By default it registers and loads all dialects.","ref":"Beaver.MLIR.Context.html#create/1"},{"type":"function","title":"Beaver.MLIR.Context.destroy/1","doc":"","ref":"Beaver.MLIR.Context.html#destroy/1"},{"type":"function","title":"Beaver.MLIR.Context.make/1","doc":"","ref":"Beaver.MLIR.Context.html#make/1"},{"type":"function","title":"Beaver.MLIR.Context.register_translations/1","doc":"","ref":"Beaver.MLIR.Context.html#register_translations/1"},{"type":"type","title":"Beaver.MLIR.Context.context_option/0","doc":"","ref":"Beaver.MLIR.Context.html#t:context_option/0"},{"type":"type","title":"Beaver.MLIR.Context.t/0","doc":"","ref":"Beaver.MLIR.Context.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Conversion","doc":"Conversions MLIR provides by default.","ref":"Beaver.MLIR.Conversion.html"},{"type":"function","title":"Beaver.MLIR.Conversion.arm_neon_2d_to_intr/0","doc":"Convert Arm NEON structured ops to intrinsics","ref":"Beaver.MLIR.Conversion.html#arm_neon_2d_to_intr/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.arm_neon_2d_to_intr/0","doc":"`arm-neon-2d-to-intr`","ref":"Beaver.MLIR.Conversion.html#arm_neon_2d_to_intr/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.arm_neon_2d_to_intr/0","doc":"`ConvertArmNeon2dToIntr`","ref":"Beaver.MLIR.Conversion.html#arm_neon_2d_to_intr/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.arm_neon_2d_to_intr/1","doc":"","ref":"Beaver.MLIR.Conversion.html#arm_neon_2d_to_intr/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_affine_for_to_gpu/0","doc":"Convert top-level AffineFor Ops to GPU kernels","ref":"Beaver.MLIR.Conversion.html#convert_affine_for_to_gpu/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_affine_for_to_gpu/0","doc":"`convert-affine-for-to-gpu`","ref":"Beaver.MLIR.Conversion.html#convert_affine_for_to_gpu/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_affine_for_to_gpu/0","doc":"`ConvertAffineForToGPU`","ref":"Beaver.MLIR.Conversion.html#convert_affine_for_to_gpu/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_affine_for_to_gpu/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_affine_for_to_gpu/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_amdgpu_to_rocdl/0","doc":"Convert AMDGPU dialect to ROCDL dialect","ref":"Beaver.MLIR.Conversion.html#convert_amdgpu_to_rocdl/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_amdgpu_to_rocdl/0","doc":"`convert-amdgpu-to-rocdl`","ref":"Beaver.MLIR.Conversion.html#convert_amdgpu_to_rocdl/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_amdgpu_to_rocdl/0","doc":"`ConvertAMDGPUToROCDL`","ref":"Beaver.MLIR.Conversion.html#convert_amdgpu_to_rocdl/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_amdgpu_to_rocdl/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_amdgpu_to_rocdl/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_amdgpu/0","doc":"Convert Arith operations to AMDGPU-specific implementations","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_amdgpu/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_amdgpu/0","doc":"`convert-arith-to-amdgpu`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_amdgpu/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_amdgpu/0","doc":"`ArithToAMDGPUConversionPass`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_amdgpu/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_amdgpu/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_amdgpu/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_arm_sme/0","doc":"Convert Arith dialect to ArmSME dialect","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_arm_sme/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_arm_sme/0","doc":"`convert-arith-to-arm-sme`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_arm_sme/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_arm_sme/0","doc":"`ArithToArmSMEConversionPass`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_arm_sme/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_arm_sme/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_arm_sme/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_emitc/0","doc":"Convert Arith dialect to EmitC dialect","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_emitc/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_emitc/0","doc":"`convert-arith-to-emitc`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_emitc/0","doc":"`ConvertArithToEmitC`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_emitc/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_emitc/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_emitc/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_llvm/0","doc":"Convert Arith dialect to LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_llvm/0","doc":"`convert-arith-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_llvm/0","doc":"`ArithToLLVMConversionPass`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_spirv/0","doc":"Convert Arith dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_spirv/0","doc":"`convert-arith-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_spirv/0","doc":"`ConvertArithToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arith_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arm_sme_to_llvm/0","doc":"Lower the operations from the ArmSME dialect into the LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arm_sme_to_llvm/0","doc":"`convert-arm-sme-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arm_sme_to_llvm/0","doc":"`ConvertArmSMEToLLVM`","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arm_sme_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arm_sme_to_scf/0","doc":"Lower the operations from the ArmSME dialect into the SCF dialect","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_scf/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arm_sme_to_scf/0","doc":"`convert-arm-sme-to-scf`","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arm_sme_to_scf/0","doc":"`ConvertArmSMEToSCF`","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_scf/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_arm_sme_to_scf/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_scf/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_async_to_llvm/0","doc":"Convert the operations from the async dialect into the LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_async_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_async_to_llvm/0","doc":"`convert-async-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_async_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_async_to_llvm/0","doc":"`ConvertAsyncToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_async_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_async_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_async_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_bufferization_to_memref/0","doc":"Convert operations from the Bufferization dialect to the MemRef dialect","ref":"Beaver.MLIR.Conversion.html#convert_bufferization_to_memref/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_bufferization_to_memref/0","doc":"`convert-bufferization-to-memref`","ref":"Beaver.MLIR.Conversion.html#convert_bufferization_to_memref/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_bufferization_to_memref/0","doc":"`ConvertBufferizationToMemRef`","ref":"Beaver.MLIR.Conversion.html#convert_bufferization_to_memref/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_bufferization_to_memref/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_bufferization_to_memref/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_cf_to_llvm/0","doc":"Convert ControlFlow operations to the LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_cf_to_llvm/0","doc":"`convert-cf-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_cf_to_llvm/0","doc":"`ConvertControlFlowToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_cf_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_cf_to_spirv/0","doc":"Convert ControlFlow dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_cf_to_spirv/0","doc":"`convert-cf-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_cf_to_spirv/0","doc":"`ConvertControlFlowToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_cf_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_complex_to_libm/0","doc":"Convert Complex dialect to libm calls","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_libm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_complex_to_libm/0","doc":"`convert-complex-to-libm`","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_libm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_complex_to_libm/0","doc":"`ConvertComplexToLibm`","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_libm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_complex_to_libm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_libm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_complex_to_llvm/0","doc":"Convert Complex dialect to LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_complex_to_llvm/0","doc":"`convert-complex-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_complex_to_llvm/0","doc":"`ConvertComplexToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_complex_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_complex_to_spirv/0","doc":"Convert Complex dialect to SPIRV dialect","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_complex_to_spirv/0","doc":"`convert-complex-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_complex_to_spirv/0","doc":"`ConvertComplexToSPIRVPass`","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_complex_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_complex_to_standard/0","doc":"Convert Complex dialect to standard dialect","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_standard/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_complex_to_standard/0","doc":"`convert-complex-to-standard`","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_standard/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_complex_to_standard/0","doc":"`ConvertComplexToStandard`","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_standard/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_complex_to_standard/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_standard/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_func_to_emitc/0","doc":"Convert Func dialect to EmitC dialect","ref":"Beaver.MLIR.Conversion.html#convert_func_to_emitc/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_func_to_emitc/0","doc":"`convert-func-to-emitc`","ref":"Beaver.MLIR.Conversion.html#convert_func_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_func_to_emitc/0","doc":"`ConvertFuncToEmitC`","ref":"Beaver.MLIR.Conversion.html#convert_func_to_emitc/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_func_to_emitc/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_func_to_emitc/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_func_to_llvm/0","doc":"Convert from the Func dialect to the LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_func_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_func_to_llvm/0","doc":"`convert-func-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_func_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_func_to_llvm/0","doc":"`ConvertFuncToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_func_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_func_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_func_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_func_to_spirv/0","doc":"Convert Func dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_func_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_func_to_spirv/0","doc":"`convert-func-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_func_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_func_to_spirv/0","doc":"`ConvertFuncToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_func_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_func_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_func_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_launch_to_vulkan_launch/0","doc":"Convert gpu.launch_func to vulkanLaunch external call","ref":"Beaver.MLIR.Conversion.html#convert_gpu_launch_to_vulkan_launch/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_launch_to_vulkan_launch/0","doc":"`convert-gpu-launch-to-vulkan-launch`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_launch_to_vulkan_launch/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_launch_to_vulkan_launch/0","doc":"`ConvertGpuLaunchFuncToVulkanLaunchFunc`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_launch_to_vulkan_launch/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_launch_to_vulkan_launch/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_gpu_launch_to_vulkan_launch/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_to_llvm_spv/0","doc":"Generate LLVM operations to be ingested by a SPIR-V backend for gpu operations","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_llvm_spv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_to_llvm_spv/0","doc":"`convert-gpu-to-llvm-spv`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_llvm_spv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_to_llvm_spv/0","doc":"`ConvertGpuOpsToLLVMSPVOps`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_llvm_spv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_to_llvm_spv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_llvm_spv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_to_nvvm/0","doc":"Generate NVVM operations for gpu operations","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_nvvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_to_nvvm/0","doc":"`convert-gpu-to-nvvm`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_nvvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_to_nvvm/0","doc":"`ConvertGpuOpsToNVVMOps`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_nvvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_to_nvvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_nvvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_to_rocdl/0","doc":"Generate ROCDL operations for gpu operations","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_rocdl/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_to_rocdl/0","doc":"`convert-gpu-to-rocdl`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_rocdl/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_to_rocdl/0","doc":"`ConvertGpuOpsToROCDLOps`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_rocdl/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_to_rocdl/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_rocdl/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_to_spirv/0","doc":"Convert GPU dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_to_spirv/0","doc":"`convert-gpu-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_to_spirv/0","doc":"`ConvertGPUToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_gpu_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_index_to_llvm/0","doc":"Lower the `index` dialect to the `llvm` dialect.","ref":"Beaver.MLIR.Conversion.html#convert_index_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_index_to_llvm/0","doc":"`convert-index-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_index_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_index_to_llvm/0","doc":"`ConvertIndexToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_index_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_index_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_index_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_index_to_spirv/0","doc":"Lower the `index` dialect to the `spirv` dialect.","ref":"Beaver.MLIR.Conversion.html#convert_index_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_index_to_spirv/0","doc":"`convert-index-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_index_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_index_to_spirv/0","doc":"`ConvertIndexToSPIRVPass`","ref":"Beaver.MLIR.Conversion.html#convert_index_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_index_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_index_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_linalg_to_std/0","doc":"Convert the operations from the linalg dialect into the Standard dialect","ref":"Beaver.MLIR.Conversion.html#convert_linalg_to_std/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_linalg_to_std/0","doc":"`convert-linalg-to-std`","ref":"Beaver.MLIR.Conversion.html#convert_linalg_to_std/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_linalg_to_std/0","doc":"`ConvertLinalgToStandard`","ref":"Beaver.MLIR.Conversion.html#convert_linalg_to_std/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_linalg_to_std/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_linalg_to_std/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_funcs/0","doc":"Convert Math operations to calls of outlined implementations.","ref":"Beaver.MLIR.Conversion.html#convert_math_to_funcs/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_funcs/0","doc":"`convert-math-to-funcs`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_funcs/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_funcs/0","doc":"`ConvertMathToFuncs`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_funcs/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_funcs/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_math_to_funcs/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_libm/0","doc":"Convert Math dialect to libm calls","ref":"Beaver.MLIR.Conversion.html#convert_math_to_libm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_libm/0","doc":"`convert-math-to-libm`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_libm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_libm/0","doc":"`ConvertMathToLibm`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_libm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_libm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_math_to_libm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_llvm/0","doc":"Convert Math dialect to LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_math_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_llvm/0","doc":"`convert-math-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_llvm/0","doc":"`ConvertMathToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_math_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_rocdl/0","doc":"Convert Math dialect to ROCDL library calls","ref":"Beaver.MLIR.Conversion.html#convert_math_to_rocdl/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_rocdl/0","doc":"`convert-math-to-rocdl`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_rocdl/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_rocdl/0","doc":"`ConvertMathToROCDL`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_rocdl/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_rocdl/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_math_to_rocdl/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_spirv/0","doc":"Convert Math dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_math_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_spirv/0","doc":"`convert-math-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_spirv/0","doc":"`ConvertMathToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_math_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_math_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_math_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_memref_to_emitc/0","doc":"Convert MemRef dialect to EmitC dialect","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_emitc/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_memref_to_emitc/0","doc":"`convert-memref-to-emitc`","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_memref_to_emitc/0","doc":"`ConvertMemRefToEmitC`","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_emitc/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_memref_to_emitc/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_emitc/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_memref_to_spirv/0","doc":"Convert MemRef dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_memref_to_spirv/0","doc":"`convert-memref-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_memref_to_spirv/0","doc":"`ConvertMemRefToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_memref_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_nvgpu_to_nvvm/0","doc":"Convert NVGPU dialect to NVVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_nvgpu_to_nvvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_nvgpu_to_nvvm/0","doc":"`convert-nvgpu-to-nvvm`","ref":"Beaver.MLIR.Conversion.html#convert_nvgpu_to_nvvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_nvgpu_to_nvvm/0","doc":"`ConvertNVGPUToNVVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_nvgpu_to_nvvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_nvgpu_to_nvvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_nvgpu_to_nvvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_nvvm_to_llvm/0","doc":"Convert NVVM to PTX with Inline Assembly in LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_nvvm_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_nvvm_to_llvm/0","doc":"`convert-nvvm-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_nvvm_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_nvvm_to_llvm/0","doc":"`ConvertNVVMToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_nvvm_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_nvvm_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_nvvm_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_openacc_to_scf/0","doc":"Convert the OpenACC ops to OpenACC with SCF dialect","ref":"Beaver.MLIR.Conversion.html#convert_openacc_to_scf/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_openacc_to_scf/0","doc":"`convert-openacc-to-scf`","ref":"Beaver.MLIR.Conversion.html#convert_openacc_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_openacc_to_scf/0","doc":"`ConvertOpenACCToSCF`","ref":"Beaver.MLIR.Conversion.html#convert_openacc_to_scf/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_openacc_to_scf/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_openacc_to_scf/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_openmp_to_llvm/0","doc":"Convert the OpenMP ops to OpenMP ops with LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_openmp_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_openmp_to_llvm/0","doc":"`convert-openmp-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_openmp_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_openmp_to_llvm/0","doc":"`ConvertOpenMPToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_openmp_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_openmp_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_openmp_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_parallel_loops_to_gpu/0","doc":"Convert mapped scf.parallel ops to gpu launch operations","ref":"Beaver.MLIR.Conversion.html#convert_parallel_loops_to_gpu/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_parallel_loops_to_gpu/0","doc":"`convert-parallel-loops-to-gpu`","ref":"Beaver.MLIR.Conversion.html#convert_parallel_loops_to_gpu/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_parallel_loops_to_gpu/0","doc":"`ConvertParallelLoopToGpu`","ref":"Beaver.MLIR.Conversion.html#convert_parallel_loops_to_gpu/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_parallel_loops_to_gpu/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_parallel_loops_to_gpu/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_pdl_to_pdl_interp/0","doc":"Convert PDL ops to PDL interpreter ops","ref":"Beaver.MLIR.Conversion.html#convert_pdl_to_pdl_interp/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_pdl_to_pdl_interp/0","doc":"`convert-pdl-to-pdl-interp`","ref":"Beaver.MLIR.Conversion.html#convert_pdl_to_pdl_interp/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_pdl_to_pdl_interp/0","doc":"`ConvertPDLToPDLInterp`","ref":"Beaver.MLIR.Conversion.html#convert_pdl_to_pdl_interp/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_pdl_to_pdl_interp/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_pdl_to_pdl_interp/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_scf_to_cf/0","doc":"Convert SCF dialect to ControlFlow dialect, replacing structured control flow with a CFG","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_cf/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_scf_to_cf/0","doc":"`convert-scf-to-cf`","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_cf/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_scf_to_cf/0","doc":"`SCFToControlFlow`","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_cf/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_scf_to_cf/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_cf/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_scf_to_emitc/0","doc":"Convert SCF dialect to EmitC dialect, maintaining structured control flow","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_emitc/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_scf_to_emitc/0","doc":"`convert-scf-to-emitc`","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_scf_to_emitc/0","doc":"`SCFToEmitC`","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_emitc/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_scf_to_emitc/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_emitc/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_scf_to_openmp/0","doc":"Convert SCF parallel loop to OpenMP parallel + workshare constructs.","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_openmp/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_scf_to_openmp/0","doc":"`convert-scf-to-openmp`","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_openmp/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_scf_to_openmp/0","doc":"`ConvertSCFToOpenMPPass`","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_openmp/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_scf_to_openmp/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_openmp/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_scf_to_spirv/0","doc":"Convert SCF dialect to SPIR-V dialect.","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_scf_to_spirv/0","doc":"`convert-scf-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_scf_to_spirv/0","doc":"`SCFToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_scf_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_shape_constraints/0","doc":"Convert shape constraint operations to the standard dialect","ref":"Beaver.MLIR.Conversion.html#convert_shape_constraints/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_shape_constraints/0","doc":"`convert-shape-constraints`","ref":"Beaver.MLIR.Conversion.html#convert_shape_constraints/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_shape_constraints/0","doc":"`ConvertShapeConstraints`","ref":"Beaver.MLIR.Conversion.html#convert_shape_constraints/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_shape_constraints/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_shape_constraints/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_shape_to_std/0","doc":"Convert operations from the shape dialect into the standard dialect","ref":"Beaver.MLIR.Conversion.html#convert_shape_to_std/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_shape_to_std/0","doc":"`convert-shape-to-std`","ref":"Beaver.MLIR.Conversion.html#convert_shape_to_std/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_shape_to_std/0","doc":"`ConvertShapeToStandard`","ref":"Beaver.MLIR.Conversion.html#convert_shape_to_std/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_shape_to_std/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_shape_to_std/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_spirv_to_llvm/0","doc":"Convert SPIR-V dialect to LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_spirv_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_spirv_to_llvm/0","doc":"`convert-spirv-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_spirv_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_spirv_to_llvm/0","doc":"`ConvertSPIRVToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_spirv_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_spirv_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_spirv_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_tensor_to_linalg/0","doc":"Convert some Tensor dialect ops to Linalg dialect","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_linalg/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_tensor_to_linalg/0","doc":"`convert-tensor-to-linalg`","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_linalg/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_tensor_to_linalg/0","doc":"`ConvertTensorToLinalg`","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_linalg/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_tensor_to_linalg/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_linalg/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_tensor_to_spirv/0","doc":"Convert Tensor dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_tensor_to_spirv/0","doc":"`convert-tensor-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_tensor_to_spirv/0","doc":"`ConvertTensorToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_tensor_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_to_llvm/0","doc":"Convert to LLVM via dialect interfaces found in the input IR","ref":"Beaver.MLIR.Conversion.html#convert_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_to_llvm/0","doc":"`convert-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_to_llvm/0","doc":"`ConvertToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_to_spirv/0","doc":"Convert to SPIR-V","ref":"Beaver.MLIR.Conversion.html#convert_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_to_spirv/0","doc":"`convert-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_to_spirv/0","doc":"`ConvertToSPIRVPass`","ref":"Beaver.MLIR.Conversion.html#convert_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_ub_to_llvm/0","doc":"Convert UB dialect to LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_ub_to_llvm/0","doc":"`convert-ub-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_ub_to_llvm/0","doc":"`UBToLLVMConversionPass`","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_ub_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_ub_to_spirv/0","doc":"Convert UB dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_ub_to_spirv/0","doc":"`convert-ub-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_ub_to_spirv/0","doc":"`UBToSPIRVConversionPass`","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_ub_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_arm_sme/0","doc":"Lower the operations from the vector dialect into the ArmSME dialect","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_arm_sme/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_arm_sme/0","doc":"`convert-vector-to-arm-sme`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_arm_sme/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_arm_sme/0","doc":"`ConvertVectorToArmSME`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_arm_sme/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_arm_sme/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_arm_sme/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_gpu/0","doc":"Lower the operations from the vector dialect into the GPU dialect","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_gpu/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_gpu/0","doc":"`convert-vector-to-gpu`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_gpu/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_gpu/0","doc":"`ConvertVectorToGPU`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_gpu/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_gpu/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_gpu/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_llvm/0","doc":"Lower the operations from the vector dialect into the LLVM dialect","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_llvm/0","doc":"`convert-vector-to-llvm`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_llvm/0","doc":"`ConvertVectorToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_scf/0","doc":"Lower the operations from the vector dialect into the SCF dialect","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_scf/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_scf/0","doc":"`convert-vector-to-scf`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_scf/0","doc":"`ConvertVectorToSCF`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_scf/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_scf/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_scf/1"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_spirv/0","doc":"Convert Vector dialect to SPIR-V dialect","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_spirv/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_spirv/0","doc":"`convert-vector-to-spirv`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_spirv/0","doc":"`ConvertVectorToSPIRV`","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_spirv/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.convert_vector_to_spirv/1","doc":"","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_spirv/1"},{"type":"function","title":"Beaver.MLIR.Conversion.finalize_memref_to_llvm/0","doc":"Finalize MemRef dialect to LLVM dialect conversion","ref":"Beaver.MLIR.Conversion.html#finalize_memref_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.finalize_memref_to_llvm/0","doc":"`finalize-memref-to-llvm`","ref":"Beaver.MLIR.Conversion.html#finalize_memref_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.finalize_memref_to_llvm/0","doc":"`FinalizeMemRefToLLVMConversionPass`","ref":"Beaver.MLIR.Conversion.html#finalize_memref_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.finalize_memref_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#finalize_memref_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.gpu_to_llvm/0","doc":"Convert GPU dialect to LLVM dialect with GPU runtime calls","ref":"Beaver.MLIR.Conversion.html#gpu_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.gpu_to_llvm/0","doc":"`gpu-to-llvm`","ref":"Beaver.MLIR.Conversion.html#gpu_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.gpu_to_llvm/0","doc":"`GpuToLLVMConversionPass`","ref":"Beaver.MLIR.Conversion.html#gpu_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.gpu_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#gpu_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.launch_func_to_vulkan/0","doc":"Convert vulkanLaunch external call to Vulkan runtime external calls","ref":"Beaver.MLIR.Conversion.html#launch_func_to_vulkan/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.launch_func_to_vulkan/0","doc":"`launch-func-to-vulkan`","ref":"Beaver.MLIR.Conversion.html#launch_func_to_vulkan/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.launch_func_to_vulkan/0","doc":"`ConvertVulkanLaunchFuncToVulkanCallsPass`","ref":"Beaver.MLIR.Conversion.html#launch_func_to_vulkan/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.launch_func_to_vulkan/1","doc":"","ref":"Beaver.MLIR.Conversion.html#launch_func_to_vulkan/1"},{"type":"function","title":"Beaver.MLIR.Conversion.lift_cf_to_scf/0","doc":"Lift ControlFlow dialect to SCF dialect","ref":"Beaver.MLIR.Conversion.html#lift_cf_to_scf/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.lift_cf_to_scf/0","doc":"`lift-cf-to-scf`","ref":"Beaver.MLIR.Conversion.html#lift_cf_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.lift_cf_to_scf/0","doc":"`LiftControlFlowToSCFPass`","ref":"Beaver.MLIR.Conversion.html#lift_cf_to_scf/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.lift_cf_to_scf/1","doc":"","ref":"Beaver.MLIR.Conversion.html#lift_cf_to_scf/1"},{"type":"function","title":"Beaver.MLIR.Conversion.lower_affine/0","doc":"Lower Affine operations to a combination of Standard and SCF operations","ref":"Beaver.MLIR.Conversion.html#lower_affine/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.lower_affine/0","doc":"`lower-affine`","ref":"Beaver.MLIR.Conversion.html#lower_affine/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.lower_affine/0","doc":"`ConvertAffineToStandard`","ref":"Beaver.MLIR.Conversion.html#lower_affine/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.lower_affine/1","doc":"","ref":"Beaver.MLIR.Conversion.html#lower_affine/1"},{"type":"function","title":"Beaver.MLIR.Conversion.lower_host_to_llvm/0","doc":"Lowers the host module code and `gpu.launch_func` to LLVM","ref":"Beaver.MLIR.Conversion.html#lower_host_to_llvm/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.lower_host_to_llvm/0","doc":"`lower-host-to-llvm`","ref":"Beaver.MLIR.Conversion.html#lower_host_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.lower_host_to_llvm/0","doc":"`LowerHostCodeToLLVMPass`","ref":"Beaver.MLIR.Conversion.html#lower_host_to_llvm/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.lower_host_to_llvm/1","doc":"","ref":"Beaver.MLIR.Conversion.html#lower_host_to_llvm/1"},{"type":"function","title":"Beaver.MLIR.Conversion.map_memref_spirv_storage_class/0","doc":"Map numeric MemRef memory spaces to SPIR-V storage classes","ref":"Beaver.MLIR.Conversion.html#map_memref_spirv_storage_class/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.map_memref_spirv_storage_class/0","doc":"`map-memref-spirv-storage-class`","ref":"Beaver.MLIR.Conversion.html#map_memref_spirv_storage_class/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.map_memref_spirv_storage_class/0","doc":"`MapMemRefStorageClass`","ref":"Beaver.MLIR.Conversion.html#map_memref_spirv_storage_class/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.map_memref_spirv_storage_class/1","doc":"","ref":"Beaver.MLIR.Conversion.html#map_memref_spirv_storage_class/1"},{"type":"function","title":"Beaver.MLIR.Conversion.reconcile_unrealized_casts/0","doc":"Simplify and eliminate unrealized conversion casts","ref":"Beaver.MLIR.Conversion.html#reconcile_unrealized_casts/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.reconcile_unrealized_casts/0","doc":"`reconcile-unrealized-casts`","ref":"Beaver.MLIR.Conversion.html#reconcile_unrealized_casts/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.reconcile_unrealized_casts/0","doc":"`ReconcileUnrealizedCasts`","ref":"Beaver.MLIR.Conversion.html#reconcile_unrealized_casts/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.reconcile_unrealized_casts/1","doc":"","ref":"Beaver.MLIR.Conversion.html#reconcile_unrealized_casts/1"},{"type":"function","title":"Beaver.MLIR.Conversion.set_llvm_module_datalayout/0","doc":"Attach a datalayout string as a module attribute","ref":"Beaver.MLIR.Conversion.html#set_llvm_module_datalayout/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.set_llvm_module_datalayout/0","doc":"`set-llvm-module-datalayout`","ref":"Beaver.MLIR.Conversion.html#set_llvm_module_datalayout/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.set_llvm_module_datalayout/0","doc":"`SetLLVMModuleDataLayoutPass`","ref":"Beaver.MLIR.Conversion.html#set_llvm_module_datalayout/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.set_llvm_module_datalayout/1","doc":"","ref":"Beaver.MLIR.Conversion.html#set_llvm_module_datalayout/1"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_arith/0","doc":"Lower TOSA to the Arith dialect","ref":"Beaver.MLIR.Conversion.html#tosa_to_arith/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_arith/0","doc":"`tosa-to-arith`","ref":"Beaver.MLIR.Conversion.html#tosa_to_arith/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_arith/0","doc":"`TosaToArith`","ref":"Beaver.MLIR.Conversion.html#tosa_to_arith/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_arith/1","doc":"","ref":"Beaver.MLIR.Conversion.html#tosa_to_arith/1"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_linalg/0","doc":"Lower TOSA to LinAlg on tensors","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_linalg/0","doc":"`tosa-to-linalg`","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_linalg/0","doc":"`TosaToLinalg`","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_linalg/1","doc":"","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg/1"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_linalg_named/0","doc":"Lower TOSA to LinAlg named operations","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg_named/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_linalg_named/0","doc":"`tosa-to-linalg-named`","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg_named/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_linalg_named/0","doc":"`TosaToLinalgNamed`","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg_named/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_linalg_named/1","doc":"","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg_named/1"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_mlprogram/0","doc":"Lower TOSA to the MLProgram dialect","ref":"Beaver.MLIR.Conversion.html#tosa_to_mlprogram/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_mlprogram/0","doc":"`tosa-to-mlprogram`","ref":"Beaver.MLIR.Conversion.html#tosa_to_mlprogram/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_mlprogram/0","doc":"`TosaToMLProgram`","ref":"Beaver.MLIR.Conversion.html#tosa_to_mlprogram/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_mlprogram/1","doc":"","ref":"Beaver.MLIR.Conversion.html#tosa_to_mlprogram/1"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_scf/0","doc":"Lower TOSA to the SCF dialect","ref":"Beaver.MLIR.Conversion.html#tosa_to_scf/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_scf/0","doc":"`tosa-to-scf`","ref":"Beaver.MLIR.Conversion.html#tosa_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_scf/0","doc":"`TosaToSCF`","ref":"Beaver.MLIR.Conversion.html#tosa_to_scf/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_scf/1","doc":"","ref":"Beaver.MLIR.Conversion.html#tosa_to_scf/1"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_tensor/0","doc":"Lower TOSA to the Tensor dialect","ref":"Beaver.MLIR.Conversion.html#tosa_to_tensor/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_tensor/0","doc":"`tosa-to-tensor`","ref":"Beaver.MLIR.Conversion.html#tosa_to_tensor/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_tensor/0","doc":"`TosaToTensor`","ref":"Beaver.MLIR.Conversion.html#tosa_to_tensor/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Conversion.tosa_to_tensor/1","doc":"","ref":"Beaver.MLIR.Conversion.html#tosa_to_tensor/1"},{"type":"module","title":"Beaver.MLIR.Diagnostic","doc":"","ref":"Beaver.MLIR.Diagnostic.html"},{"type":"function","title":"Beaver.MLIR.Diagnostic.make/1","doc":"","ref":"Beaver.MLIR.Diagnostic.html#make/1"},{"type":"type","title":"Beaver.MLIR.Diagnostic.t/0","doc":"","ref":"Beaver.MLIR.Diagnostic.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.DiagnosticHandler","doc":"","ref":"Beaver.MLIR.DiagnosticHandler.html"},{"type":"function","title":"Beaver.MLIR.DiagnosticHandler.make/1","doc":"","ref":"Beaver.MLIR.DiagnosticHandler.html#make/1"},{"type":"type","title":"Beaver.MLIR.DiagnosticHandler.t/0","doc":"","ref":"Beaver.MLIR.DiagnosticHandler.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.DiagnosticHandlerID","doc":"","ref":"Beaver.MLIR.DiagnosticHandlerID.html"},{"type":"function","title":"Beaver.MLIR.DiagnosticHandlerID.make/1","doc":"","ref":"Beaver.MLIR.DiagnosticHandlerID.html#make/1"},{"type":"type","title":"Beaver.MLIR.DiagnosticHandlerID.t/0","doc":"","ref":"Beaver.MLIR.DiagnosticHandlerID.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.DiagnosticSeverity","doc":"","ref":"Beaver.MLIR.DiagnosticSeverity.html"},{"type":"function","title":"Beaver.MLIR.DiagnosticSeverity.make/1","doc":"","ref":"Beaver.MLIR.DiagnosticSeverity.html#make/1"},{"type":"type","title":"Beaver.MLIR.DiagnosticSeverity.t/0","doc":"","ref":"Beaver.MLIR.DiagnosticSeverity.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.ExecutionEngine","doc":"This module defines functions working with MLIR ExecutionEngine.","ref":"Beaver.MLIR.ExecutionEngine.html"},{"type":"function","title":"Beaver.MLIR.ExecutionEngine.create!/1","doc":"Create a MLIR JIT engine for a module and check if successful. Usually this module should be of LLVM dialect.","ref":"Beaver.MLIR.ExecutionEngine.html#create!/1"},{"type":"function","title":"Beaver.MLIR.ExecutionEngine.create!/2","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#create!/2"},{"type":"function","title":"Beaver.MLIR.ExecutionEngine.destroy/1","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#destroy/1"},{"type":"function","title":"Beaver.MLIR.ExecutionEngine.invoke!/5","doc":"invoke a function by symbol name.","ref":"Beaver.MLIR.ExecutionEngine.html#invoke!/5"},{"type":"function","title":"Beaver.MLIR.ExecutionEngine.is_null/1","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#is_null/1"},{"type":"function","title":"Beaver.MLIR.ExecutionEngine.make/1","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#make/1"},{"type":"type","title":"Beaver.MLIR.ExecutionEngine.dirty/0","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#t:dirty/0"},{"type":"type","title":"Beaver.MLIR.ExecutionEngine.invoke_opts/0","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#t:invoke_opts/0"},{"type":"type","title":"Beaver.MLIR.ExecutionEngine.object_dump/0","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#t:object_dump/0"},{"type":"type","title":"Beaver.MLIR.ExecutionEngine.opt_level/0","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#t:opt_level/0"},{"type":"type","title":"Beaver.MLIR.ExecutionEngine.opts/0","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#t:opts/0"},{"type":"type","title":"Beaver.MLIR.ExecutionEngine.shared_lib_path/0","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#t:shared_lib_path/0"},{"type":"type","title":"Beaver.MLIR.ExecutionEngine.t/0","doc":"","ref":"Beaver.MLIR.ExecutionEngine.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.ExternalPassCallbacks","doc":"","ref":"Beaver.MLIR.ExternalPassCallbacks.html"},{"type":"function","title":"Beaver.MLIR.ExternalPassCallbacks.make/1","doc":"","ref":"Beaver.MLIR.ExternalPassCallbacks.html#make/1"},{"type":"type","title":"Beaver.MLIR.ExternalPassCallbacks.t/0","doc":"","ref":"Beaver.MLIR.ExternalPassCallbacks.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Identifier","doc":"This module defines functions working with MLIR Identifier.","ref":"Beaver.MLIR.Identifier.html"},{"type":"function","title":"Beaver.MLIR.Identifier.make/1","doc":"","ref":"Beaver.MLIR.Identifier.html#make/1"},{"type":"type","title":"Beaver.MLIR.Identifier.t/0","doc":"","ref":"Beaver.MLIR.Identifier.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.IntegerSet","doc":"","ref":"Beaver.MLIR.IntegerSet.html"},{"type":"function","title":"Beaver.MLIR.IntegerSet.make/1","doc":"","ref":"Beaver.MLIR.IntegerSet.html#make/1"},{"type":"type","title":"Beaver.MLIR.IntegerSet.t/0","doc":"","ref":"Beaver.MLIR.IntegerSet.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.LLVMThreadPool","doc":"","ref":"Beaver.MLIR.LLVMThreadPool.html"},{"type":"function","title":"Beaver.MLIR.LLVMThreadPool.make/1","doc":"","ref":"Beaver.MLIR.LLVMThreadPool.html#make/1"},{"type":"type","title":"Beaver.MLIR.LLVMThreadPool.t/0","doc":"","ref":"Beaver.MLIR.LLVMThreadPool.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Location","doc":"This module defines functions working with MLIR Location.","ref":"Beaver.MLIR.Location.html"},{"type":"function","title":"Beaver.MLIR.Location.file/1","doc":"Get a location of file line. Column is zero by default because in Elixir it is usually omitted.","ref":"Beaver.MLIR.Location.html#file/1"},{"type":"function","title":"Examples - Beaver.MLIR.Location.file/1","doc":"iex> ctx = MLIR.Context.create()\n    iex> MLIR.Location.file(name: \"filename\", line: 1, column: 1, ctx: ctx) |> MLIR.to_string()\n    ~s{filename:1:1}\n    iex> ctx |> MLIR.Context.destroy","ref":"Beaver.MLIR.Location.html#file/1-examples"},{"type":"function","title":"Beaver.MLIR.Location.from_env/2","doc":"Create an MLIR location from `Macro.Env`","ref":"Beaver.MLIR.Location.html#from_env/2"},{"type":"function","title":"Beaver.MLIR.Location.make/1","doc":"","ref":"Beaver.MLIR.Location.html#make/1"},{"type":"function","title":"Beaver.MLIR.Location.unknown/1","doc":"","ref":"Beaver.MLIR.Location.html#unknown/1"},{"type":"type","title":"Beaver.MLIR.Location.file_opts/0","doc":"","ref":"Beaver.MLIR.Location.html#t:file_opts/0"},{"type":"type","title":"Beaver.MLIR.Location.t/0","doc":"","ref":"Beaver.MLIR.Location.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.LogicalResult","doc":"This module defines functions working with MLIR LogicalResult.","ref":"Beaver.MLIR.LogicalResult.html"},{"type":"function","title":"Beaver.MLIR.LogicalResult.make/1","doc":"","ref":"Beaver.MLIR.LogicalResult.html#make/1"},{"type":"function","title":"Beaver.MLIR.LogicalResult.success?/1","doc":"","ref":"Beaver.MLIR.LogicalResult.html#success?/1"},{"type":"type","title":"Beaver.MLIR.LogicalResult.t/0","doc":"","ref":"Beaver.MLIR.LogicalResult.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Module","doc":"This module defines functions working with MLIR Module.","ref":"Beaver.MLIR.Module.html"},{"type":"function","title":"Beaver.MLIR.Module.body/1","doc":"","ref":"Beaver.MLIR.Module.html#body/1"},{"type":"function","title":"Beaver.MLIR.Module.create/2","doc":"","ref":"Beaver.MLIR.Module.html#create/2"},{"type":"function","title":"Beaver.MLIR.Module.create!/2","doc":"","ref":"Beaver.MLIR.Module.html#create!/2"},{"type":"function","title":"Beaver.MLIR.Module.destroy/1","doc":"","ref":"Beaver.MLIR.Module.html#destroy/1"},{"type":"function","title":"Beaver.MLIR.Module.empty/1","doc":"","ref":"Beaver.MLIR.Module.html#empty/1"},{"type":"function","title":"Beaver.MLIR.Module.from_operation/1","doc":"","ref":"Beaver.MLIR.Module.html#from_operation/1"},{"type":"function","title":"Beaver.MLIR.Module.is_null/1","doc":"","ref":"Beaver.MLIR.Module.html#is_null/1"},{"type":"function","title":"Beaver.MLIR.Module.make/1","doc":"","ref":"Beaver.MLIR.Module.html#make/1"},{"type":"function","title":"Beaver.MLIR.Module.verify!/1","doc":"","ref":"Beaver.MLIR.Module.html#verify!/1"},{"type":"type","title":"Beaver.MLIR.Module.t/0","doc":"","ref":"Beaver.MLIR.Module.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.NamedAttribute","doc":"This module defines a wrapper struct of NamedAttribute in MLIR","ref":"Beaver.MLIR.NamedAttribute.html"},{"type":"function","title":"Beaver.MLIR.NamedAttribute.make/1","doc":"","ref":"Beaver.MLIR.NamedAttribute.html#make/1"},{"type":"type","title":"Beaver.MLIR.NamedAttribute.t/0","doc":"","ref":"Beaver.MLIR.NamedAttribute.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.ODS","doc":"ODS helper functions to work with special concepts in ODS.","ref":"Beaver.MLIR.ODS.html"},{"type":"function","title":"Beaver.MLIR.ODS.operand_segment_sizes/1","doc":"Generate attribute for operand_segment_sizes","ref":"Beaver.MLIR.ODS.html#operand_segment_sizes/1"},{"type":"function","title":"Beaver.MLIR.ODS.result_segment_sizes/1","doc":"","ref":"Beaver.MLIR.ODS.html#result_segment_sizes/1"},{"type":"module","title":"Beaver.MLIR.OpOperand","doc":"This module defines functions working with MLIR OpOperand.","ref":"Beaver.MLIR.OpOperand.html"},{"type":"function","title":"Beaver.MLIR.OpOperand.make/1","doc":"","ref":"Beaver.MLIR.OpOperand.html#make/1"},{"type":"type","title":"Beaver.MLIR.OpOperand.t/0","doc":"","ref":"Beaver.MLIR.OpOperand.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.OpPassManager","doc":"","ref":"Beaver.MLIR.OpPassManager.html"},{"type":"function","title":"Beaver.MLIR.OpPassManager.make/1","doc":"","ref":"Beaver.MLIR.OpPassManager.html#make/1"},{"type":"type","title":"Beaver.MLIR.OpPassManager.t/0","doc":"","ref":"Beaver.MLIR.OpPassManager.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.OpPrintingFlags","doc":"","ref":"Beaver.MLIR.OpPrintingFlags.html"},{"type":"function","title":"Beaver.MLIR.OpPrintingFlags.make/1","doc":"","ref":"Beaver.MLIR.OpPrintingFlags.html#make/1"},{"type":"type","title":"Beaver.MLIR.OpPrintingFlags.t/0","doc":"","ref":"Beaver.MLIR.OpPrintingFlags.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Operation","doc":"This module defines functions working with MLIR Operation.","ref":"Beaver.MLIR.Operation.html"},{"type":"function","title":"Beaver.MLIR.Operation.create/1","doc":"","ref":"Beaver.MLIR.Operation.html#create/1"},{"type":"function","title":"Beaver.MLIR.Operation.dump/1","doc":"","ref":"Beaver.MLIR.Operation.html#dump/1"},{"type":"function","title":"Beaver.MLIR.Operation.dump!/1","doc":"Verify the op and dump it. It raises if the verification fails.","ref":"Beaver.MLIR.Operation.html#dump!/1"},{"type":"function","title":"Beaver.MLIR.Operation.equal?/2","doc":"","ref":"Beaver.MLIR.Operation.html#equal?/2"},{"type":"function","title":"Beaver.MLIR.Operation.from_module/1","doc":"","ref":"Beaver.MLIR.Operation.html#from_module/1"},{"type":"function","title":"Beaver.MLIR.Operation.location/1","doc":"","ref":"Beaver.MLIR.Operation.html#location/1"},{"type":"function","title":"Beaver.MLIR.Operation.make/1","doc":"","ref":"Beaver.MLIR.Operation.html#make/1"},{"type":"function","title":"Beaver.MLIR.Operation.name/1","doc":"","ref":"Beaver.MLIR.Operation.html#name/1"},{"type":"function","title":"Beaver.MLIR.Operation.parent/1","doc":"","ref":"Beaver.MLIR.Operation.html#parent/1"},{"type":"function","title":"Beaver.MLIR.Operation.results/1","doc":"","ref":"Beaver.MLIR.Operation.html#results/1"},{"type":"function","title":"Beaver.MLIR.Operation.verify/2","doc":"","ref":"Beaver.MLIR.Operation.html#verify/2"},{"type":"function","title":"Beaver.MLIR.Operation.verify!/2","doc":"","ref":"Beaver.MLIR.Operation.html#verify!/2"},{"type":"type","title":"Beaver.MLIR.Operation.t/0","doc":"","ref":"Beaver.MLIR.Operation.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.OperationWalkCallback","doc":"","ref":"Beaver.MLIR.OperationWalkCallback.html"},{"type":"function","title":"Beaver.MLIR.OperationWalkCallback.make/1","doc":"","ref":"Beaver.MLIR.OperationWalkCallback.html#make/1"},{"type":"type","title":"Beaver.MLIR.OperationWalkCallback.t/0","doc":"","ref":"Beaver.MLIR.OperationWalkCallback.html#t:t/0"},{"type":"behaviour","title":"Beaver.MLIR.Pass","doc":"This module defines functions working with MLIR Pass.","ref":"Beaver.MLIR.Pass.html"},{"type":"function","title":"Beaver.MLIR.Pass.ensure_all_registered!/0","doc":"Ensure all passes are registered with the global registry.","ref":"Beaver.MLIR.Pass.html#ensure_all_registered!/0"},{"type":"function","title":"Beaver.MLIR.Pass.make/1","doc":"","ref":"Beaver.MLIR.Pass.html#make/1"},{"type":"callback","title":"Beaver.MLIR.Pass.run/1","doc":"","ref":"Beaver.MLIR.Pass.html#c:run/1"},{"type":"type","title":"Beaver.MLIR.Pass.t/0","doc":"","ref":"Beaver.MLIR.Pass.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Pass.Composer","doc":"This module provide functions to compose passes.","ref":"Beaver.MLIR.Pass.Composer.html"},{"type":"function","title":"Beaver.MLIR.Pass.Composer.append/2","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#append/2"},{"type":"function","title":"Beaver.MLIR.Pass.Composer.nested/3","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#nested/3"},{"type":"function","title":"Beaver.MLIR.Pass.Composer.new/1","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#new/1"},{"type":"function","title":"Beaver.MLIR.Pass.Composer.run/2","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#run/2"},{"type":"function","title":"Beaver.MLIR.Pass.Composer.run!/2","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#run!/2"},{"type":"function","title":"Beaver.MLIR.Pass.Composer.to_pipeline/1","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#to_pipeline/1"},{"type":"type","title":"Beaver.MLIR.Pass.Composer.composer/0","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#t:composer/0"},{"type":"type","title":"Beaver.MLIR.Pass.Composer.operation/0","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#t:operation/0"},{"type":"type","title":"Beaver.MLIR.Pass.Composer.run_option/0","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#t:run_option/0"},{"type":"type","title":"Beaver.MLIR.Pass.Composer.run_result/0","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#t:run_result/0"},{"type":"type","title":"Beaver.MLIR.Pass.Composer.t/0","doc":"","ref":"Beaver.MLIR.Pass.Composer.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Pass.Server","doc":"server to forward invoking from C to a Elixir module","ref":"Beaver.MLIR.Pass.Server.html"},{"type":"function","title":"Beaver.MLIR.Pass.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Beaver.MLIR.Pass.Server.html#child_spec/1"},{"type":"module","title":"Beaver.MLIR.PassManager","doc":"","ref":"Beaver.MLIR.PassManager.html"},{"type":"function","title":"Beaver.MLIR.PassManager.make/1","doc":"","ref":"Beaver.MLIR.PassManager.html#make/1"},{"type":"type","title":"Beaver.MLIR.PassManager.t/0","doc":"","ref":"Beaver.MLIR.PassManager.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Pattern","doc":"","ref":"Beaver.MLIR.Pattern.html"},{"type":"function","title":"Beaver.MLIR.Pattern.apply!/3","doc":"Apply patterns on a container (region, operation, module).\nIt returns the container if it succeeds otherwise it raises.","ref":"Beaver.MLIR.Pattern.html#apply!/3"},{"type":"function","title":"Beaver.MLIR.Pattern.apply_/3","doc":"Apply patterns on a container (region, operation, module).\nIt is named `apply_` with a underscore to avoid name collision with `Kernel.apply/2`","ref":"Beaver.MLIR.Pattern.html#apply_/3"},{"type":"module","title":"Beaver.MLIR.Region","doc":"This module defines functions working with MLIR Region.","ref":"Beaver.MLIR.Region.html"},{"type":"function","title":"Beaver.MLIR.Region.make/1","doc":"","ref":"Beaver.MLIR.Region.html#make/1"},{"type":"function","title":"Beaver.MLIR.Region.under/2","doc":"","ref":"Beaver.MLIR.Region.html#under/2"},{"type":"type","title":"Beaver.MLIR.Region.t/0","doc":"","ref":"Beaver.MLIR.Region.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.RewritePatternSet","doc":"","ref":"Beaver.MLIR.RewritePatternSet.html"},{"type":"function","title":"Beaver.MLIR.RewritePatternSet.make/1","doc":"","ref":"Beaver.MLIR.RewritePatternSet.html#make/1"},{"type":"type","title":"Beaver.MLIR.RewritePatternSet.t/0","doc":"","ref":"Beaver.MLIR.RewritePatternSet.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.ShapedTypeComponentsCallback","doc":"","ref":"Beaver.MLIR.ShapedTypeComponentsCallback.html"},{"type":"function","title":"Beaver.MLIR.ShapedTypeComponentsCallback.make/1","doc":"","ref":"Beaver.MLIR.ShapedTypeComponentsCallback.html#make/1"},{"type":"type","title":"Beaver.MLIR.ShapedTypeComponentsCallback.t/0","doc":"","ref":"Beaver.MLIR.ShapedTypeComponentsCallback.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Sigils","doc":"Sigils return a function to create MLIR elements by parsing the content.","ref":"Beaver.MLIR.Sigils.html"},{"type":"function","title":"Beaver.MLIR.Sigils.sigil_a/2","doc":"Create an attribute creator.\nYou might add a modifier to it as a shortcut to annotate the type","ref":"Beaver.MLIR.Sigils.html#sigil_a/2"},{"type":"function","title":"Examples - Beaver.MLIR.Sigils.sigil_a/2","doc":"iex> ctx = MLIR.Context.create()\n    iex> Attribute.equal?(Attribute.float(Type.f(32), 0.0).(ctx), ~a{0.0}f32.(ctx))\n    true\n    iex> ~a{1 : i32}.(ctx) |> MLIR.to_string()\n    \"1 : i32\"\n    iex> ctx |> MLIR.Context.destroy","ref":"Beaver.MLIR.Sigils.html#sigil_a/2-examples"},{"type":"function","title":"Beaver.MLIR.Sigils.sigil_m/2","doc":"Create a module creator.","ref":"Beaver.MLIR.Sigils.html#sigil_m/2"},{"type":"function","title":"Examples - Beaver.MLIR.Sigils.sigil_m/2","doc":"iex> ctx = MLIR.Context.create()\n    iex> %MLIR.Module{} = ~m\"\"\"\n    ...> module {\n    ...>   func.func @add(%arg0 : i32, %arg1 : i32) -> i32 attributes { llvm.emit_c_interface } {\n    ...>     %res = arith.addi %arg0, %arg1 : i32\n    ...>     return %res : i32\n    ...>   }\n    ...> }\n    ...> \"\"\".(ctx) |> MLIR.Operation.verify!()\n    iex> ctx |> MLIR.Context.destroy","ref":"Beaver.MLIR.Sigils.html#sigil_m/2-examples"},{"type":"function","title":"Beaver.MLIR.Sigils.sigil_t/2","doc":"Create a type creator.\nYou might add a modifier to it as a shortcut to make it a higher order type.","ref":"Beaver.MLIR.Sigils.html#sigil_t/2"},{"type":"function","title":"Examples - Beaver.MLIR.Sigils.sigil_t/2","doc":"iex> ctx = MLIR.Context.create()\n    iex> Type.equal?(Type.unranked_tensor(Type.f32()).(ctx), ~t{tensor<*xf32>}.(ctx))\n    true\n    iex> Type.equal?(Type.unranked_tensor(Type.f32()).(ctx), ~t{tensor<*xf32>})\n    true\n    iex> Type.equal?(Type.complex(Type.f32()).(ctx), ~t complex.(ctx))\n    true\n    iex> Type.equal?(Type.complex(Type.f32()), ~t complex.(ctx))\n    true\n    iex> ctx |> MLIR.Context.destroy","ref":"Beaver.MLIR.Sigils.html#sigil_t/2-examples"},{"type":"module","title":"Beaver.MLIR.SparseTensorLevelType","doc":"","ref":"Beaver.MLIR.SparseTensorLevelType.html"},{"type":"function","title":"Beaver.MLIR.SparseTensorLevelType.make/1","doc":"","ref":"Beaver.MLIR.SparseTensorLevelType.html#make/1"},{"type":"type","title":"Beaver.MLIR.SparseTensorLevelType.t/0","doc":"","ref":"Beaver.MLIR.SparseTensorLevelType.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.StringCallback","doc":"","ref":"Beaver.MLIR.StringCallback.html"},{"type":"function","title":"Beaver.MLIR.StringCallback.make/1","doc":"","ref":"Beaver.MLIR.StringCallback.html#make/1"},{"type":"type","title":"Beaver.MLIR.StringCallback.t/0","doc":"","ref":"Beaver.MLIR.StringCallback.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.StringRef","doc":"This module defines functions working with MLIR StringRef.","ref":"Beaver.MLIR.StringRef.html"},{"type":"function","title":"Beaver.MLIR.StringRef.create/1","doc":"Create a Elixir owned null-terminated C string from a Elixir bitstring and create a `StringRef` from it.\n\n> Note: A `StringRef` will not reference the original BEAM binary.\n> Instead, it will reference a copy of the binary and owns it.\n> In other words, excessively creating `StringRef` using this function can lead to memory leak.","ref":"Beaver.MLIR.StringRef.html#create/1"},{"type":"function","title":"Beaver.MLIR.StringRef.data/1","doc":"","ref":"Beaver.MLIR.StringRef.html#data/1"},{"type":"function","title":"Beaver.MLIR.StringRef.length/1","doc":"","ref":"Beaver.MLIR.StringRef.html#length/1"},{"type":"function","title":"Beaver.MLIR.StringRef.make/1","doc":"","ref":"Beaver.MLIR.StringRef.html#make/1"},{"type":"function","title":"Beaver.MLIR.StringRef.to_string/1","doc":"Converts an `StringRef` to a string.","ref":"Beaver.MLIR.StringRef.html#to_string/1"},{"type":"type","title":"Beaver.MLIR.StringRef.t/0","doc":"","ref":"Beaver.MLIR.StringRef.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.SymbolTable","doc":"","ref":"Beaver.MLIR.SymbolTable.html"},{"type":"function","title":"Beaver.MLIR.SymbolTable.make/1","doc":"","ref":"Beaver.MLIR.SymbolTable.html#make/1"},{"type":"type","title":"Beaver.MLIR.SymbolTable.t/0","doc":"","ref":"Beaver.MLIR.SymbolTable.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Transforms","doc":"Transformations MLIR provides by default.","ref":"Beaver.MLIR.Transforms.html"},{"type":"function","title":"Beaver.MLIR.Transforms.canonicalize/0","doc":"Canonicalize operations","ref":"Beaver.MLIR.Transforms.html#canonicalize/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.canonicalize/0","doc":"`canonicalize`","ref":"Beaver.MLIR.Transforms.html#canonicalize/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.canonicalize/0","doc":"`Canonicalizer`","ref":"Beaver.MLIR.Transforms.html#canonicalize/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.canonicalize/1","doc":"","ref":"Beaver.MLIR.Transforms.html#canonicalize/1"},{"type":"function","title":"Beaver.MLIR.Transforms.composite_fixed_point_pass/0","doc":"Composite fixed point pass","ref":"Beaver.MLIR.Transforms.html#composite_fixed_point_pass/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.composite_fixed_point_pass/0","doc":"`composite-fixed-point-pass`","ref":"Beaver.MLIR.Transforms.html#composite_fixed_point_pass/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.composite_fixed_point_pass/0","doc":"`CompositeFixedPointPass`","ref":"Beaver.MLIR.Transforms.html#composite_fixed_point_pass/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.composite_fixed_point_pass/1","doc":"","ref":"Beaver.MLIR.Transforms.html#composite_fixed_point_pass/1"},{"type":"function","title":"Beaver.MLIR.Transforms.control_flow_sink/0","doc":"Sink operations into conditional blocks","ref":"Beaver.MLIR.Transforms.html#control_flow_sink/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.control_flow_sink/0","doc":"`control-flow-sink`","ref":"Beaver.MLIR.Transforms.html#control_flow_sink/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.control_flow_sink/0","doc":"`ControlFlowSink`","ref":"Beaver.MLIR.Transforms.html#control_flow_sink/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.control_flow_sink/1","doc":"","ref":"Beaver.MLIR.Transforms.html#control_flow_sink/1"},{"type":"function","title":"Beaver.MLIR.Transforms.convert_elementwise_to_linalg/0","doc":"Convert ElementwiseMappable ops to linalg","ref":"Beaver.MLIR.Transforms.html#convert_elementwise_to_linalg/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.convert_elementwise_to_linalg/0","doc":"`convert-elementwise-to-linalg`","ref":"Beaver.MLIR.Transforms.html#convert_elementwise_to_linalg/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.convert_elementwise_to_linalg/0","doc":"`ConvertElementwiseToLinalgPass`","ref":"Beaver.MLIR.Transforms.html#convert_elementwise_to_linalg/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.convert_elementwise_to_linalg/1","doc":"","ref":"Beaver.MLIR.Transforms.html#convert_elementwise_to_linalg/1"},{"type":"function","title":"Beaver.MLIR.Transforms.convert_linalg_to_affine_loops/0","doc":"Lower the operations from the linalg dialect into affine loops","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_affine_loops/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.convert_linalg_to_affine_loops/0","doc":"`convert-linalg-to-affine-loops`","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_affine_loops/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.convert_linalg_to_affine_loops/0","doc":"`ConvertLinalgToAffineLoopsPass`","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_affine_loops/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.convert_linalg_to_affine_loops/1","doc":"","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_affine_loops/1"},{"type":"function","title":"Beaver.MLIR.Transforms.convert_linalg_to_loops/0","doc":"Lower the operations from the linalg dialect into loops","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_loops/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.convert_linalg_to_loops/0","doc":"`convert-linalg-to-loops`","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_loops/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.convert_linalg_to_loops/0","doc":"`ConvertLinalgToLoopsPass`","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_loops/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.convert_linalg_to_loops/1","doc":"","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_loops/1"},{"type":"function","title":"Beaver.MLIR.Transforms.convert_linalg_to_parallel_loops/0","doc":"Lower the operations from the linalg dialect into parallel loops","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_parallel_loops/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.convert_linalg_to_parallel_loops/0","doc":"`convert-linalg-to-parallel-loops`","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_parallel_loops/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.convert_linalg_to_parallel_loops/0","doc":"`ConvertLinalgToParallelLoopsPass`","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_parallel_loops/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.convert_linalg_to_parallel_loops/1","doc":"","ref":"Beaver.MLIR.Transforms.html#convert_linalg_to_parallel_loops/1"},{"type":"function","title":"Beaver.MLIR.Transforms.cse/0","doc":"Eliminate common sub-expressions","ref":"Beaver.MLIR.Transforms.html#cse/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.cse/0","doc":"`cse`","ref":"Beaver.MLIR.Transforms.html#cse/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.cse/0","doc":"`CSE`","ref":"Beaver.MLIR.Transforms.html#cse/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.cse/1","doc":"","ref":"Beaver.MLIR.Transforms.html#cse/1"},{"type":"function","title":"Beaver.MLIR.Transforms.generate_runtime_verification/0","doc":"Generate additional runtime op verification checks","ref":"Beaver.MLIR.Transforms.html#generate_runtime_verification/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.generate_runtime_verification/0","doc":"`generate-runtime-verification`","ref":"Beaver.MLIR.Transforms.html#generate_runtime_verification/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.generate_runtime_verification/0","doc":"`GenerateRuntimeVerification`","ref":"Beaver.MLIR.Transforms.html#generate_runtime_verification/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.generate_runtime_verification/1","doc":"","ref":"Beaver.MLIR.Transforms.html#generate_runtime_verification/1"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_async_region/0","doc":"Make GPU ops async","ref":"Beaver.MLIR.Transforms.html#gpu_async_region/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.gpu_async_region/0","doc":"`gpu-async-region`","ref":"Beaver.MLIR.Transforms.html#gpu_async_region/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.gpu_async_region/0","doc":"`GpuAsyncRegionPass`","ref":"Beaver.MLIR.Transforms.html#gpu_async_region/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_async_region/1","doc":"","ref":"Beaver.MLIR.Transforms.html#gpu_async_region/1"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_decompose_memrefs/0","doc":"Decomposes memref index computation into explicit ops.","ref":"Beaver.MLIR.Transforms.html#gpu_decompose_memrefs/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.gpu_decompose_memrefs/0","doc":"`gpu-decompose-memrefs`","ref":"Beaver.MLIR.Transforms.html#gpu_decompose_memrefs/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.gpu_decompose_memrefs/0","doc":"`GpuDecomposeMemrefsPass`","ref":"Beaver.MLIR.Transforms.html#gpu_decompose_memrefs/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_decompose_memrefs/1","doc":"","ref":"Beaver.MLIR.Transforms.html#gpu_decompose_memrefs/1"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_eliminate_barriers/0","doc":"Erase unnecessary barriers","ref":"Beaver.MLIR.Transforms.html#gpu_eliminate_barriers/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.gpu_eliminate_barriers/0","doc":"`gpu-eliminate-barriers`","ref":"Beaver.MLIR.Transforms.html#gpu_eliminate_barriers/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.gpu_eliminate_barriers/0","doc":"`GpuEliminateBarriers`","ref":"Beaver.MLIR.Transforms.html#gpu_eliminate_barriers/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_eliminate_barriers/1","doc":"","ref":"Beaver.MLIR.Transforms.html#gpu_eliminate_barriers/1"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_kernel_outlining/0","doc":"Outline gpu.launch bodies to kernel functions","ref":"Beaver.MLIR.Transforms.html#gpu_kernel_outlining/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.gpu_kernel_outlining/0","doc":"`gpu-kernel-outlining`","ref":"Beaver.MLIR.Transforms.html#gpu_kernel_outlining/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.gpu_kernel_outlining/0","doc":"`GpuKernelOutlining`","ref":"Beaver.MLIR.Transforms.html#gpu_kernel_outlining/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_kernel_outlining/1","doc":"","ref":"Beaver.MLIR.Transforms.html#gpu_kernel_outlining/1"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_launch_sink_index_computations/0","doc":"Sink index computations into gpu.launch body","ref":"Beaver.MLIR.Transforms.html#gpu_launch_sink_index_computations/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.gpu_launch_sink_index_computations/0","doc":"`gpu-launch-sink-index-computations`","ref":"Beaver.MLIR.Transforms.html#gpu_launch_sink_index_computations/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.gpu_launch_sink_index_computations/0","doc":"`GpuLaunchSinkIndexComputations`","ref":"Beaver.MLIR.Transforms.html#gpu_launch_sink_index_computations/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_launch_sink_index_computations/1","doc":"","ref":"Beaver.MLIR.Transforms.html#gpu_launch_sink_index_computations/1"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_map_parallel_loops/0","doc":"Greedily maps loops to GPU hardware dimensions.","ref":"Beaver.MLIR.Transforms.html#gpu_map_parallel_loops/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.gpu_map_parallel_loops/0","doc":"`gpu-map-parallel-loops`","ref":"Beaver.MLIR.Transforms.html#gpu_map_parallel_loops/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.gpu_map_parallel_loops/0","doc":"`GpuMapParallelLoopsPass`","ref":"Beaver.MLIR.Transforms.html#gpu_map_parallel_loops/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_map_parallel_loops/1","doc":"","ref":"Beaver.MLIR.Transforms.html#gpu_map_parallel_loops/1"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_module_to_binary/0","doc":"Transforms a GPU module into a GPU binary.","ref":"Beaver.MLIR.Transforms.html#gpu_module_to_binary/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.gpu_module_to_binary/0","doc":"`gpu-module-to-binary`","ref":"Beaver.MLIR.Transforms.html#gpu_module_to_binary/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.gpu_module_to_binary/0","doc":"`GpuModuleToBinaryPass`","ref":"Beaver.MLIR.Transforms.html#gpu_module_to_binary/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.gpu_module_to_binary/1","doc":"","ref":"Beaver.MLIR.Transforms.html#gpu_module_to_binary/1"},{"type":"function","title":"Beaver.MLIR.Transforms.inline/0","doc":"Inline function calls","ref":"Beaver.MLIR.Transforms.html#inline/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.inline/0","doc":"`inline`","ref":"Beaver.MLIR.Transforms.html#inline/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.inline/0","doc":"`Inliner`","ref":"Beaver.MLIR.Transforms.html#inline/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.inline/1","doc":"","ref":"Beaver.MLIR.Transforms.html#inline/1"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_block_pack_matmul/0","doc":"Convert linalg matmul ops to block layout and back","ref":"Beaver.MLIR.Transforms.html#linalg_block_pack_matmul/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.linalg_block_pack_matmul/0","doc":"`linalg-block-pack-matmul`","ref":"Beaver.MLIR.Transforms.html#linalg_block_pack_matmul/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.linalg_block_pack_matmul/0","doc":"`LinalgBlockPackMatmul`","ref":"Beaver.MLIR.Transforms.html#linalg_block_pack_matmul/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_block_pack_matmul/1","doc":"","ref":"Beaver.MLIR.Transforms.html#linalg_block_pack_matmul/1"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_detensorize/0","doc":"Detensorize linalg ops","ref":"Beaver.MLIR.Transforms.html#linalg_detensorize/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.linalg_detensorize/0","doc":"`linalg-detensorize`","ref":"Beaver.MLIR.Transforms.html#linalg_detensorize/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.linalg_detensorize/0","doc":"`LinalgDetensorizePass`","ref":"Beaver.MLIR.Transforms.html#linalg_detensorize/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_detensorize/1","doc":"","ref":"Beaver.MLIR.Transforms.html#linalg_detensorize/1"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_fold_unit_extent_dims/0","doc":"Remove unit-extent dimension in Linalg ops on tensors","ref":"Beaver.MLIR.Transforms.html#linalg_fold_unit_extent_dims/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.linalg_fold_unit_extent_dims/0","doc":"`linalg-fold-unit-extent-dims`","ref":"Beaver.MLIR.Transforms.html#linalg_fold_unit_extent_dims/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.linalg_fold_unit_extent_dims/0","doc":"`LinalgFoldUnitExtentDimsPass`","ref":"Beaver.MLIR.Transforms.html#linalg_fold_unit_extent_dims/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_fold_unit_extent_dims/1","doc":"","ref":"Beaver.MLIR.Transforms.html#linalg_fold_unit_extent_dims/1"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_fuse_elementwise_ops/0","doc":"Fuse elementwise operations on tensors","ref":"Beaver.MLIR.Transforms.html#linalg_fuse_elementwise_ops/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.linalg_fuse_elementwise_ops/0","doc":"`linalg-fuse-elementwise-ops`","ref":"Beaver.MLIR.Transforms.html#linalg_fuse_elementwise_ops/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.linalg_fuse_elementwise_ops/0","doc":"`LinalgElementwiseOpFusionPass`","ref":"Beaver.MLIR.Transforms.html#linalg_fuse_elementwise_ops/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_fuse_elementwise_ops/1","doc":"","ref":"Beaver.MLIR.Transforms.html#linalg_fuse_elementwise_ops/1"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_generalize_named_ops/0","doc":"Convert named ops into generic ops","ref":"Beaver.MLIR.Transforms.html#linalg_generalize_named_ops/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.linalg_generalize_named_ops/0","doc":"`linalg-generalize-named-ops`","ref":"Beaver.MLIR.Transforms.html#linalg_generalize_named_ops/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.linalg_generalize_named_ops/0","doc":"`LinalgGeneralizeNamedOpsPass`","ref":"Beaver.MLIR.Transforms.html#linalg_generalize_named_ops/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_generalize_named_ops/1","doc":"","ref":"Beaver.MLIR.Transforms.html#linalg_generalize_named_ops/1"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_inline_scalar_operands/0","doc":"Inline scalar operands into linalg generic ops","ref":"Beaver.MLIR.Transforms.html#linalg_inline_scalar_operands/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.linalg_inline_scalar_operands/0","doc":"`linalg-inline-scalar-operands`","ref":"Beaver.MLIR.Transforms.html#linalg_inline_scalar_operands/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.linalg_inline_scalar_operands/0","doc":"`LinalgInlineScalarOperandsPass`","ref":"Beaver.MLIR.Transforms.html#linalg_inline_scalar_operands/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_inline_scalar_operands/1","doc":"","ref":"Beaver.MLIR.Transforms.html#linalg_inline_scalar_operands/1"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_named_op_conversion/0","doc":"Convert from one named linalg op to another.","ref":"Beaver.MLIR.Transforms.html#linalg_named_op_conversion/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.linalg_named_op_conversion/0","doc":"`linalg-named-op-conversion`","ref":"Beaver.MLIR.Transforms.html#linalg_named_op_conversion/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.linalg_named_op_conversion/0","doc":"`LinalgNamedOpConversionPass`","ref":"Beaver.MLIR.Transforms.html#linalg_named_op_conversion/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_named_op_conversion/1","doc":"","ref":"Beaver.MLIR.Transforms.html#linalg_named_op_conversion/1"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_specialize_generic_ops/0","doc":"Convert generic ops back to named ops","ref":"Beaver.MLIR.Transforms.html#linalg_specialize_generic_ops/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.linalg_specialize_generic_ops/0","doc":"`linalg-specialize-generic-ops`","ref":"Beaver.MLIR.Transforms.html#linalg_specialize_generic_ops/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.linalg_specialize_generic_ops/0","doc":"`LinalgSpecializeGenericOpsPass`","ref":"Beaver.MLIR.Transforms.html#linalg_specialize_generic_ops/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.linalg_specialize_generic_ops/1","doc":"","ref":"Beaver.MLIR.Transforms.html#linalg_specialize_generic_ops/1"},{"type":"function","title":"Beaver.MLIR.Transforms.loop_invariant_code_motion/0","doc":"Hoist loop invariant instructions outside of the loop","ref":"Beaver.MLIR.Transforms.html#loop_invariant_code_motion/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.loop_invariant_code_motion/0","doc":"`loop-invariant-code-motion`","ref":"Beaver.MLIR.Transforms.html#loop_invariant_code_motion/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.loop_invariant_code_motion/0","doc":"`LoopInvariantCodeMotion`","ref":"Beaver.MLIR.Transforms.html#loop_invariant_code_motion/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.loop_invariant_code_motion/1","doc":"","ref":"Beaver.MLIR.Transforms.html#loop_invariant_code_motion/1"},{"type":"function","title":"Beaver.MLIR.Transforms.loop_invariant_subset_hoisting/0","doc":"Hoist loop invariant subset ops outside of the loop","ref":"Beaver.MLIR.Transforms.html#loop_invariant_subset_hoisting/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.loop_invariant_subset_hoisting/0","doc":"`loop-invariant-subset-hoisting`","ref":"Beaver.MLIR.Transforms.html#loop_invariant_subset_hoisting/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.loop_invariant_subset_hoisting/0","doc":"`LoopInvariantSubsetHoisting`","ref":"Beaver.MLIR.Transforms.html#loop_invariant_subset_hoisting/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.loop_invariant_subset_hoisting/1","doc":"","ref":"Beaver.MLIR.Transforms.html#loop_invariant_subset_hoisting/1"},{"type":"function","title":"Beaver.MLIR.Transforms.mem2reg/0","doc":"Promotes memory slots into values.","ref":"Beaver.MLIR.Transforms.html#mem2reg/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.mem2reg/0","doc":"`mem2reg`","ref":"Beaver.MLIR.Transforms.html#mem2reg/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.mem2reg/0","doc":"`Mem2Reg`","ref":"Beaver.MLIR.Transforms.html#mem2reg/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.mem2reg/1","doc":"","ref":"Beaver.MLIR.Transforms.html#mem2reg/1"},{"type":"function","title":"Beaver.MLIR.Transforms.nvvm_attach_target/0","doc":"Attaches an NVVM target attribute to a GPU Module.","ref":"Beaver.MLIR.Transforms.html#nvvm_attach_target/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.nvvm_attach_target/0","doc":"`nvvm-attach-target`","ref":"Beaver.MLIR.Transforms.html#nvvm_attach_target/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.nvvm_attach_target/0","doc":"`GpuNVVMAttachTarget`","ref":"Beaver.MLIR.Transforms.html#nvvm_attach_target/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.nvvm_attach_target/1","doc":"","ref":"Beaver.MLIR.Transforms.html#nvvm_attach_target/1"},{"type":"function","title":"Beaver.MLIR.Transforms.print_ir/0","doc":"Print IR on the debug stream","ref":"Beaver.MLIR.Transforms.html#print_ir/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.print_ir/0","doc":"`print-ir`","ref":"Beaver.MLIR.Transforms.html#print_ir/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.print_ir/0","doc":"`PrintIRPass`","ref":"Beaver.MLIR.Transforms.html#print_ir/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.print_ir/1","doc":"","ref":"Beaver.MLIR.Transforms.html#print_ir/1"},{"type":"function","title":"Beaver.MLIR.Transforms.print_op_stats/0","doc":"Print statistics of operations","ref":"Beaver.MLIR.Transforms.html#print_op_stats/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.print_op_stats/0","doc":"`print-op-stats`","ref":"Beaver.MLIR.Transforms.html#print_op_stats/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.print_op_stats/0","doc":"`PrintOpStats`","ref":"Beaver.MLIR.Transforms.html#print_op_stats/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.print_op_stats/1","doc":"","ref":"Beaver.MLIR.Transforms.html#print_op_stats/1"},{"type":"function","title":"Beaver.MLIR.Transforms.remove_dead_values/0","doc":"Remove dead values","ref":"Beaver.MLIR.Transforms.html#remove_dead_values/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.remove_dead_values/0","doc":"`remove-dead-values`","ref":"Beaver.MLIR.Transforms.html#remove_dead_values/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.remove_dead_values/0","doc":"`RemoveDeadValues`","ref":"Beaver.MLIR.Transforms.html#remove_dead_values/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.remove_dead_values/1","doc":"","ref":"Beaver.MLIR.Transforms.html#remove_dead_values/1"},{"type":"function","title":"Beaver.MLIR.Transforms.rocdl_attach_target/0","doc":"Attaches a ROCDL target attribute to a GPU Module.","ref":"Beaver.MLIR.Transforms.html#rocdl_attach_target/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.rocdl_attach_target/0","doc":"`rocdl-attach-target`","ref":"Beaver.MLIR.Transforms.html#rocdl_attach_target/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.rocdl_attach_target/0","doc":"`GpuROCDLAttachTarget`","ref":"Beaver.MLIR.Transforms.html#rocdl_attach_target/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.rocdl_attach_target/1","doc":"","ref":"Beaver.MLIR.Transforms.html#rocdl_attach_target/1"},{"type":"function","title":"Beaver.MLIR.Transforms.sccp/0","doc":"Sparse Conditional Constant Propagation","ref":"Beaver.MLIR.Transforms.html#sccp/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.sccp/0","doc":"`sccp`","ref":"Beaver.MLIR.Transforms.html#sccp/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.sccp/0","doc":"`SCCP`","ref":"Beaver.MLIR.Transforms.html#sccp/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.sccp/1","doc":"","ref":"Beaver.MLIR.Transforms.html#sccp/1"},{"type":"function","title":"Beaver.MLIR.Transforms.snapshot_op_locations/0","doc":"Generate new locations from the current IR","ref":"Beaver.MLIR.Transforms.html#snapshot_op_locations/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.snapshot_op_locations/0","doc":"`snapshot-op-locations`","ref":"Beaver.MLIR.Transforms.html#snapshot_op_locations/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.snapshot_op_locations/0","doc":"`LocationSnapshot`","ref":"Beaver.MLIR.Transforms.html#snapshot_op_locations/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.snapshot_op_locations/1","doc":"","ref":"Beaver.MLIR.Transforms.html#snapshot_op_locations/1"},{"type":"function","title":"Beaver.MLIR.Transforms.spirv_attach_target/0","doc":"Attaches an SPIR-V target attribute to a GPU Module.","ref":"Beaver.MLIR.Transforms.html#spirv_attach_target/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.spirv_attach_target/0","doc":"`spirv-attach-target`","ref":"Beaver.MLIR.Transforms.html#spirv_attach_target/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.spirv_attach_target/0","doc":"`GpuSPIRVAttachTarget`","ref":"Beaver.MLIR.Transforms.html#spirv_attach_target/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.spirv_attach_target/1","doc":"","ref":"Beaver.MLIR.Transforms.html#spirv_attach_target/1"},{"type":"function","title":"Beaver.MLIR.Transforms.sroa/0","doc":"Scalar Replacement of Aggregates","ref":"Beaver.MLIR.Transforms.html#sroa/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.sroa/0","doc":"`sroa`","ref":"Beaver.MLIR.Transforms.html#sroa/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.sroa/0","doc":"`SROA`","ref":"Beaver.MLIR.Transforms.html#sroa/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.sroa/1","doc":"","ref":"Beaver.MLIR.Transforms.html#sroa/1"},{"type":"function","title":"Beaver.MLIR.Transforms.strip_debuginfo/0","doc":"Strip debug info from all operations","ref":"Beaver.MLIR.Transforms.html#strip_debuginfo/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.strip_debuginfo/0","doc":"`strip-debuginfo`","ref":"Beaver.MLIR.Transforms.html#strip_debuginfo/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.strip_debuginfo/0","doc":"`StripDebugInfo`","ref":"Beaver.MLIR.Transforms.html#strip_debuginfo/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.strip_debuginfo/1","doc":"","ref":"Beaver.MLIR.Transforms.html#strip_debuginfo/1"},{"type":"function","title":"Beaver.MLIR.Transforms.symbol_dce/0","doc":"Eliminate dead symbols","ref":"Beaver.MLIR.Transforms.html#symbol_dce/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.symbol_dce/0","doc":"`symbol-dce`","ref":"Beaver.MLIR.Transforms.html#symbol_dce/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.symbol_dce/0","doc":"`SymbolDCE`","ref":"Beaver.MLIR.Transforms.html#symbol_dce/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.symbol_dce/1","doc":"","ref":"Beaver.MLIR.Transforms.html#symbol_dce/1"},{"type":"function","title":"Beaver.MLIR.Transforms.symbol_privatize/0","doc":"Mark symbols private","ref":"Beaver.MLIR.Transforms.html#symbol_privatize/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.symbol_privatize/0","doc":"`symbol-privatize`","ref":"Beaver.MLIR.Transforms.html#symbol_privatize/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.symbol_privatize/0","doc":"`SymbolPrivatize`","ref":"Beaver.MLIR.Transforms.html#symbol_privatize/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.symbol_privatize/1","doc":"","ref":"Beaver.MLIR.Transforms.html#symbol_privatize/1"},{"type":"function","title":"Beaver.MLIR.Transforms.topological_sort/0","doc":"Sort regions without SSA dominance in topological order","ref":"Beaver.MLIR.Transforms.html#topological_sort/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.topological_sort/0","doc":"`topological-sort`","ref":"Beaver.MLIR.Transforms.html#topological_sort/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.topological_sort/0","doc":"`TopologicalSort`","ref":"Beaver.MLIR.Transforms.html#topological_sort/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.topological_sort/1","doc":"","ref":"Beaver.MLIR.Transforms.html#topological_sort/1"},{"type":"function","title":"Beaver.MLIR.Transforms.view_op_graph/0","doc":"Print Graphviz visualization of an operation","ref":"Beaver.MLIR.Transforms.html#view_op_graph/0"},{"type":"function","title":"Argument name in MLIR CLI - Beaver.MLIR.Transforms.view_op_graph/0","doc":"`view-op-graph`","ref":"Beaver.MLIR.Transforms.html#view_op_graph/0-argument-name-in-mlir-cli"},{"type":"function","title":"Pass name in TableGen - Beaver.MLIR.Transforms.view_op_graph/0","doc":"`ViewOpGraph`","ref":"Beaver.MLIR.Transforms.html#view_op_graph/0-pass-name-in-tablegen"},{"type":"function","title":"Beaver.MLIR.Transforms.view_op_graph/1","doc":"","ref":"Beaver.MLIR.Transforms.html#view_op_graph/1"},{"type":"module","title":"Beaver.MLIR.Type","doc":"This module defines functions working with MLIR Type.","ref":"Beaver.MLIR.Type.html"},{"type":"function","title":"Beaver.MLIR.Type.complex/1","doc":"","ref":"Beaver.MLIR.Type.html#complex/1"},{"type":"function","title":"Beaver.MLIR.Type.equal?/2","doc":"","ref":"Beaver.MLIR.Type.html#equal?/2"},{"type":"function","title":"Beaver.MLIR.Type.f16/1","doc":"","ref":"Beaver.MLIR.Type.html#f16/1"},{"type":"function","title":"Beaver.MLIR.Type.f32/1","doc":"","ref":"Beaver.MLIR.Type.html#f32/1"},{"type":"function","title":"Beaver.MLIR.Type.f64/1","doc":"","ref":"Beaver.MLIR.Type.html#f64/1"},{"type":"function","title":"Beaver.MLIR.Type.f/2","doc":"","ref":"Beaver.MLIR.Type.html#f/2"},{"type":"function","title":"Beaver.MLIR.Type.function/3","doc":"","ref":"Beaver.MLIR.Type.html#function/3"},{"type":"function","title":"Beaver.MLIR.Type.get/2","doc":"","ref":"Beaver.MLIR.Type.html#get/2"},{"type":"function","title":"Beaver.MLIR.Type.i1/1","doc":"","ref":"Beaver.MLIR.Type.html#i1/1"},{"type":"function","title":"Beaver.MLIR.Type.i8/1","doc":"","ref":"Beaver.MLIR.Type.html#i8/1"},{"type":"function","title":"Beaver.MLIR.Type.i16/1","doc":"","ref":"Beaver.MLIR.Type.html#i16/1"},{"type":"function","title":"Beaver.MLIR.Type.i32/1","doc":"","ref":"Beaver.MLIR.Type.html#i32/1"},{"type":"function","title":"Beaver.MLIR.Type.i64/1","doc":"","ref":"Beaver.MLIR.Type.html#i64/1"},{"type":"function","title":"Beaver.MLIR.Type.i128/1","doc":"","ref":"Beaver.MLIR.Type.html#i128/1"},{"type":"function","title":"Beaver.MLIR.Type.i/2","doc":"","ref":"Beaver.MLIR.Type.html#i/2"},{"type":"function","title":"Beaver.MLIR.Type.index/1","doc":"","ref":"Beaver.MLIR.Type.html#index/1"},{"type":"function","title":"Beaver.MLIR.Type.integer/2","doc":"","ref":"Beaver.MLIR.Type.html#integer/2"},{"type":"function","title":"Beaver.MLIR.Type.make/1","doc":"","ref":"Beaver.MLIR.Type.html#make/1"},{"type":"function","title":"Beaver.MLIR.Type.memref/3","doc":"","ref":"Beaver.MLIR.Type.html#memref/3"},{"type":"function","title":"Beaver.MLIR.Type.ranked_tensor/3","doc":"","ref":"Beaver.MLIR.Type.html#ranked_tensor/3"},{"type":"function","title":"Beaver.MLIR.Type.tuple/2","doc":"Get a tuple type.","ref":"Beaver.MLIR.Type.html#tuple/2"},{"type":"function","title":"Examples - Beaver.MLIR.Type.tuple/2","doc":"iex> ctx = MLIR.Context.create()\n    iex> MLIR.Type.tuple([MLIR.Type.i32, MLIR.Type.i32], ctx: ctx) |> MLIR.to_string()\n    \"tuple \"\n    iex> ctx |> MLIR.Context.destroy","ref":"Beaver.MLIR.Type.html#tuple/2-examples"},{"type":"function","title":"Beaver.MLIR.Type.unranked_tensor/1","doc":"","ref":"Beaver.MLIR.Type.html#unranked_tensor/1"},{"type":"function","title":"Beaver.MLIR.Type.vector/2","doc":"Get a vector type creator.","ref":"Beaver.MLIR.Type.html#vector/2"},{"type":"function","title":"Examples - Beaver.MLIR.Type.vector/2","doc":"iex> ctx = MLIR.Context.create()\n    iex> MLIR.Type.vector([1, 2, 3], MLIR.Type.i32).(ctx) |> MLIR.to_string()\n    \"vector<1x2x3xi32>\"\n    iex> ctx |> MLIR.Context.destroy","ref":"Beaver.MLIR.Type.html#vector/2-examples"},{"type":"type","title":"Beaver.MLIR.Type.t/0","doc":"","ref":"Beaver.MLIR.Type.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.TypeID","doc":"","ref":"Beaver.MLIR.TypeID.html"},{"type":"function","title":"Beaver.MLIR.TypeID.make/1","doc":"","ref":"Beaver.MLIR.TypeID.html#make/1"},{"type":"type","title":"Beaver.MLIR.TypeID.t/0","doc":"","ref":"Beaver.MLIR.TypeID.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.TypeIDAllocator","doc":"","ref":"Beaver.MLIR.TypeIDAllocator.html"},{"type":"function","title":"Beaver.MLIR.TypeIDAllocator.make/1","doc":"","ref":"Beaver.MLIR.TypeIDAllocator.html#make/1"},{"type":"type","title":"Beaver.MLIR.TypeIDAllocator.t/0","doc":"","ref":"Beaver.MLIR.TypeIDAllocator.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.TypesCallback","doc":"","ref":"Beaver.MLIR.TypesCallback.html"},{"type":"function","title":"Beaver.MLIR.TypesCallback.make/1","doc":"","ref":"Beaver.MLIR.TypesCallback.html#make/1"},{"type":"type","title":"Beaver.MLIR.TypesCallback.t/0","doc":"","ref":"Beaver.MLIR.TypesCallback.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.Value","doc":"This module defines functions working with MLIR Value.","ref":"Beaver.MLIR.Value.html"},{"type":"function","title":"Beaver.MLIR.Value.argument?/1","doc":"","ref":"Beaver.MLIR.Value.html#argument?/1"},{"type":"function","title":"Beaver.MLIR.Value.make/1","doc":"","ref":"Beaver.MLIR.Value.html#make/1"},{"type":"function","title":"Beaver.MLIR.Value.owner/1","doc":"Return the defining op of this value if this value is a result","ref":"Beaver.MLIR.Value.html#owner/1"},{"type":"function","title":"Beaver.MLIR.Value.owner!/1","doc":"Return the defining op of this value. Raises if this value is not a result","ref":"Beaver.MLIR.Value.html#owner!/1"},{"type":"function","title":"Beaver.MLIR.Value.result?/1","doc":"Returns true if the value is a result of an operation.","ref":"Beaver.MLIR.Value.html#result?/1"},{"type":"function","title":"Beaver.MLIR.Value.type/1","doc":"Return the type of this value","ref":"Beaver.MLIR.Value.html#type/1"},{"type":"type","title":"Beaver.MLIR.Value.t/0","doc":"","ref":"Beaver.MLIR.Value.html#t:t/0"},{"type":"module","title":"Beaver.MLIR.WalkOrder","doc":"","ref":"Beaver.MLIR.WalkOrder.html"},{"type":"function","title":"Beaver.MLIR.WalkOrder.make/1","doc":"","ref":"Beaver.MLIR.WalkOrder.html#make/1"},{"type":"type","title":"Beaver.MLIR.WalkOrder.t/0","doc":"","ref":"Beaver.MLIR.WalkOrder.html#t:t/0"},{"type":"module","title":"Beaver.Native","doc":"This module provide higher level interface to primitive data types and MemRefDescriptor C struct in [MemRef](https://mlir.llvm.org/docs/Dialects/MemRef/) dialect.\nIt aims to manage memory with BEAM and help a Erlang/Elixir function play well with function generated by MLIR and other NIFs.","ref":"Beaver.Native.html"},{"type":"function","title":"Beaver.Native.array/3","doc":"","ref":"Beaver.Native.html#array/3"},{"type":"function","title":"Beaver.Native.check!/1","doc":"","ref":"Beaver.Native.html#check!/1"},{"type":"function","title":"Beaver.Native.dump/1","doc":"","ref":"Beaver.Native.html#dump/1"},{"type":"function","title":"Beaver.Native.forward/3","doc":"","ref":"Beaver.Native.html#forward/3"},{"type":"function","title":"Beaver.Native.opaque_ptr/1","doc":"","ref":"Beaver.Native.html#opaque_ptr/1"},{"type":"function","title":"Beaver.Native.ptr/1","doc":"","ref":"Beaver.Native.html#ptr/1"},{"type":"function","title":"Beaver.Native.to_term/1","doc":"","ref":"Beaver.Native.html#to_term/1"},{"type":"module","title":"Beaver.Native.Array","doc":"This module defines functions working with C array.","ref":"Beaver.Native.Array.html"},{"type":"function","title":"Beaver.Native.Array.as_opaque/1","doc":"","ref":"Beaver.Native.Array.html#as_opaque/1"},{"type":"module","title":"Beaver.Native.Bool","doc":"","ref":"Beaver.Native.Bool.html"},{"type":"function","title":"Beaver.Native.Bool.make/1","doc":"","ref":"Beaver.Native.Bool.html#make/1"},{"type":"type","title":"Beaver.Native.Bool.t/0","doc":"","ref":"Beaver.Native.Bool.html#t:t/0"},{"type":"module","title":"Beaver.Native.CInt","doc":"","ref":"Beaver.Native.CInt.html"},{"type":"function","title":"Beaver.Native.CInt.make/1","doc":"","ref":"Beaver.Native.CInt.html#make/1"},{"type":"type","title":"Beaver.Native.CInt.t/0","doc":"","ref":"Beaver.Native.CInt.html#t:t/0"},{"type":"module","title":"Beaver.Native.CUInt","doc":"","ref":"Beaver.Native.CUInt.html"},{"type":"function","title":"Beaver.Native.CUInt.make/1","doc":"","ref":"Beaver.Native.CUInt.html#make/1"},{"type":"type","title":"Beaver.Native.CUInt.t/0","doc":"","ref":"Beaver.Native.CUInt.html#t:t/0"},{"type":"module","title":"Beaver.Native.Complex.F32","doc":"","ref":"Beaver.Native.Complex.F32.html"},{"type":"function","title":"Beaver.Native.Complex.F32.make/1","doc":"","ref":"Beaver.Native.Complex.F32.html#make/1"},{"type":"type","title":"Beaver.Native.Complex.F32.t/0","doc":"","ref":"Beaver.Native.Complex.F32.html#t:t/0"},{"type":"module","title":"Beaver.Native.F32","doc":"","ref":"Beaver.Native.F32.html"},{"type":"function","title":"Beaver.Native.F32.make/1","doc":"","ref":"Beaver.Native.F32.html#make/1"},{"type":"type","title":"Beaver.Native.F32.t/0","doc":"","ref":"Beaver.Native.F32.html#t:t/0"},{"type":"module","title":"Beaver.Native.F64","doc":"","ref":"Beaver.Native.F64.html"},{"type":"function","title":"Beaver.Native.F64.make/1","doc":"","ref":"Beaver.Native.F64.html#make/1"},{"type":"type","title":"Beaver.Native.F64.t/0","doc":"","ref":"Beaver.Native.F64.html#t:t/0"},{"type":"module","title":"Beaver.Native.I16","doc":"","ref":"Beaver.Native.I16.html"},{"type":"function","title":"Beaver.Native.I16.make/1","doc":"","ref":"Beaver.Native.I16.html#make/1"},{"type":"type","title":"Beaver.Native.I16.t/0","doc":"","ref":"Beaver.Native.I16.html#t:t/0"},{"type":"module","title":"Beaver.Native.I32","doc":"","ref":"Beaver.Native.I32.html"},{"type":"function","title":"Beaver.Native.I32.make/1","doc":"","ref":"Beaver.Native.I32.html#make/1"},{"type":"type","title":"Beaver.Native.I32.t/0","doc":"","ref":"Beaver.Native.I32.html#t:t/0"},{"type":"module","title":"Beaver.Native.I64","doc":"","ref":"Beaver.Native.I64.html"},{"type":"function","title":"Beaver.Native.I64.make/1","doc":"","ref":"Beaver.Native.I64.html#make/1"},{"type":"type","title":"Beaver.Native.I64.t/0","doc":"","ref":"Beaver.Native.I64.html#t:t/0"},{"type":"module","title":"Beaver.Native.I8","doc":"","ref":"Beaver.Native.I8.html"},{"type":"function","title":"Beaver.Native.I8.make/1","doc":"","ref":"Beaver.Native.I8.html#make/1"},{"type":"type","title":"Beaver.Native.I8.t/0","doc":"","ref":"Beaver.Native.I8.html#t:t/0"},{"type":"module","title":"Beaver.Native.ISize","doc":"","ref":"Beaver.Native.ISize.html"},{"type":"function","title":"Beaver.Native.ISize.make/1","doc":"","ref":"Beaver.Native.ISize.html#make/1"},{"type":"type","title":"Beaver.Native.ISize.t/0","doc":"","ref":"Beaver.Native.ISize.html#t:t/0"},{"type":"module","title":"Beaver.Native.Memory","doc":"A piece of memory managed by BEAM and can by addressed by a generated native function as MLIR MemRef descriptor","ref":"Beaver.Native.Memory.html"},{"type":"function","title":"Beaver.Native.Memory.aligned/1","doc":"return a opaque pointer to the memory","ref":"Beaver.Native.Memory.html#aligned/1"},{"type":"function","title":"Beaver.Native.Memory.allocated/1","doc":"","ref":"Beaver.Native.Memory.html#allocated/1"},{"type":"function","title":"Beaver.Native.Memory.deallocate/1","doc":"","ref":"Beaver.Native.Memory.html#deallocate/1"},{"type":"function","title":"Beaver.Native.Memory.dense_strides/1","doc":"","ref":"Beaver.Native.Memory.html#dense_strides/1"},{"type":"function","title":"Beaver.Native.Memory.descriptor_ptr/1","doc":"return a opaque pointer to the memory descriptor. Usually used in the invoking of a generated function.\nIf it is a array, will return the pointer of the array to mimic a struct of packed memory descriptors","ref":"Beaver.Native.Memory.html#descriptor_ptr/1"},{"type":"function","title":"Beaver.Native.Memory.new/2","doc":"","ref":"Beaver.Native.Memory.html#new/2"},{"type":"module","title":"Beaver.Native.OpaqueArray","doc":"","ref":"Beaver.Native.OpaqueArray.html"},{"type":"function","title":"Beaver.Native.OpaqueArray.make/1","doc":"","ref":"Beaver.Native.OpaqueArray.html#make/1"},{"type":"type","title":"Beaver.Native.OpaqueArray.t/0","doc":"","ref":"Beaver.Native.OpaqueArray.html#t:t/0"},{"type":"module","title":"Beaver.Native.OpaquePtr","doc":"This module defines functions working with opaque pointer, usually a `void*` in C.","ref":"Beaver.Native.OpaquePtr.html"},{"type":"function","title":"Beaver.Native.OpaquePtr.deallocate/1","doc":"","ref":"Beaver.Native.OpaquePtr.html#deallocate/1"},{"type":"function","title":"Beaver.Native.OpaquePtr.make/1","doc":"","ref":"Beaver.Native.OpaquePtr.html#make/1"},{"type":"function","title":"Beaver.Native.OpaquePtr.null/0","doc":"","ref":"Beaver.Native.OpaquePtr.html#null/0"},{"type":"function","title":"Beaver.Native.OpaquePtr.to_binary/2","doc":"read the N bytes starting from the pointer and returns an Erlang binary","ref":"Beaver.Native.OpaquePtr.html#to_binary/2"},{"type":"function","title":"Beaver.Native.OpaquePtr.to_resource/3","doc":"read the N bytes starting from the pointer and return a resource","ref":"Beaver.Native.OpaquePtr.html#to_resource/3"},{"type":"type","title":"Beaver.Native.OpaquePtr.t/0","doc":"","ref":"Beaver.Native.OpaquePtr.html#t:t/0"},{"type":"module","title":"Beaver.Native.Ptr","doc":"This module defines functions working with pointer in C.","ref":"Beaver.Native.Ptr.html"},{"type":"module","title":"Beaver.Native.U16","doc":"","ref":"Beaver.Native.U16.html"},{"type":"function","title":"Beaver.Native.U16.make/1","doc":"","ref":"Beaver.Native.U16.html#make/1"},{"type":"type","title":"Beaver.Native.U16.t/0","doc":"","ref":"Beaver.Native.U16.html#t:t/0"},{"type":"module","title":"Beaver.Native.U32","doc":"","ref":"Beaver.Native.U32.html"},{"type":"function","title":"Beaver.Native.U32.make/1","doc":"","ref":"Beaver.Native.U32.html#make/1"},{"type":"type","title":"Beaver.Native.U32.t/0","doc":"","ref":"Beaver.Native.U32.html#t:t/0"},{"type":"module","title":"Beaver.Native.U64","doc":"","ref":"Beaver.Native.U64.html"},{"type":"function","title":"Beaver.Native.U64.make/1","doc":"","ref":"Beaver.Native.U64.html#make/1"},{"type":"type","title":"Beaver.Native.U64.t/0","doc":"","ref":"Beaver.Native.U64.html#t:t/0"},{"type":"module","title":"Beaver.Native.U8","doc":"","ref":"Beaver.Native.U8.html"},{"type":"function","title":"Beaver.Native.U8.make/1","doc":"","ref":"Beaver.Native.U8.html#make/1"},{"type":"type","title":"Beaver.Native.U8.t/0","doc":"","ref":"Beaver.Native.U8.html#t:t/0"},{"type":"module","title":"Beaver.Native.USize","doc":"","ref":"Beaver.Native.USize.html"},{"type":"function","title":"Beaver.Native.USize.make/1","doc":"","ref":"Beaver.Native.USize.html#make/1"},{"type":"type","title":"Beaver.Native.USize.t/0","doc":"","ref":"Beaver.Native.USize.html#t:t/0"},{"type":"module","title":"Beaver.Deferred","doc":"","ref":"Beaver.Deferred.html"},{"type":"function","title":"Beaver.Deferred.create/2","doc":"","ref":"Beaver.Deferred.html#create/2"},{"type":"function","title":"Beaver.Deferred.from_opts/2","doc":"","ref":"Beaver.Deferred.html#from_opts/2"},{"type":"type","title":"Beaver.Deferred.attribute/0","doc":"","ref":"Beaver.Deferred.html#t:attribute/0"},{"type":"type","title":"Beaver.Deferred.operation/0","doc":"","ref":"Beaver.Deferred.html#t:operation/0"},{"type":"type","title":"Beaver.Deferred.opts/0","doc":"","ref":"Beaver.Deferred.html#t:opts/0"},{"type":"type","title":"Beaver.Deferred.type/0","doc":"","ref":"Beaver.Deferred.html#t:type/0"},{"type":"module","title":"Beaver.Diagnostic","doc":"","ref":"Beaver.Diagnostic.html"},{"type":"function","title":"Beaver.Diagnostic.attach/2","doc":"","ref":"Beaver.Diagnostic.html#attach/2"},{"type":"function","title":"Beaver.Diagnostic.callback/0","doc":"","ref":"Beaver.Diagnostic.html#callback/0"},{"type":"function","title":"Beaver.Diagnostic.detach/2","doc":"","ref":"Beaver.Diagnostic.html#detach/2"},{"type":"module","title":"Beaver.Diagnostic.Server","doc":"server to collect diagnostic printing from MLIR","ref":"Beaver.Diagnostic.Server.html"},{"type":"function","title":"Beaver.Diagnostic.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Beaver.Diagnostic.Server.html#child_spec/1"},{"type":"function","title":"Beaver.Diagnostic.Server.flush/1","doc":"","ref":"Beaver.Diagnostic.Server.html#flush/1"},{"type":"function","title":"Beaver.Diagnostic.Server.init/1","doc":"","ref":"Beaver.Diagnostic.Server.html#init/1"},{"type":"exception","title":"Beaver.EnvNotFoundError","doc":"","ref":"Beaver.EnvNotFoundError.html"},{"type":"extras","title":"Your first compiler with Beaver!","doc":"<!-- livebook:{\"persist_outputs\":true} -->\n\n# Your first compiler with Beaver!\n\n```elixir\nMix.install([\n  {:beaver, \"~> 0.3\"}\n])\n```","ref":"your-first-beaver-compiler.html"},{"type":"extras","title":"What makes a compiler - Your first compiler with Beaver!","doc":"Before start coding anything. Let's get some intuition about what a typical compiler is made of.\n\n* IR\n* Pass\n* CodeGen","ref":"your-first-beaver-compiler.html#what-makes-a-compiler"},{"type":"extras","title":"A taste of MLIR - Your first compiler with Beaver!","doc":"Most of LLVM tutorial starts with AST and parser. Guess what we are building it with Elixir and it rocks.\nSo we can start with something fun, generating the IR.\n\n```elixir\nuse Beaver\nalias Beaver.MLIR.Dialect.{Func, Arith}\nrequire Func\nctx = MLIR.Context.create()\n\nir =\n  mlir ctx: ctx do\n    module do\n      Func.func some_func(function_type: Type.function([Type.i32()], [Type.i32()])) do\n        region do\n          block _bb_entry(a >>> Type.i32()) do\n            b = Arith.constant(value: Attribute.integer(Type.i32(), 1024)) >>> Type.i32()\n            c = Arith.addi(a, b) >>> Type.i32()\n            Func.return(c) >>> []\n          end\n        end\n      end\n    end\n  end\n\nir |> Beaver.MLIR.to_string() |> IO.puts()\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nmodule {\n  func.func @some_func(%arg0: i32) -> i32 {\n    %c1024_i32 = arith.constant 1024 : i32\n    %0 = arith.addi %arg0, %c1024_i32 : i32\n    return %0 : i32\n  }\n}\n\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```\n\nAs you can see, with MLIR we are not working with those low level LLVM instructions you might have seen somewhere else.\nHere we have this `Func.func` and `Func.return` thing looks like a function and return statement in a programming language.\nAnd the `Arith` stuff seems to be doing some arithmetic for us.\nNow you might take some time to look at the IR printed by `IO.puts` and think about it.\n\nIf you find the text full of `%1`, `%2` not so interesting, don't worry.\nThe only thing you need to know is that this is called MLIR's \"textual form\".\nLet's carry on.","ref":"your-first-beaver-compiler.html#a-taste-of-mlir"},{"type":"extras","title":"Entering the LLVM realm - Your first compiler with Beaver!","doc":"The Next Big Thing™ we are going to do is to convert what we got so far to LLVM IR.\nWhy? Long story short, MLIR is like a cinematic universe.\nInstead of having different hero franchises, we got a bunch of \"dialects\". The `Func`, `Arith` are both dialects.\nThere is a dialect called `LLVM` we haven't seen. `LLVM` is a dialect kind of magical and kind of different from others.\nIt is magical that if we can convert IR to `LLVM`, we can generate native machine code and run it.\n\nThis is how it is done with Beaver:\n\n```elixir\nimport MLIR.Conversion\n\nllvm_ir =\n  ir\n  |> convert_arith_to_llvm\n  |> MLIR.Pass.Composer.nested(\"func.func\", \"llvm-request-c-wrappers\")\n  |> convert_func_to_llvm\n  |> MLIR.Pass.Composer.run!()\n\nllvm_ir |> Beaver.MLIR.to_string() |> IO.puts()\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nmodule {\n  llvm.func @some_func(%arg0: i32) -> i32 attributes {llvm.emit_c_interface} {\n    %0 = llvm.mlir.constant(1024 : i32) : i32\n    %1 = llvm.add %arg0, %0 : i32\n    llvm.return %1 : i32\n  }\n  llvm.func @_mlir_ciface_some_func(%arg0: i32) -> i32 attributes {llvm.emit_c_interface} {\n    %0 = llvm.call @some_func(%arg0) : (i32) -> i32\n    llvm.return %0 : i32\n  }\n}\n\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```\n\nNow you can see the IR seems to \"grow\" a little. It is called \"lowering\".\nWhat we just did is running two passes `convert_func_to_llvm` and `convert_arith_to_llvm` on our IR.\nSo that the higher level abstraction like `Func` and `Arith` are lowered to LLVM IR,\nwhich is a representation closer to the hardware instruction.\n\nRemember what I told you, if we get to LLVM Dialect, basically we should get native machine code to run right?\nLet's do it!","ref":"your-first-beaver-compiler.html#entering-the-llvm-realm"},{"type":"extras","title":"Run it! - Your first compiler with Beaver!","doc":"```elixir\njit = MLIR.ExecutionEngine.create!(llvm_ir)\n\nreturn = Beaver.Native.I32.make(0)\narguments = [Beaver.Native.I32.make(1024)]\n\nMLIR.ExecutionEngine.invoke!(jit, \"some_func\", arguments, return)\n|> Beaver.Native.to_term()\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n2048\n```","ref":"your-first-beaver-compiler.html#run-it"},{"type":"extras","title":"Recap - Your first compiler with Beaver!","doc":"Congratulations! You have just built your first compiler with Beaver.\nThere could be a lot to unpack and here is the summary:\n\n* First we generate some MLIR with the `mlir/1` macro.\n* Then we convert it to LLVM IR with `convert_func_to_llvm` and `convert_arith_to_llvm` passes.\n* Later we create a JIT engine from the generated LLVM IR with `MLIR.ExecutionEngine.create!` and run the native function.\n\nThese three steps are corespondent to what makes a compiler\n\n* IR\n* Pass\n* CodeGen\n\nIn next tutorial we are taking a more programmable approach to generate the IR, converting Elixir AST to MLIR.\nBy doing it we will pick up concepts like region, block, operations appear here but didn't receive much attention for now.\nYou might want to look at the full list of MLIR dialects [here](https://mlir.llvm.org/docs/Dialects/).","ref":"your-first-beaver-compiler.html#recap"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}